@@ -24,7 +24,7 @@
 #ifndef ALBUMICONVIEWTOOLTIP_H
 #define ALBUMICONVIEWTOOLTIP_H
 
-// Local includes.
+// Local includes
 
 #include "imageinfo.h"
 #include "ditemtooltip.h"
@@ -45,8 +45,6 @@ public:
 
     void setIconItem(AlbumIconItem* iconItem);
 
-    static QString fillTipContents(const ImageInfo& info);
-
 private:
 
     QRect   repositionRect();
