@@ -824,16 +824,6 @@ bool AlbumManager::setDatabase(const QString& dbPath, bool priority, const QStri
 
     // -- ---------------------------------------------------------
 
-    // measures to filter out KDirWatch signals caused by database operations
-    d->dirWatchBlackList.clear();
-    DatabaseParameters params = DatabaseAccess::parameters();
-    if (params.isSQLite())
-    {
-        QFileInfo dbFile(params.SQLiteDatabaseFile());
-        d->dbPathModificationDateList = d->buildDirectoryModList(dbFile);
-        d->dirWatchBlackList << dbFile.fileName() << dbFile.fileName() + "-journal";
-    }
-
     // check that we have one album root
     if (CollectionManager::instance()->allLocations().isEmpty())
     {
@@ -862,6 +852,20 @@ bool AlbumManager::setDatabase(const QString& dbPath, bool priority, const QStri
 
     // -- ---------------------------------------------------------
 
+    // measures to filter out KDirWatch signals caused by database operations
+    d->dirWatchBlackList.clear();
+    DatabaseParameters params = DatabaseAccess::parameters();
+    if (params.isSQLite())
+    {
+        QFileInfo dbFile(params.SQLiteDatabaseFile());
+        d->dirWatchBlackList << dbFile.fileName() << dbFile.fileName() + "-journal";
+
+        // ensure this is done after setting up the black list
+        d->dbPathModificationDateList = d->buildDirectoryModList(dbFile);
+    }
+
+    // -- ---------------------------------------------------------
+
 #ifdef HAVE_NEPOMUK
     if (checkNepomukService())
     {
@@ -1034,7 +1038,6 @@ void AlbumManager::slotCollectionLocationPropertiesChanged(const CollectionLocat
     if (album)
     {
         QString newLabel = d->labelForAlbumRootAlbum(location);
-        kDebug() << newLabel << album->title();
         if (album->title() != newLabel)
         {
             album->setTitle(newLabel);
@@ -2679,7 +2682,9 @@ void AlbumManager::slotTagChange(const TagChangeset& changeset)
             break;
         case TagChangeset::Renamed:
         case TagChangeset::IconChanged:
-            //TODO
+            /**
+             * @todo
+             */
             break;
         case TagChangeset::Unknown:
             break;
@@ -2758,7 +2763,12 @@ void AlbumManager::slotDirWatchDirty(const QString& path)
     DatabaseParameters params = DatabaseAccess::parameters();
     if (params.isSQLite())
     {
-        QDir dir(path);
+        QFileInfo info(path);
+        QDir dir;
+        if (info.isDir())
+            dir = QDir(path);
+        else
+            dir = info.dir();
         QFileInfo dbFile(params.SQLiteDatabaseFile());
 
         // Workaround for broken KDirWatch in KDE 4.2.4
