@@ -28,18 +28,18 @@
 #ifndef ALBUMMANAGER_H
 #define ALBUMMANAGER_H
 
-// Qt includes.
+// Qt includes
 
 #include <QList>
 #include <QObject>
 #include <QString>
 #include <QMap>
 
-// KDE includes.
+// KDE includes
 
 #include <kurl.h>
 
-// Local includes.
+// Local includes
 
 #include "albuminfo.h"
 #include "digikam_export.h"
@@ -61,7 +61,6 @@ class PAlbum;
 class TAlbum;
 class DAlbum;
 class SAlbum;
-class AlbumItemHandler;
 class AlbumChangeset;
 class TagChangeset;
 class SearchChangeset;
@@ -70,7 +69,6 @@ class ImageTagChangeset;
 class AlbumManagerPriv;
 
 typedef QList<Album*> AlbumList;
-typedef QPair<int, int> YearMonth;
 
 /**
  * \class AlbumManager
@@ -109,14 +107,17 @@ public:
     * A return value of false during startup indicates termination of the program
     * (user is informed)
     */
-    bool setDatabase(const QString &dbPath, bool priority);
+    bool setDatabase(const QString& dbPath, bool priority, const QString& suggestedAlbumRoot = QString());
+
+    /** Some checks for settings done in first run wizard */
+    static void checkDatabaseDirsAfterFirstRun(const QString& dbPath, const QString& albumPath);
 
     /**
     * Sets new database when chosen by the user in setup.
     * Handles user notification about problems.
     * Call this instead of setDatabase when digikam is up and running.
     */
-    void changeDatabase(const QString &dbPath);
+    void changeDatabase(const QString& dbPath);
 
     /**
     * Stop ongoing operations, prepare for application shutdown
@@ -126,7 +127,7 @@ public:
     /**
     * Checks if the given database path is equal to the current one
     */
-    bool databaseEqual(const QString &dbPath) const;
+    bool databaseEqual(const QString& dbPath) const;
 
     /**
     * starts scanning the libraryPath and listing the albums. If the
@@ -170,7 +171,7 @@ public:
     AlbumList allSAlbums() const;
 
     /**
-     * @return a list of all SAlbums
+     * @return a list of all DAlbums
      */
     AlbumList allDAlbums() const;
 
@@ -233,13 +234,13 @@ public:
      * @return a TAlbum with given tag path, or 0 if not found
      * @param tagPath the tag path ("People/Friend/John")
      */
-    TAlbum*   findTAlbum(const QString &tagPath) const;
+    TAlbum*   findTAlbum(const QString& tagPath) const;
 
     /**
      * @return a SAlbum with given name, or 0 if not found
-     * @param tagPath the name of the search
+     * @param name the name of the search
      */
-    SAlbum*   findSAlbum(const QString &name) const;
+    SAlbum*   findSAlbum(const QString& name) const;
     //@}
 
     /** @name Operations on PAlbum
@@ -259,7 +260,6 @@ public:
      * @param name    the name of the new album
      * @param caption the caption for the new album
      * @param date    the date for the new album
-     * @param collection the collection for the new album
      * @param errMsg  this will contain the error message describing why the
      * operation failed
      */
@@ -280,8 +280,10 @@ public:
     /**
      * Overloaded method. Here you can supply a collection location (which
      * must be available).
+     *
+     * @param location the collection for the new album
      */
-    PAlbum* createPAlbum(const CollectionLocation &location, const QString& name,
+    PAlbum* createPAlbum(const CollectionLocation& location, const QString& name,
                          const QString& caption, const QDate& date,
                          const QString& category,
                          QString& errMsg);
@@ -310,6 +312,11 @@ public:
     bool updatePAlbumIcon(PAlbum *album, qlonglong iconID, QString& errMsg);
     //@}
 
+    /**
+     * @return A hash with the titles for all album IDs.
+     */
+    QHash<int, QString> albumTitles() const;
+
     /** @name Operations on TAlbum
      */
     //@{
@@ -332,10 +339,10 @@ public:
     /**
      * A list of tag paths is supplied.
      * If no corresponding TAlbum exists, a new one will be created.
-     * @param tagPath A list of tag paths
+     * @param tagPaths A list of tag paths
      * @returns A list of all TAlbums for the list (already existing or newly created)
     */
-    AlbumList findOrCreateTAlbums(const QStringList &tagPaths);
+    AlbumList findOrCreateTAlbums(const QStringList& tagPaths);
 
     /**
      * Delete a TAlbum.
@@ -369,7 +376,7 @@ public:
      * @param errMsg this will contain the error message describing why the
      * operation failed
      */
-    bool moveTAlbum(TAlbum* album, TAlbum *newParent, QString &errMsg);
+    bool moveTAlbum(TAlbum* album, TAlbum *newParent, QString& errMsg);
 
     /**
      * Update the icon for a TAlbum. 
@@ -393,16 +400,27 @@ public:
     AlbumList getRecentlyAssignedTags() const;
 
     /**
-     * @return A list with the tagPaths for a list of tag IDs.
+     * @return A list with the tag paths for a list of tag IDs.
      * @param tagIDs list of tag album IDs
+     * @param leadingSlash if <code>true</code> return tags with a leading slash
      */
-    QStringList tagPaths(const QList<int> &tagIDs, bool leadingSlash=true) const;
+    QStringList tagPaths(const QList<int>& tagIDs, bool leadingSlash=true) const;
 
     /**
-     * @return A list with the tagPaths for a list of tag IDs.
+     * @return A list with the tag names for a list of tag IDs.
      * @param tagIDs list of tag album IDs
      */
-    QStringList tagNames(const QList<int> &tagIDs) const;
+    QStringList tagNames(const QList<int>& tagIDs) const;
+
+    /**
+     * @return A hash with the tag paths for all tag IDs.
+     */
+    QHash<int, QString> tagPaths(bool leadingSlash=true) const;
+
+    /**
+     * @return A hash with the tag names for all tag IDs.
+     */
+    QHash<int, QString> tagNames() const;
 
     //@}
 
@@ -417,22 +435,22 @@ public:
      * \note the signalAlbumAdded will be fired before this function returns. Its
      * recommended to connect to that signal to get notification of new album added
      * @return the newly created SAlbum or an existing SAlbum with same name
-     * @param url    the url of the album
-     * @param simple indicates whether the Search album is of simple type or
-     * extended type
+     * @param name  name for the new search
+     * @param type  the type of the search
+     * @param query search query to use
      */
-    SAlbum* createSAlbum(const QString &name, DatabaseSearch::Type type, const QString &query);
+    SAlbum* createSAlbum(const QString& name, DatabaseSearch::Type type, const QString& query);
 
     /**
      * Update the url for a SAlbum
      * @return true if the operation succeeds, false otherwise
      * @param album the album to update
-     * @param query the new query data of the album
+     * @param changedQuery the new query data of the album
      * @param changedName a new name, or null to keep the current name
      * @param type a new type, or UndefinedType to keep the current type
      */
-    bool updateSAlbum(SAlbum* album, const QString &changedQuery,
-                      const QString &changedName = QString(), DatabaseSearch::Type type = DatabaseSearch::UndefinedType);
+    bool updateSAlbum(SAlbum* album, const QString& changedQuery,
+                      const QString& changedName = QString(), DatabaseSearch::Type type = DatabaseSearch::UndefinedType);
 
     /**
      * Delete a SAlbum from the database
@@ -444,12 +462,7 @@ public:
     bool deleteSAlbum(SAlbum* album);
     //@}
 
-    void setItemHandler(AlbumItemHandler *handler);
-    AlbumItemHandler* getItemHandler();
-    void refreshItemHandler(const KUrl::List& itemList=KUrl::List());
-    void emitAlbumItemsSelected(bool val);
-
-signals:
+Q_SIGNALS:
 
     /// An album is about to be added to the given parent (0 if album is root)
     /// after the item given by prev (prev is 0 if parent has no children yet)
@@ -463,7 +476,6 @@ signals:
     /// The album is deleted, the object can no longer be accessed.
     /// For identification purposes, the former album pointer is passed.
     void signalAlbumHasBeenDeleted(void *);
-    void signalAlbumItemsSelected(bool selected);
     void signalAlbumsCleared();
     void signalAlbumCurrentChanged(Album* album);
     void signalAllAlbumsLoaded();
@@ -472,13 +484,12 @@ signals:
     void signalAlbumRenamed(Album* album);
     void signalSearchUpdated(SAlbum *album);
     void signalTAlbumMoved(TAlbum* album, TAlbum* newParent);
-    void signalPAlbumDirty(PAlbum* album);
     void signalPAlbumsDirty(const QMap<int, int>&);
     void signalTAlbumsDirty(const QMap<int, int>&);
     void signalDAlbumsDirty(const QMap<YearMonth, int>&);
     void signalDatesMapDirty(const QMap<QDateTime, int>&);
 
-private slots:
+private Q_SLOTS:
 
     void slotDatesJobResult(KJob* job);
     void slotDatesJobData(KIO::Job* job, const QByteArray& data);
@@ -490,14 +501,14 @@ private slots:
     void slotKioFileMoved(const QString& urlFrom, const QString& urlTo);
     void slotKioFilesDeleted(const QStringList& urls);
     void slotKioFilesAdded(const QString& directory);
-    void slotNotifyFileChange(const QString &directory);
+    void slotNotifyFileChange(const QString& directory);
     void slotCollectionLocationStatusChanged(const CollectionLocation &, int);
-    void slotCollectionLocationPropertiesChanged(const CollectionLocation &location);
-    void slotAlbumChange(const AlbumChangeset &changeset);
-    void slotTagChange(const TagChangeset &changeset);
-    void slotSearchChange(const SearchChangeset &changeset);
-    void slotCollectionImageChange(const CollectionImageChangeset &changeset);
-    void slotImageTagChange(const ImageTagChangeset &changeset);
+    void slotCollectionLocationPropertiesChanged(const CollectionLocation& location);
+    void slotAlbumChange(const AlbumChangeset& changeset);
+    void slotTagChange(const TagChangeset& changeset);
+    void slotSearchChange(const SearchChangeset& changeset);
+    void slotCollectionImageChange(const CollectionImageChangeset& changeset);
+    void slotImageTagChange(const ImageTagChangeset& changeset);
 
     /**
      * Scan albums directly from database and creates new PAlbums
@@ -541,10 +552,10 @@ private:
 
     void notifyAlbumDeletion(Album *album);
 
-    void addAlbumRoot(const CollectionLocation &location);
-    void removeAlbumRoot(const CollectionLocation &location);
+    void addAlbumRoot(const CollectionLocation& location);
+    void removeAlbumRoot(const CollectionLocation& location);
 
-    void handleKioNotification(const KUrl &url);
+    void handleKioNotification(const KUrl& url);
 
     template <class T> friend class AlbumPointer;
     friend class Album;
@@ -554,6 +565,8 @@ private:
     void changeGuardedPointer(Album *oldAlbum, Album *a, Album **pointer);
     void invalidateGuardedPointers(Album *album);
 
+    bool checkNepomukService();
+
 private:
 
     AlbumManagerPriv* const d;
@@ -573,7 +586,7 @@ public:
     AlbumPointer() : album(0) {}
     AlbumPointer(T *a) : album(a)
     { AlbumManager::instance()->addGuardedPointer(album, &album); }
-    AlbumPointer(const AlbumPointer<T> &p) : album(p.album)
+    AlbumPointer(const AlbumPointer<T>& p) : album(p.album)
     { AlbumManager::instance()->addGuardedPointer(album, &album); }
 
     ~AlbumPointer()
@@ -586,7 +599,7 @@ public:
         AlbumManager::instance()->changeGuardedPointer(oldAlbum, album, &album);
         return *this;
     }
-    AlbumPointer<T> operator=(const AlbumPointer<T> &p)
+    AlbumPointer<T> operator=(const AlbumPointer<T>& p)
     {
         Album *oldAlbum = album;
         album = p.album;
