@@ -9,6 +9,7 @@
  * Copyright (C) 2002-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
  * Copyright (C)      2006 by Tom Albers <tomalbers@kde.nl>
  * Copyright (C) 2002-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C)      2009 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,13 +27,13 @@
 #ifndef DIGIKAMAPP_H
 #define DIGIKAMAPP_H
 
-// Qt includes.
+// Qt includes
 
 #include <QList>
 #include <QAction>
 #include <QString>
 
-// KDE includes.
+// KDE includes
 
 #include <kurl.h>
 #include <kxmlguiwindow.h>
@@ -40,16 +41,20 @@
 #include <kio/netaccess.h>
 #include <solid/solidnamespace.h>
 
-// Local includes.
+// Local includes
 
 #include "albumlister.h"
 #include "digikam_export.h"
 
+class KAction;
+
 namespace Solid { class Device; }
 
 namespace Digikam
 {
 
+class AlbumIconViewFilter;
+class DigikamView;
 class ImageInfo;
 class ImageInfoList;
 class CameraType;
@@ -67,7 +72,7 @@ public:
     virtual void show();
     void restoreSession();
 
-    static DigikamApp* getinstance();
+    static DigikamApp* instance();
 
     // KIPI Actions collections access.
     const QList<QAction*>& menuImageActions();
@@ -77,29 +82,33 @@ public:
     const QList<QAction*>& menuExportActions();
 
     void autoDetect();
-    void downloadFrom(const QString &cameraGuiPath);
-    void downloadFromUdi(const QString &udi);
+    void downloadFrom(const QString& cameraGuiPath);
+    void downloadFromUdi(const QString& udi);
+    QString currentDatabaseParameters();
     void enableZoomPlusAction(bool val);
     void enableZoomMinusAction(bool val);
     void enableAlbumBackwardHistory(bool enable);
     void enableAlbumForwardHistory(bool enable);
 
-signals:
+    DigikamView *view() const;
+    AlbumIconViewFilter *iconViewFilter() const;
+
+Q_SIGNALS:
 
     void signalEscapePressed();
     void signalNextItem();
     void signalPrevItem();
     void signalFirstItem();
     void signalLastItem();
+    void signalCutAlbumItemsSelection();
     void signalCopyAlbumItemsSelection();
     void signalPasteAlbumItemsSelection();
     void signalCancelButtonPressed();
-    void signalResetTagFilters();
 
     void signalWindowHasMoved();
 
-    void queuedOpenCameraUiFromPath(const QString &path);
-    void queuedOpenSolidDevice(const QString &udi);
+    void queuedOpenCameraUiFromPath(const QString& path);
+    void queuedOpenSolidDevice(const QString& udi);
 
 protected:
 
@@ -108,26 +117,31 @@ protected:
 
 private:
 
-    bool setup(bool iccSetupPage=false);
+    bool setup();
+    bool setupICC();
     void setupView();
     void setupStatusBar();
     void setupActions();
     void setupAccelerators();
+    void setupExifOrientationActions();
     void loadPlugins();
     void loadCameras();
     void populateThemes();
     void fillSolidMenus();
-    bool checkSolidCamera(const Solid::Device &cameraDevice);
-    QString labelForSolidCamera(const Solid::Device &cameraDevice);
-    void openSolidCamera(const QString &udi, const QString &label = QString());
-    void openSolidUsmDevice(const QString &udi, const QString &label = QString());
+    bool checkSolidCamera(const Solid::Device& cameraDevice);
+    QString labelForSolidCamera(const Solid::Device& cameraDevice);
+    void openSolidCamera(const QString& udi, const QString& label = QString());
+    void openSolidUsmDevice(const QString& udi, const QString& label = QString());
     void runFingerPrintsGenerator(bool rebuildAll);
+    void runThumbnailsGenerator(bool rebuildAll);
+    void updateCameraMenu();
 
-private slots:
+private Q_SLOTS:
 
     void slotAlbumSelected(bool val);
     void slotTagSelected(bool val);
     void slotImageSelected(const ImageInfoList&, bool, bool, const ImageInfoList&);
+    void slotSelectionChanged(int selectionCount);
     void slotExit();
     void slotShowTip();
     void slotShowKipiHelp();
@@ -135,6 +149,7 @@ private slots:
     void slotContribute();
     void slotRawCameraList();
     void slotComponentsInfo();
+    void slotDBStat();
 
     void slotRecurseAlbums(bool);
     void slotRecurseTags(bool);
@@ -145,18 +160,20 @@ private slots:
     void slotSetup();
     void slotSetupCamera();
     void slotSetupChanged();
+    void slotSetCheckedExifOrientationAction(const ImageInfo& info);
+    void slotResetExifOrientationActions();
 
     void slotKipiPluginPlug();
 
     void slotOpenSolidCamera(QAction *);
     void slotOpenManualCamera(QAction *);
     void slotOpenSolidUsmDevice(QAction *);
-    void slotOpenSolidDevice(const QString &udi);
-    void slotOpenCameraUiFromPath(const QString &path);
-    void slotSolidSetupDone(Solid::ErrorType errorType, QVariant errorData, const QString &udi);
-    void slotSolidDeviceChanged(const QString &udi);
-    void slotCameraAdded(CameraType *ctype);
-    void slotCameraRemoved(CameraType *ctype);
+    void slotOpenSolidDevice(const QString& udi);
+    void slotOpenCameraUiFromPath(const QString& path);
+    void slotSolidSetupDone(Solid::ErrorType errorType, QVariant errorData, const QString& udi);
+    void slotSolidDeviceChanged(const QString& udi);
+    void slotCameraAdded(CameraType*);
+    void slotCameraRemoved(KAction*);
     void slotCameraAutoDetect();
     void downloadImages(const QString& folder);
     void cameraAutoDetect();
@@ -165,13 +182,15 @@ private slots:
     void slotShowMenuBar();
     void slotEditKeys();
     void slotConfToolbars();
+    void slotConfNotifications();
     void slotToggleFullScreen();
 
     void slotDatabaseRescan();
-    void slotRebuildAllThumbs();
-    void slotSyncAllPicturesMetadata();
-    void slotRebuildAllFingerPrints();
-    void slotRebuildAllFingerPrintsDone();
+    void slotRebuildThumbnails();
+    void slotWriteMetadataToAllImages();
+    void slotGenerateFingerPrintsFirstTime();
+    void slotRebuildFingerPrints();
+    void slotRebuildFingerPrintsDone();
 
     void slotChangeTheme(const QString& theme);
     void slotThemeChanged();
@@ -188,6 +207,8 @@ private slots:
     void slotImportAddFolders();
     void slotDIOResult(KJob*);
 
+    void slotNepomukSettingsChanged();
+
 private:
 
     DigikamAppPriv* const d;
