@@ -7,7 +7,7 @@
  * Description : digiKam image editor to adjust Hue, Saturation,
  *               and Lightness of picture.
  *
- * Copyright (C) 2004-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -65,7 +65,7 @@
 #include "hslmodifier.h"
 #include "hspreviewwidget.h"
 #include "imageiface.h"
-#include "imagewidget.h"
+#include "imageguidewidget.h"
 
 using namespace KDcrawIface;
 using namespace Digikam;
@@ -112,7 +112,7 @@ public:
 
     HSPreviewWidget*        HSPreview;
 
-    ImageWidget*            previewWidget;
+    ImageGuideWidget*       previewWidget;
     EditorToolSettings*     gboxSettings;
 };
 
@@ -127,12 +127,13 @@ HSLTool::HSLTool(QObject* parent)
 
     d->destinationPreviewData = 0;
 
-    d->previewWidget = new ImageWidget("hsladjust Tool", 0,
-                                      i18n("The Hue/Saturation/Lightness adjustment preview "
-                                           "is shown here. "
-                                           "Picking a color on the image will show the "
-                                           "corresponding color level on the histogram."));
+    d->previewWidget = new ImageGuideWidget;
+    d->previewWidget->setWhatsThis(i18n("The Hue/Saturation/Lightness adjustment preview "
+                                        "is shown here. "
+                                        "Picking a color on the image will show the "
+                                        "corresponding color level on the histogram."));
     setToolView(d->previewWidget);
+    setPreviewModeMask(PreviewToolBar::AllPreviewModes);
 
     // -------------------------------------------------------------
 
@@ -300,7 +301,7 @@ void HSLTool::writeSettings()
     group.writeEntry(d->configHueAdjustmentEntry,        d->hInput->value());
     group.writeEntry(d->configSaturationAdjustmentEntry, d->sInput->value());
     group.writeEntry(d->configLighnessAdjustmentEntry,   d->lInput->value());
-    d->previewWidget->writeSettings();
+
     config->sync();
 }
 
@@ -332,8 +333,7 @@ void HSLTool::slotEffect()
     double sa  = d->sInput->value();
     double lu  = d->lInput->value();
 
-    d->gboxSettings->enableButton(EditorToolSettings::Ok,
-                                (hu != 0.0 || sa != 0.0 || lu != 0.0));
+    d->gboxSettings->enableButton(EditorToolSettings::Ok, (hu != 0.0 || sa != 0.0 || lu != 0.0));
 
     d->HSPreview->setHS(hu, sa);
     d->gboxSettings->histogramBox()->histogram()->stopHistogramComputation();
@@ -341,8 +341,8 @@ void HSLTool::slotEffect()
     if (d->destinationPreviewData)
        delete [] d->destinationPreviewData;
 
-    ImageIface* iface = d->previewWidget->imageIface();
-    d->destinationPreviewData   = iface->getPreviewImage();
+    ImageIface* iface          = d->previewWidget->imageIface();
+    d->destinationPreviewData  = iface->getPreviewImage();
     int w                      = iface->previewWidth();
     int h                      = iface->previewHeight();
     bool a                     = iface->previewHasAlpha();
@@ -370,16 +370,16 @@ void HSLTool::finalRendering()
 {
     kapp->setOverrideCursor( Qt::WaitCursor );
 
-    double hu  = d->hInput->value();
-    double sa  = d->sInput->value();
-    double lu  = d->lInput->value();
+    double hu = d->hInput->value();
+    double sa = d->sInput->value();
+    double lu = d->lInput->value();
 
     ImageIface* iface = d->previewWidget->imageIface();
-    uchar *data                = iface->getOriginalImage();
-    int w                      = iface->originalWidth();
-    int h                      = iface->originalHeight();
-    bool a                     = iface->originalHasAlpha();
-    bool sb                    = iface->originalSixteenBit();
+    uchar *data       = iface->getOriginalImage();
+    int w             = iface->originalWidth();
+    int h             = iface->originalHeight();
+    bool a            = iface->originalHasAlpha();
+    bool sb           = iface->originalSixteenBit();
     DImg original(w, h, sb, a, data);
     delete [] data;
 
