@@ -31,22 +31,21 @@
 #define MINRANGE 0
 
 // Golden number (1+sqrt(5))/2
-#define PHI      1.61803398874989479
+#define PHI      1.61803398874989479F
 // 1/PHI
-#define INVPHI   0.61803398874989479
+#define INVPHI   0.61803398874989479F
 
 
-#include "imageselectionwidget.h"
 #include "imageselectionwidget.moc"
 
-// C++ includes.
+// C++ includes
 
 #include <iostream>
 #include <cstdio>
 #include <cmath>
 #include <cstdlib>
 
-// Qt includes.
+// Qt includes
 
 #include <QRegion>
 #include <QColor>
@@ -62,14 +61,15 @@
 #include <QMouseEvent>
 #include <QPaintEvent>
 
-// KDE includes.
+// KDE includes
+
 
-#include <kdebug.h>
 #include <kstandarddirs.h>
 #include <kcursor.h>
 #include <kglobal.h>
+#include <kdebug.h>
 
-// Local includes.
+// Local includes
 
 #include "imageiface.h"
 #include "dimg.h"
@@ -112,6 +112,8 @@ public:
     bool                 autoOrientation;
     bool                 preciseCrop;
 
+    bool                 isDrawingSelection;
+
     int                  guideLinesType;
     int                  guideSize;
 
@@ -135,21 +137,44 @@ public:
     QRect                localTopRightCorner;
     QRect                localBottomRightCorner;
 
-    QPixmap             *pixmap;
+    QPixmap*             pixmap;
+    QPixmap              grayOverLay;
+    QPixmap              previewPixmap;
 
     QColor               guideColor;
 
     Digikam::DImg        preview;
 
-    Digikam::ImageIface *iface;
+    Digikam::ImageIface* iface;
 };
 
-ImageSelectionWidget::ImageSelectionWidget(int w, int h, QWidget *parent,
-                                           int widthRatioValue, int heightRatioValue,
-                                           int aspectRatioType, int orient, int guideLinesType)
+ImageSelectionWidget::ImageSelectionWidget(int w, int h, QWidget *parent)
                     : QWidget(parent), d(new ImageSelectionWidgetPriv)
 {
-    d->currentAspectRatioType  = aspectRatioType;
+    d->isDrawingSelection = true;
+    setup(w, h);
+}
+
+ImageSelectionWidget::ImageSelectionWidget(int w, int h, bool initDrawing, QWidget *parent)
+                    : QWidget(parent), d(new ImageSelectionWidgetPriv)
+{
+    d->isDrawingSelection = initDrawing;
+    setup(w, h);
+}
+
+ImageSelectionWidget::~ImageSelectionWidget()
+{
+    delete d->iface;
+    delete d->pixmap;
+    delete d;
+}
+
+void ImageSelectionWidget::setup(int w, int h,
+                                 int widthRatioValue, int heightRatioValue,
+                                 int aspectRatio, int orient,
+                                 int guideLinesType)
+{
+    d->currentAspectRatioType  = aspectRatio;
     d->currentWidthRatioValue  = widthRatioValue;
     d->currentHeightRatioValue = heightRatioValue;
     d->currentOrientation      = orient;
@@ -177,17 +202,11 @@ ImageSelectionWidget::ImageSelectionWidget(int w, int h, QWidget *parent,
     d->image = QRect(0, 0, d->iface->originalWidth(), d->iface->originalHeight());
     d->rect  = QRect(w/2-d->preview.width()/2, h/2-d->preview.height()/2,
                      d->preview.width(), d->preview.height());
+
     updatePixmap();
     setGoldenGuideTypes(true, false, false, false, false, false);
 }
 
-ImageSelectionWidget::~ImageSelectionWidget()
-{
-    delete d->iface;
-    delete d->pixmap;
-    delete d;
-}
-
 Digikam::ImageIface* ImageSelectionWidget::imageIface()
 {
     return d->iface;
@@ -213,6 +232,41 @@ void ImageSelectionWidget::resizeEvent(QResizeEvent *e)
 
     d->rect   = QRect(w/2-d->preview.width()/2, h/2-d->preview.height()/2,
                       d->preview.width(), d->preview.height());
+
+    // Drawing the gray overlay
+    {
+        Digikam::DImg image = d->preview.copy();
+        uchar* ptr          = image.bits();
+        uchar  r, g, b;
+
+        int xlow  = d->rect.left();
+        int xhigh = d->rect.right();
+        int ylow  = d->rect.top();
+        int yhigh = d->rect.bottom();
+
+        for (int y = ylow ; y <= yhigh ; ++y)
+        {
+            for (int x = xlow ; x <= xhigh ; ++x)
+            {
+                b = ptr[0];
+                g = ptr[1];
+                r = ptr[2];
+
+                r += (uchar)((RCOL - r) * OPACITY);
+                g += (uchar)((GCOL - g) * OPACITY);
+                b += (uchar)((BCOL - b) * OPACITY);
+
+                ptr[0] = b;
+                ptr[1] = g;
+                ptr[2] = r;
+
+                ptr+=4;
+            }
+        }
+        d->grayOverLay   = image.convertToPixmap();
+        d->previewPixmap = d->preview.convertToPixmap();
+    }
+
     updatePixmap();
 }
 
@@ -704,6 +758,147 @@ void ImageSelectionWidget::regionSelectionChanged(void)
     emit signalSelectionChanged( d->regionSelection );
 }
 
+void ImageSelectionWidget::drawRulesOfThirds(QPainter &p, const int &xThird, const int &yThird)
+{
+
+    p.drawLine( d->localRegionSelection.left() + xThird,   d->localRegionSelection.top(),
+                d->localRegionSelection.left() + xThird,   d->localRegionSelection.bottom() );
+    p.drawLine( d->localRegionSelection.left() + 2*xThird, d->localRegionSelection.top(),
+                d->localRegionSelection.left() + 2*xThird, d->localRegionSelection.bottom() );
+
+    p.drawLine( d->localRegionSelection.left(),  d->localRegionSelection.top() + yThird,
+                d->localRegionSelection.right(), d->localRegionSelection.top() + yThird );
+    p.drawLine( d->localRegionSelection.left(),  d->localRegionSelection.top() + 2*yThird,
+                d->localRegionSelection.right(), d->localRegionSelection.top() + 2*yThird );
+
+}
+
+void ImageSelectionWidget::drawDiagonalMethod(QPainter &p, const int &w, const int &h)
+{
+    p.setRenderHint(QPainter::Antialiasing);
+    
+    if (w > h)
+    {
+        p.drawLine(0, 0, h, h);
+        p.drawLine(0, h, h, 0);
+        p.drawLine(w-h, 0, w, h);
+        p.drawLine(w-h, h, w, 0);
+    }
+    else
+    {
+        p.drawLine(0, 0, w, w);
+        p.drawLine(0, w, w, 0);
+        p.drawLine(0, h-w, w, h);
+        p.drawLine(0, h, w, h-w);
+    }
+
+}
+
+void ImageSelectionWidget::drawHarmoniousTriangles(QPainter &p, const int &dst)
+{
+    p.setRenderHint(QPainter::Antialiasing);
+        
+    p.drawLine( -d->localRegionSelection.width()/2, -d->localRegionSelection.height()/2,
+                 d->localRegionSelection.width()/2,  d->localRegionSelection.height()/2);
+
+    p.drawLine( -d->localRegionSelection.width()/2 + dst, -d->localRegionSelection.height()/2,
+                -d->localRegionSelection.width()/2,        d->localRegionSelection.height()/2);
+
+    p.drawLine( d->localRegionSelection.width()/2,       -d->localRegionSelection.height()/2,
+                d->localRegionSelection.width()/2 - dst,  d->localRegionSelection.height()/2);
+
+}
+
+void ImageSelectionWidget::drawGoldenMean(QPainter &p, const QRect &R1,
+                const QRect &R2, const QRect &R3, const QRect &R4,
+                const QRect &R5, const QRect &R6, const QRect &R7)
+{
+    p.setRenderHint(QPainter::Antialiasing);
+    
+    // Drawing Golden sections.
+    if (d->drawGoldenSection)
+    {
+       // horizontal lines:
+       p.drawLine( R1.left(), R2.top(),
+                   R2.right(), R2.top());
+
+       p.drawLine( R1.left(), R1.top() + R2.height(),
+                   R2.right(), R1.top() + R2.height());
+
+       // vertical lines:
+       p.drawLine( R1.right(), R1.top(),
+                   R1.right(), R1.bottom() );
+
+       p.drawLine( R1.left()+R2.width(), R1.top(),
+                   R1.left()+R2.width(), R1.bottom() );
+    }
+
+    // Drawing Golden triangle guides.
+    if (d->drawGoldenTriangle)
+    {
+       p.drawLine( R1.left(),  R1.bottom(),
+                   R2.right(), R1.top() );
+
+       p.drawLine( R1.left(), R1.top(),
+                   R2.right() - R1.width(), R1.bottom());
+
+       p.drawLine( R1.left() + R1.width(), R1.top(),
+                   R2.right(), R1.bottom() );
+    }
+
+    // Drawing Golden spiral sections.
+    if (d->drawGoldenSpiralSection)
+    {
+       p.drawLine( R1.topRight(),   R1.bottomRight() );
+       p.drawLine( R2.topLeft(),    R2.topRight() );
+       p.drawLine( R3.topLeft(),    R3.bottomLeft() );
+       p.drawLine( R4.bottomLeft(), R4.bottomRight() );
+       p.drawLine( R5.topRight(),   R5.bottomRight() );
+       p.drawLine( R6.topLeft(),    R6.topRight() );
+       p.drawLine( R7.topLeft(),    R7.bottomLeft() );
+    }
+
+    // Drawing Golden Spiral.
+    if (d->drawGoldenSpiral)
+    {
+       p.drawArc ( R1.left(),
+                   R1.top() - R1.height(),
+                   2*R1.width(), 2*R1.height(),
+                   180*16, 90*16);
+
+       p.drawArc ( R2.right() - 2*R2.width(),
+                   R1.bottom() - 2*R2.height(),
+                   2*R2.width(), 2*R2.height(),
+                   270*16, 90*16);
+
+       p.drawArc ( R2.right() - 2*R3.width(),
+                   R3.top(),
+                   2*R3.width(), 2*R3.height(),
+                   0, 90*16);
+
+       p.drawArc ( R4.left(),
+                   R4.top(),
+                   2*R4.width(), 2*R4.height(),
+                   90*16, 90*16);
+
+       p.drawArc ( R5.left(),
+                   R5.top()-R5.height(),
+                   2*R5.width(), 2*R5.height(),
+                   180*16, 90*16);
+
+       p.drawArc ( R6.left()-R6.width(),
+                   R6.top()-R6.height(),
+                   2*R6.width(), 2*R6.height(),
+                   270*16, 90*16);
+
+       p.drawArc ( R7.left()-R7.width(),
+                   R7.top(),
+                   2*R7.width(), 2*R7.height(),
+                   0, 90*16);
+    }
+
+}
+
 void ImageSelectionWidget::updatePixmap()
 {
     // Updated local selection region.
@@ -728,44 +923,22 @@ void ImageSelectionWidget::updatePixmap()
     if (d->preview.isNull())
         return;
 
-    // Drawing region outside selection grayed.
+    int sx = d->localRegionSelection.left() - d->rect.left();
+    int sy = d->localRegionSelection.top()  - d->rect.top();
+    int dw = d->localRegionSelection.width();
+    int dh = d->localRegionSelection.height();
 
-    Digikam::DImg image = d->preview.copy();
-
-    uchar* ptr = image.bits();
-    uchar  r, g, b;
-
-    for (int y=d->rect.top() ; y <= d->rect.bottom() ; y++)
-    {
-        for (int x=d->rect.left() ; x <= d->rect.right() ; x++)
-        {
-            if (! d->localRegionSelection.contains(x, y, true) )
-            {
-                b = ptr[0];
-                g = ptr[1];
-                r = ptr[2];
-
-                r += (uchar)((RCOL - r) * OPACITY);
-                g += (uchar)((GCOL - g) * OPACITY);
-                b += (uchar)((BCOL - b) * OPACITY);
-
-                ptr[0] = b;
-                ptr[1] = g;
-                ptr[2] = r;
-            }
-
-            ptr+=4;
-        }
-    }
-
-    QPixmap pix = d->iface->convertToPixmap(image);
     QPainter p(d->pixmap);
-    p.drawPixmap(d->rect.x(), d->rect.y(), pix);
+
+    p.drawPixmap(d->rect.x(), d->rect.y(), d->grayOverLay);
 
     // Stop here if no selection to draw
-    if ( d->regionSelection.isEmpty() )
+    if (d->regionSelection.isEmpty() || !d->isDrawingSelection)
         return;
 
+    p.drawPixmap(d->localRegionSelection.left(), d->localRegionSelection.top(), d->previewPixmap,
+                 sx, sy, dw, dh);
+
     // Drawing selection borders.
 
     p.setPen(QPen(QColor(250, 250, 255), 1, Qt::SolidLine));
@@ -790,31 +963,15 @@ void ImageSelectionWidget::updatePixmap()
     {
        case RulesOfThirds:
        {
-            int xThird = d->localRegionSelection.width()  / 3;
-            int yThird = d->localRegionSelection.height() / 3;
+           int xThird = d->localRegionSelection.width()  / 3;
+           int yThird = d->localRegionSelection.height() / 3;
 
-            p.setPen(QPen(Qt::white, d->guideSize, Qt::SolidLine));
-            p.drawLine( d->localRegionSelection.left() + xThird,   d->localRegionSelection.top(),
-                        d->localRegionSelection.left() + xThird,   d->localRegionSelection.bottom() );
-            p.drawLine( d->localRegionSelection.left() + 2*xThird, d->localRegionSelection.top(),
-                        d->localRegionSelection.left() + 2*xThird, d->localRegionSelection.bottom() );
+           p.setPen(QPen(Qt::white, d->guideSize, Qt::SolidLine));
+           drawRulesOfThirds(p, xThird, yThird);
 
-            p.drawLine( d->localRegionSelection.left(),  d->localRegionSelection.top() + yThird,
-                        d->localRegionSelection.right(), d->localRegionSelection.top() + yThird );
-            p.drawLine( d->localRegionSelection.left(),  d->localRegionSelection.top() + 2*yThird,
-                        d->localRegionSelection.right(), d->localRegionSelection.top() + 2*yThird );
-
-            p.setPen(QPen(d->guideColor, d->guideSize, Qt::DotLine));
-            p.drawLine( d->localRegionSelection.left() + xThird,   d->localRegionSelection.top(),
-                        d->localRegionSelection.left() + xThird,   d->localRegionSelection.bottom() );
-            p.drawLine( d->localRegionSelection.left() + 2*xThird, d->localRegionSelection.top(),
-                        d->localRegionSelection.left() + 2*xThird, d->localRegionSelection.bottom() );
-
-            p.drawLine( d->localRegionSelection.left(),  d->localRegionSelection.top() + yThird,
-                        d->localRegionSelection.right(), d->localRegionSelection.top() + yThird );
-            p.drawLine( d->localRegionSelection.left(),  d->localRegionSelection.top() + 2*yThird,
-                        d->localRegionSelection.right(), d->localRegionSelection.top() + 2*yThird );
-            break;
+           p.setPen(QPen(d->guideColor, d->guideSize, Qt::DotLine));
+           drawRulesOfThirds(p, xThird, yThird);
+           break;
        }
 
        case DiagonalMethod:
@@ -826,38 +983,10 @@ void ImageSelectionWidget::updatePixmap()
            int h = d->localRegionSelection.height();
 
            p.setPen(QPen(Qt::white, d->guideSize, Qt::SolidLine));
-           if (w > h)
-           {
-               p.drawLine(0, 0, h, h);
-               p.drawLine(0, h, h, 0);
-               p.drawLine(w-h, 0, w, h);
-               p.drawLine(w-h, h, w, 0);
-
-           }
-           else
-           {
-               p.drawLine(0, 0, w, w);
-               p.drawLine(0, w, w, 0);
-               p.drawLine(0, h-w, w, h);
-               p.drawLine(0, h, w, h-w);
-           }
+           drawDiagonalMethod(p, w, h);
 
            p.setPen(QPen(d->guideColor, d->guideSize, Qt::DotLine));
-           if (w > h)
-           {
-               p.drawLine(0, 0, h, h);
-               p.drawLine(0, h, h, 0);
-               p.drawLine(w-h, 0, w, h);
-               p.drawLine(w-h, h, w, 0);
-
-           }
-           else
-           {
-               p.drawLine(0, 0, w, w);
-               p.drawLine(0, w, w, 0);
-               p.drawLine(0, h-w, w, h);
-               p.drawLine(0, h, w, h-w);
-           }
+           drawDiagonalMethod(p, w, h);
            break;
        }
 
@@ -879,24 +1008,10 @@ void ImageSelectionWidget::updatePixmap()
             int dst = (int)((h*cos(atan(w/h)) / (cos(atan(h/w)))));
 
             p.setPen(QPen(Qt::white, d->guideSize, Qt::SolidLine));
-            p.drawLine( -d->localRegionSelection.width()/2, -d->localRegionSelection.height()/2,
-                         d->localRegionSelection.width()/2,  d->localRegionSelection.height()/2);
-
-            p.drawLine( -d->localRegionSelection.width()/2 + dst, -d->localRegionSelection.height()/2,
-                        -d->localRegionSelection.width()/2,        d->localRegionSelection.height()/2);
-
-            p.drawLine( d->localRegionSelection.width()/2,       -d->localRegionSelection.height()/2,
-                        d->localRegionSelection.width()/2 - dst,  d->localRegionSelection.height()/2);
+            drawHarmoniousTriangles(p, dst);
 
             p.setPen(QPen(d->guideColor, d->guideSize, Qt::DotLine));
-            p.drawLine( -d->localRegionSelection.width()/2, -d->localRegionSelection.height()/2,
-                         d->localRegionSelection.width()/2,  d->localRegionSelection.height()/2);
-
-            p.drawLine( -d->localRegionSelection.width()/2 + dst, -d->localRegionSelection.height()/2,
-                        -d->localRegionSelection.width()/2,        d->localRegionSelection.height()/2);
-
-            p.drawLine( d->localRegionSelection.width()/2,       -d->localRegionSelection.height()/2,
-                        d->localRegionSelection.width()/2 - dst,  d->localRegionSelection.height()/2);
+            drawHarmoniousTriangles(p, dst);
             break;
        }
 
@@ -939,172 +1054,10 @@ void ImageSelectionWidget::updatePixmap()
                      (int)(R6.width()*INVPHI), R5.height() - R6.height());
 
             p.setPen(QPen(Qt::white, d->guideSize, Qt::SolidLine));
-
-            // Drawing Golden sections.
-            if (d->drawGoldenSection)
-            {
-               // horizontal lines:
-               p.drawLine( R1.left(), R2.top(),
-                           R2.right(), R2.top());
-
-               p.drawLine( R1.left(), R1.top() + R2.height(),
-                           R2.right(), R1.top() + R2.height());
-
-               // vertical lines:
-               p.drawLine( R1.right(), R1.top(),
-                           R1.right(), R1.bottom() );
-
-               p.drawLine( R1.left()+R2.width(), R1.top(),
-                           R1.left()+R2.width(), R1.bottom() );
-            }
-
-            // Drawing Golden triangle guides.
-            if (d->drawGoldenTriangle)
-            {
-               p.drawLine( R1.left(),  R1.bottom(),
-                           R2.right(), R1.top() );
-
-               p.drawLine( R1.left(), R1.top(),
-                           R2.right() - R1.width(), R1.bottom());
-
-               p.drawLine( R1.left() + R1.width(), R1.top(),
-                           R2.right(), R1.bottom() );
-            }
-
-            // Drawing Golden spiral sections.
-            if (d->drawGoldenSpiralSection)
-            {
-               p.drawLine( R1.topRight(),   R1.bottomRight() );
-               p.drawLine( R2.topLeft(),    R2.topRight() );
-               p.drawLine( R3.topLeft(),    R3.bottomLeft() );
-               p.drawLine( R4.bottomLeft(), R4.bottomRight() );
-               p.drawLine( R5.topRight(),   R5.bottomRight() );
-               p.drawLine( R6.topLeft(),    R6.topRight() );
-               p.drawLine( R7.topLeft(),    R7.bottomLeft() );
-            }
-
-            // Drawing Golden Spiral.
-            if (d->drawGoldenSpiral)
-            {
-               p.drawArc ( R1.left(),
-                           R1.top() - R1.height(),
-                           2*R1.width(), 2*R1.height(),
-                           180*16, 90*16);
-
-               p.drawArc ( R2.right() - 2*R2.width(),
-                           R1.bottom() - 2*R2.height(),
-                           2*R2.width(), 2*R2.height(),
-                           270*16, 90*16);
-
-               p.drawArc ( R2.right() - 2*R3.width(),
-                           R3.top(),
-                           2*R3.width(), 2*R3.height(),
-                           0, 90*16);
-
-               p.drawArc ( R4.left(),
-                           R4.top(),
-                           2*R4.width(), 2*R4.height(),
-                           90*16, 90*16);
-
-               p.drawArc ( R5.left(),
-                           R5.top()-R5.height(),
-                           2*R5.width(), 2*R5.height(),
-                           180*16, 90*16);
-
-               p.drawArc ( R6.left()-R6.width(),
-                           R6.top()-R6.height(),
-                           2*R6.width(), 2*R6.height(),
-                           270*16, 90*16);
-
-               p.drawArc ( R7.left()-R7.width(),
-                           R7.top(),
-                           2*R7.width(), 2*R7.height(),
-                           0, 90*16);
-            }
+            drawGoldenMean(p, R1, R2, R3, R4, R5, R6, R7);
 
             p.setPen(QPen(d->guideColor, d->guideSize, Qt::DotLine));
-
-            // Drawing Golden sections.
-            if (d->drawGoldenSection)
-            {
-               // horizontal lines:
-               p.drawLine( R1.left(), R2.top(),
-                           R2.right(), R2.top());
-
-               p.drawLine( R1.left(), R1.top() + R2.height(),
-                           R2.right(), R1.top() + R2.height());
-
-               // vertical lines:
-               p.drawLine( R1.right(), R1.top(),
-                           R1.right(), R1.bottom() );
-
-               p.drawLine( R1.left()+R2.width(), R1.top(),
-                           R1.left()+R2.width(), R1.bottom() );
-            }
-
-            // Drawing Golden triangle guides.
-            if (d->drawGoldenTriangle)
-            {
-               p.drawLine( R1.left(),  R1.bottom(),
-                           R2.right(), R1.top() );
-
-               p.drawLine( R1.left(), R1.top(),
-                           R2.right() - R1.width(), R1.bottom());
-
-               p.drawLine( R1.left() + R1.width(), R1.top(),
-                           R2.right(), R1.bottom() );
-            }
-
-            // Drawing Golden spiral sections.
-            if (d->drawGoldenSpiralSection)
-            {
-               p.drawLine( R1.topRight(),   R1.bottomRight() );
-               p.drawLine( R2.topLeft(),    R2.topRight() );
-               p.drawLine( R3.topLeft(),    R3.bottomLeft() );
-               p.drawLine( R4.bottomLeft(), R4.bottomRight() );
-               p.drawLine( R5.topRight(),   R5.bottomRight() );
-               p.drawLine( R6.topLeft(),    R6.topRight() );
-               p.drawLine( R7.topLeft(),    R7.bottomLeft() );
-            }
-
-            // Drawing Golden Spiral.
-            if (d->drawGoldenSpiral)
-            {
-               p.drawArc ( R1.left(),
-                           R1.top() - R1.height(),
-                           2*R1.width(), 2*R1.height(),
-                           180*16, 90*16);
-
-               p.drawArc ( R2.right() - 2*R2.width(),
-                           R1.bottom() - 2*R2.height(),
-                           2*R2.width(), 2*R2.height(),
-                           270*16, 90*16);
-
-               p.drawArc ( R2.right() - 2*R3.width(),
-                           R3.top(),
-                           2*R3.width(), 2*R3.height(),
-                           0, 90*16);
-
-               p.drawArc ( R4.left(),
-                           R4.top(),
-                           2*R4.width(), 2*R4.height(),
-                           90*16, 90*16);
-
-               p.drawArc ( R5.left(),
-                           R5.top()-R5.height(),
-                           2*R5.width(), 2*R5.height(),
-                           180*16, 90*16);
-
-               p.drawArc ( R6.left()-R6.width(),
-                           R6.top()-R6.height(),
-                           2*R6.width(), 2*R6.height(),
-                           270*16, 90*16);
-
-               p.drawArc ( R7.left()-R7.width(),
-                           R7.top(),
-                           2*R7.width(), 2*R7.height(),
-                           0, 90*16);
-            }
+            drawGoldenMean(p, R1, R2, R3, R4, R5, R6, R7);
 
             break;
        }
@@ -1248,7 +1201,7 @@ void ImageSelectionWidget::placeSelection(QPoint pm, bool symmetric, QPoint cent
 
 void ImageSelectionWidget::mousePressEvent ( QMouseEvent * e )
 {
-    if ( e->button() == Qt::LeftButton )
+    if (e->button() == Qt::LeftButton)
     {
         QPoint pm        = QPoint(e->x(), e->y());
         QPoint pmVirtual = convertPoint(pm);
@@ -1269,11 +1222,12 @@ void ImageSelectionWidget::mousePressEvent ( QMouseEvent * e )
                                 ImageSelectionWidgetPriv::ResizingTopRight,
                                 ImageSelectionWidgetPriv::ResizingBottomLeft,
                                 ImageSelectionWidgetPriv::ResizingBottomRight };
-            float dist = -1;
-            for (int i = 0 ; i < 4 ; i++)
+            float dist  = -1.0f;
+            float dist2 =  0.0f;
+            for (int i = 0 ; i < 4 ; ++i)
             {
                 QPoint point = points[i];
-                float dist2 = distance(pmVirtual, point);
+                dist2 = distance(pmVirtual, point);
                 if (dist2 < dist || d->currentResizing == ImageSelectionWidgetPriv::ResizingNone)
                 {
                     dist = dist2;
@@ -1327,7 +1281,7 @@ void ImageSelectionWidget::mouseReleaseEvent ( QMouseEvent * )
     }
     else if ( d->regionSelection.contains( d->lastPos ) )
     {
-        setCursor( Qt::PointingHandCursor );
+        setCursor( Qt::SizeAllCursor );
         regionSelectionMoved();
     }
     else
@@ -1339,7 +1293,7 @@ void ImageSelectionWidget::mouseReleaseEvent ( QMouseEvent * )
 
 void ImageSelectionWidget::mouseMoveEvent ( QMouseEvent * e )
 {
-    if ( ( e->buttons() & Qt::LeftButton ) == Qt::LeftButton )
+    if (e->buttons() & Qt::LeftButton)
     {
         if ( d->moving )
         {
@@ -1421,10 +1375,15 @@ void ImageSelectionWidget::mouseMoveEvent ( QMouseEvent * e )
                   d->localBottomLeftCorner.contains( e->x(), e->y() ) )
             setCursor( Qt::SizeBDiagCursor );
         else if ( d->localRegionSelection.contains( e->x(), e->y() ) )
-            setCursor( Qt::PointingHandCursor );
+            setCursor( Qt::SizeAllCursor );
         else
             setCursor( Qt::ArrowCursor );
     }
 }
 
+void ImageSelectionWidget::setIsDrawingSelection(bool draw)
+{
+    d->isDrawingSelection = draw;
+}
+
 }  // namespace DigikamImagesPluginCore
