@@ -7,8 +7,8 @@
  * Description : a digiKam image editor plugin for add film
  *               grain on an image.
  *
- * Copyright (C) 2004-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2004-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,16 +23,13 @@
  *
  * ============================================================ */
 
-
 #include "filmgraintool.moc"
 
 // Qt includes
 
 #include <QGridLayout>
 #include <QImage>
-#include <QLCDNumber>
 #include <QLabel>
-#include <QSlider>
 
 // KDE includes
 
@@ -45,6 +42,10 @@
 #include <klocale.h>
 #include <kstandarddirs.h>
 
+// LibKDcraw includes
+
+#include <libkdcraw/rnuminput.h>
+
 // Local includes
 
 #include "daboutdata.h"
@@ -52,10 +53,10 @@
 #include "editortoolsettings.h"
 #include "filmgrain.h"
 #include "imageiface.h"
-#include "imagepanelwidget.h"
+#include "imageregionwidget.h"
 #include "version.h"
 
-using namespace Digikam;
+using namespace KDcrawIface;
 
 namespace DigikamFilmGrainImagesPlugin
 {
@@ -67,8 +68,7 @@ public:
     FilmGrainToolPriv() :
         configGroupName("filmgrain Tool"),
         configSensitivityAdjustmentEntry("SensitivityAdjustment"),
-        sensibilitySlider(0),
-        sensibilityLCDValue(0),
+        sensibilityInput(0),
         previewWidget(0),
         gboxSettings(0)
         {}
@@ -76,11 +76,9 @@ public:
     const QString       configGroupName;
     const QString       configSensitivityAdjustmentEntry;
 
-    QSlider*            sensibilitySlider;
+    RIntNumInput*       sensibilityInput;
 
-    QLCDNumber*         sensibilityLCDValue;
-
-    ImagePanelWidget*   previewWidget;
+    ImageRegionWidget*  previewWidget;
     EditorToolSettings* gboxSettings;
 };
 
@@ -94,38 +92,29 @@ FilmGrainTool::FilmGrainTool(QObject* parent)
 
     // -------------------------------------------------------------
 
-    d->gboxSettings = new EditorToolSettings;
-    d->gboxSettings->setTools(EditorToolSettings::PanIcon);
-
-    d->previewWidget = new ImagePanelWidget(470, 350, "filmgrain Tool", d->gboxSettings->panIconView());
+    d->gboxSettings  = new EditorToolSettings;
+    d->previewWidget = new ImageRegionWidget;
+    
+    d->gboxSettings->setButtons(EditorToolSettings::Default|
+                                EditorToolSettings::Ok|
+                                EditorToolSettings::Cancel|
+                                EditorToolSettings::Try);
 
     // -------------------------------------------------------------
 
-    QLabel *label1       = new QLabel(i18n("Sensitivity (ISO):"));
-    d->sensibilitySlider = new QSlider(Qt::Horizontal);
-    d->sensibilitySlider->setMinimum(2);
-    d->sensibilitySlider->setMaximum(30);
-    d->sensibilitySlider->setPageStep(1);
-    d->sensibilitySlider->setValue(12);
-    d->sensibilitySlider->setTracking(false);
-    d->sensibilitySlider->setTickInterval(1);
-    d->sensibilitySlider->setTickPosition(QSlider::TicksBelow);
-
-    d->sensibilityLCDValue = new QLCDNumber(4);
-    d->sensibilityLCDValue->setSegmentStyle( QLCDNumber::Flat );
-    d->sensibilityLCDValue->display( QString::number(2400) );
-    QString whatsThis = i18n("Set here the film ISO-sensitivity to use for "
-                             "simulating the film graininess.");
-
-    d->sensibilityLCDValue->setWhatsThis( whatsThis);
-    d->sensibilitySlider->setWhatsThis( whatsThis);
+    QLabel *label1      = new QLabel(i18n("Sensitivity (ISO):"));
+    d->sensibilityInput = new RIntNumInput;
+    d->sensibilityInput->setRange(800, 6400, 10);
+    d->sensibilityInput->setSliderEnabled(true);
+    d->sensibilityInput->setDefaultValue(2400);
+    d->sensibilityInput->setWhatsThis(i18n("Set here the film ISO-sensitivity to use for "
+                                           "simulating the film graininess."));
 
     // -------------------------------------------------------------
 
     QGridLayout* mainLayout = new QGridLayout;
-    mainLayout->addWidget(label1,                 0, 0, 1, 2);
-    mainLayout->addWidget(d->sensibilitySlider,   1, 0, 1, 1);
-    mainLayout->addWidget(d->sensibilityLCDValue, 1, 1, 1, 1);
+    mainLayout->addWidget(label1,              0, 0, 1, 1);
+    mainLayout->addWidget(d->sensibilityInput, 1, 0, 1, 1);
     mainLayout->setRowStretch(2, 10);
     mainLayout->setMargin(d->gboxSettings->spacingHint());
     mainLayout->setSpacing(d->gboxSettings->spacingHint());
@@ -135,20 +124,13 @@ FilmGrainTool::FilmGrainTool(QObject* parent)
 
     setToolSettings(d->gboxSettings);
     setToolView(d->previewWidget);
+    setPreviewModeMask(PreviewToolBar::AllPreviewModes);    
     init();
 
     // -------------------------------------------------------------
 
-    connect(d->sensibilitySlider, SIGNAL(valueChanged(int)),
-            this, SLOT(slotTimer()) );
-
-    // this connection is necessary to change the LCD display when
-    // the value is changed by single clicking on the slider
-    connect(d->sensibilitySlider, SIGNAL(valueChanged(int)),
-            this, SLOT(slotSliderMoved(int)) );
-
-    connect(d->sensibilitySlider, SIGNAL(sliderMoved(int)),
-            this, SLOT(slotSliderMoved(int)) );
+    connect(d->sensibilityInput, SIGNAL(valueChanged (int)),
+            this, SLOT(slotTimer()));
 
     // -------------------------------------------------------------
 
@@ -162,55 +144,51 @@ FilmGrainTool::~FilmGrainTool()
 
 void FilmGrainTool::renderingFinished()
 {
-    d->sensibilitySlider->setEnabled(true);
+    d->sensibilityInput->setEnabled(true);
+    toolView()->setEnabled(true);
 }
 
 void FilmGrainTool::readSettings()
 {
     KSharedConfig::Ptr config = KGlobal::config();
     KConfigGroup group        = config->group(d->configGroupName);
-    d->sensibilitySlider->blockSignals(true);
-    d->sensibilitySlider->setValue(group.readEntry(d->configSensitivityAdjustmentEntry, 12));
-    d->sensibilitySlider->blockSignals(false);
-    slotSliderMoved(d->sensibilitySlider->value());
+    d->sensibilityInput->blockSignals(true);
+    d->sensibilityInput->setValue(group.readEntry(d->configSensitivityAdjustmentEntry, d->sensibilityInput->defaultValue()));
+    d->sensibilityInput->blockSignals(false);
 }
 
 void FilmGrainTool::writeSettings()
 {
     KSharedConfig::Ptr config = KGlobal::config();
     KConfigGroup group        = config->group(d->configGroupName);
-    group.writeEntry(d->configSensitivityAdjustmentEntry, d->sensibilitySlider->value());
-    d->previewWidget->writeSettings();
+    group.writeEntry(d->configSensitivityAdjustmentEntry, d->sensibilityInput->value());
     config->sync();
 }
 
 void FilmGrainTool::slotResetSettings()
 {
-    d->sensibilitySlider->blockSignals(true);
-    d->sensibilitySlider->setValue(12);
-    d->sensibilitySlider->blockSignals(false);
-}
-
-void FilmGrainTool::slotSliderMoved(int v)
-{
-    d->sensibilityLCDValue->display( QString::number(400+200*v) );
+    d->sensibilityInput->blockSignals(true);
+    d->sensibilityInput->slotReset();
+    d->sensibilityInput->blockSignals(false);
 }
 
 void FilmGrainTool::prepareEffect()
 {
-    d->sensibilitySlider->setEnabled(false);
-
+    d->sensibilityInput->setEnabled(false);
+    toolView()->setEnabled(false);
+    
     DImg image = d->previewWidget->getOriginalRegionImage();
-    int s      = 400 + 200 * d->sensibilitySlider->value();
+    int s      = d->sensibilityInput->value();
 
     setFilter(dynamic_cast<DImgThreadedFilter*>(new FilmGrain(&image, this, s)));
 }
 
 void FilmGrainTool::prepareFinal()
 {
-    d->sensibilitySlider->setEnabled(false);
+    d->sensibilityInput->setEnabled(false);
+    toolView()->setEnabled(false);    
 
-    int s = 400 + 200 * d->sensibilitySlider->value();
+    int s = d->sensibilityInput->value();
 
     ImageIface iface(0, 0);
 
