@@ -7,8 +7,8 @@
  * Description : a digiKam image editor plugin to process image
  *               free rotation.
  *
- * Copyright (C) 2004-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2004-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -23,7 +23,6 @@
  *
  * ============================================================ */
 
-
 #include "freerotationtool.moc"
 
 // C++ includes
@@ -62,7 +61,7 @@
 #include "editortoolsettings.h"
 #include "freerotation.h"
 #include "imageiface.h"
-#include "imagewidget.h"
+#include "imageguidewidget.h"
 #include "rexpanderbox.h"
 #include "version.h"
 
@@ -113,7 +112,7 @@ public:
 
     RExpanderBox*       expanderBox;
     EditorToolSettings* gboxSettings;
-    ImageWidget*        previewWidget;
+    ImageGuideWidget*   previewWidget;
 
     RComboBox*          autoCropCB;
     RDoubleNumInput*    fineAngleInput;
@@ -128,21 +127,20 @@ FreeRotationTool::FreeRotationTool(QObject* parent)
     setToolName(i18n("Free Rotation"));
     setToolIcon(SmallIcon("freerotation"));
 
-    d->previewWidget = new ImageWidget("freerotation Tool", 0,
-                                       i18n("This is the free rotation operation preview. "
-                                            "If you move the mouse cursor on this preview, "
-                                            "a vertical and horizontal dashed line will be drawn "
-                                            "to guide you in adjusting the free rotation correction. "
-                                            "Release the left mouse button to freeze the dashed "
-                                            "line's position."),
-                                       false, ImageGuideWidget::HVGuideMode);
+    d->previewWidget = new ImageGuideWidget(0, true, ImageGuideWidget::HVGuideMode);
+    d->previewWidget->setWhatsThis(i18n("This is the free rotation operation preview. "
+                                        "If you move the mouse cursor on this preview, "
+                                        "a vertical and horizontal dashed line will be drawn "
+                                        "to guide you in adjusting the free rotation correction. "
+                                        "Release the left mouse button to freeze the dashed "
+                                        "line's position."));
 
     setToolView(d->previewWidget);
 
     // -------------------------------------------------------------
 
     QString temp;
-    Digikam::ImageIface iface(0, 0);
+    ImageIface iface(0, 0);
 
     d->gboxSettings = new EditorToolSettings;
     d->gboxSettings->setTools(EditorToolSettings::ColorGuide);
@@ -372,7 +370,7 @@ void FreeRotationTool::writeSettings()
     KConfigGroup group        = config->group(d->configGroupName);
     group.writeEntry(d->configAutoCropTypeEntry, d->autoCropCB->currentIndex());
     group.writeEntry(d->configAntiAliasingEntry, d->antialiasInput->isChecked());
-    d->previewWidget->writeSettings();
+
     group.sync();
 }
 
@@ -445,8 +443,8 @@ void FreeRotationTool::prepareFinal()
 void FreeRotationTool::putPreviewData(void)
 {
     ImageIface* iface = d->previewWidget->imageIface();
-    int w = iface->previewWidth();
-    int h = iface->previewHeight();
+    int w             = iface->previewWidth();
+    int h             = iface->previewHeight();
 
     DImg imTemp = filter()->getTargetImage().smoothScale(w, h, Qt::KeepAspectRatio);
     DImg imDest( w, h, filter()->getTargetImage().sixteenBit(),
