@@ -7,7 +7,7 @@
  * Description : a digiKam image plugin for fixing dots produced by
  *               hot/stuck/dead pixels from a CCD.
  *
- * Copyright (C) 2005-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2005-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2005-2006 by Unai Garro <ugarro at users dot sourceforge dot net>
  *
  * This program is free software; you can redistribute it
@@ -23,7 +23,6 @@
  *
  * ============================================================ */
 
-
 #include "hotpixelstool.moc"
 
 // Qt includes
@@ -59,7 +58,7 @@
 #include "hotpixelfixer.h"
 #include "imagedialog.h"
 #include "imageiface.h"
-#include "imagepanelwidget.h"
+#include "imageregionwidget.h"
 #include "version.h"
 
 using namespace KDcrawIface;
@@ -98,7 +97,7 @@ public:
     RComboBox*          filterMethodCombo;
 
     BlackFrameListView* blackFrameListView;
-    ImagePanelWidget*   previewWidget;
+    ImageRegionWidget*  previewWidget;
     EditorToolSettings* gboxSettings;
 };
 
@@ -112,11 +111,12 @@ HotPixelsTool::HotPixelsTool(QObject* parent)
 
     // -------------------------------------------------------------
 
-    d->gboxSettings = new EditorToolSettings;
-    d->gboxSettings->setTools(EditorToolSettings::PanIcon);
-
-    // -------------------------------------------------------------
-
+    d->gboxSettings   = new EditorToolSettings;
+    d->gboxSettings->setButtons(EditorToolSettings::Default|
+                                EditorToolSettings::Ok|
+                                EditorToolSettings::Cancel|
+                                EditorToolSettings::Try);
+                                
     QGridLayout* grid = new QGridLayout(d->gboxSettings->plainPage());
 
     QLabel *filterMethodLabel = new QLabel(i18n("Filter:"), d->gboxSettings->plainPage());
@@ -128,8 +128,9 @@ HotPixelsTool::HotPixelsTool(QObject* parent)
     d->filterMethodCombo->setDefaultIndex(HotPixelFixer::QUADRATIC_INTERPOLATION);
 
     d->blackFrameButton = new QPushButton(i18n("Black Frame..."), d->gboxSettings->plainPage());
+    d->blackFrameButton->setIcon(KIcon("document-open"));
     d->blackFrameButton->setWhatsThis(i18n("Use this button to add a new black frame file which will "
-                                          "be used by the hot pixels removal filter.") );
+                                           "be used by the hot pixels removal filter.") );
 
     d->blackFrameListView = new BlackFrameListView(d->gboxSettings->plainPage());
 
@@ -143,14 +144,13 @@ HotPixelsTool::HotPixelsTool(QObject* parent)
     grid->setMargin(d->gboxSettings->spacingHint());
     grid->setSpacing(d->gboxSettings->spacingHint());
 
-    setToolSettings(d->gboxSettings);
-
     // -------------------------------------------------------------
 
-    d->previewWidget = new ImagePanelWidget(470, 350, "hotpixels Tool", d->gboxSettings->panIconView(),
-                                            0, ImagePanelWidget::SeparateViewDuplicate);
+    d->previewWidget = new ImageRegionWidget;
 
+    setToolSettings(d->gboxSettings);
     setToolView(d->previewWidget);
+    setPreviewModeMask(PreviewToolBar::AllPreviewModes);
     init();
 
     // -------------------------------------------------------------
@@ -161,8 +161,8 @@ HotPixelsTool::HotPixelsTool(QObject* parent)
     connect(d->blackFrameButton, SIGNAL(clicked()),
             this, SLOT(slotAddBlackFrame()));
 
-    connect(d->blackFrameListView, SIGNAL(blackFrameSelected(QList<HotPixel>, const KUrl&)),
-            this, SLOT(slotBlackFrame(QList<HotPixel>, const KUrl&)));
+    connect(d->blackFrameListView, SIGNAL(signalBlackFrameSelected(const QList<HotPixel>&, const KUrl&)),
+            this, SLOT(slotBlackFrame(const QList<HotPixel>&, const KUrl&)));
 }
 
 HotPixelsTool::~HotPixelsTool()
@@ -196,7 +196,6 @@ void HotPixelsTool::writeSettings()
     KConfigGroup group        = config->group(d->configGroupName);
     group.writeEntry(d->configLastBlackFrameFileEntry, d->blackFrameURL.url());
     group.writeEntry(d->configFilterMethodEntry,       d->filterMethodCombo->currentIndex());
-    d->previewWidget->writeSettings();
     group.sync();
 }
 
@@ -240,12 +239,14 @@ void HotPixelsTool::renderingFinished()
 {
     d->filterMethodCombo->setEnabled(true);
     d->blackFrameListView->setEnabled(true);
+    toolView()->setEnabled(true);
 }
 
 void HotPixelsTool::prepareEffect()
 {
     d->filterMethodCombo->setEnabled(false);
     d->blackFrameListView->setEnabled(false);
+    toolView()->setEnabled(false);
 
     DImg image              = d->previewWidget->getOriginalRegionImage();
     int interpolationMethod = d->filterMethodCombo->currentIndex();
@@ -253,11 +254,11 @@ void HotPixelsTool::prepareEffect()
     QList<HotPixel> hotPixelsRegion;
     QRect area = d->previewWidget->getOriginalImageRegionToRender();
 
-    for (QList<HotPixel>::Iterator it = d->hotPixelsList.begin() ; it != d->hotPixelsList.end() ; ++it )
+    for (QList<HotPixel>::Iterator it = d->hotPixelsList.begin() ; it != d->hotPixelsList.end() ; ++it)
     {
         HotPixel hp = (*it);
 
-        if ( area.contains( hp.rect ) )
+        if (area.contains( hp.rect ))
         {
            hp.rect.moveTopLeft(QPoint( hp.rect.x()-area.x(), hp.rect.y()-area.y() ));
            hotPixelsRegion.append(hp);
@@ -271,7 +272,8 @@ void HotPixelsTool::prepareFinal()
 {
     d->filterMethodCombo->setEnabled(false);
     d->blackFrameListView->setEnabled(false);
-
+    toolView()->setEnabled(false);
+    
     int interpolationMethod = d->filterMethodCombo->currentIndex();
 
     ImageIface iface(0, 0);
@@ -289,7 +291,7 @@ void HotPixelsTool::putFinalData()
     iface.putOriginalImage(i18n("Hot Pixels Correction"), filter()->getTargetImage().bits());
 }
 
-void HotPixelsTool::slotBlackFrame(QList<HotPixel> hpList, const KUrl& blackFrameURL)
+void HotPixelsTool::slotBlackFrame(const QList<HotPixel>& hpList, const KUrl& blackFrameURL)
 {
     d->blackFrameURL = blackFrameURL;
     d->hotPixelsList = hpList;
@@ -301,7 +303,7 @@ void HotPixelsTool::slotBlackFrame(QList<HotPixel> hpList, const KUrl& blackFram
     for (it = d->hotPixelsList.begin() ; it != d->hotPixelsList.end() ; ++it, ++i)
        pointList.setPoint(i, (*it).rect.center());
 
-    d->previewWidget->setPanIconHighLightPoints(pointList);
+    d->previewWidget->setHighLightPoints(pointList);
 
     slotEffect();
 }
