@@ -7,8 +7,8 @@
  * Description : a digiKam image editor plugin for simulate
  *               infrared film.
  *
- * Copyright (C) 2005-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2005-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -30,12 +30,14 @@
 
 #include "editortool.h"
 
+using namespace Digikam;
+
 namespace DigikamInfraredImagesPlugin
 {
 
 class InfraredToolPriv;
 
-class InfraredTool : public Digikam::EditorToolThreaded
+class InfraredTool : public EditorToolThreaded
 {
     Q_OBJECT
 
@@ -46,7 +48,6 @@ public:
 
 private Q_SLOTS:
 
-    void slotSliderMoved(int);
     void slotResetSettings();
 
 private:
