@@ -37,7 +37,8 @@ class AntiVignetting : public Digikam::DImgThreadedFilter
 public:
 
     explicit AntiVignetting(Digikam::DImg *orgImage, QObject *parent=0, double density=2.0,
-                            double power=1.0, double radius=1.0, int xshift=0, int yshift=0, bool normalize=true);
+                            double power=1.0, double radius=1.0, double xshift=0, double yshift=0, 
+                            bool normalize=true, bool anti=true);
 
     ~AntiVignetting(){};
 
@@ -55,6 +56,13 @@ private:
     double m_density;
     double m_power;
     double m_radius;
+    
+    bool   m_add_vignetting;
+    
+    double         hypothenuse(double x,double y);
+    int            approx(double x);
+    uchar          clamp8bits(double x);
+    unsigned short clamp16bits(double x);
 };
 
 }  // namespace DigikamAntiVignettingImagesPlugin
