@@ -58,7 +58,7 @@
 #include "dimg.h"
 #include "editortoolsettings.h"
 #include "imageiface.h"
-#include "imagepanelwidget.h"
+#include "imageregionwidget.h"
 #include "localcontrast.h"
 #include "rexpanderbox.h"
 #include "version.h"
@@ -174,7 +174,7 @@ public:
 
     RExpanderBox*       expanderBox;
 
-    ImagePanelWidget*   previewWidget;
+    ImageRegionWidget*  previewWidget;
     EditorToolSettings* gboxSettings;
 };
 
@@ -196,9 +196,6 @@ LocalContrastTool::LocalContrastTool(QObject* parent)
                                 EditorToolSettings::SaveAs|
                                 EditorToolSettings::Try);
 
-
-    d->gboxSettings->setTools(EditorToolSettings::PanIcon);
-
     // -------------------------------------------------------------
 
     QGridLayout* grid  = new QGridLayout( d->gboxSettings->plainPage() );
@@ -296,7 +293,7 @@ LocalContrastTool::LocalContrastTool(QObject* parent)
     d->blurInput1->setWhatsThis(i18n("<b>Blur</b>: How strong the image is blurred before combining with the original "
                                      "image and with the tonemapping function."));
 
-    grid2->addWidget(d->stageOne,    0, 0, 1, 1);
+    grid2->addWidget(d->stageOne,    0, 0, 1, 2);
     grid2->addWidget(d->label4,      1, 0, 1, 1);
     grid2->addWidget(d->powerInput1, 1, 1, 1, 1);
     grid2->addWidget(d->label5,      2, 0, 1, 1);
@@ -336,7 +333,7 @@ LocalContrastTool::LocalContrastTool(QObject* parent)
     d->blurInput2->setWhatsThis(i18n("<b>Blur</b>: How strong the image is blurred before combining with the original "
                                      "image and with the tonemapping function."));
 
-    grid3->addWidget(d->stageTwo,    0, 0, 1, 1);
+    grid3->addWidget(d->stageTwo,    0, 0, 1, 2);
     grid3->addWidget(d->label6,      1, 0, 1, 1);
     grid3->addWidget(d->powerInput2, 1, 1, 1, 1);
     grid3->addWidget(d->label7,      2, 0, 1, 1);
@@ -376,7 +373,7 @@ LocalContrastTool::LocalContrastTool(QObject* parent)
     d->blurInput3->setWhatsThis(i18n("<b>Blur</b>: How strong the image is blurred before combining with the original "
                                      "image and with the tonemapping function."));
 
-    grid4->addWidget(d->stageThree,  0, 0, 1, 1);
+    grid4->addWidget(d->stageThree,  0, 0, 1, 2);
     grid4->addWidget(d->label8,      1, 0, 1, 1);
     grid4->addWidget(d->powerInput3, 1, 1, 1, 1);
     grid4->addWidget(d->label9,      2, 0, 1, 1);
@@ -416,7 +413,7 @@ LocalContrastTool::LocalContrastTool(QObject* parent)
     d->blurInput4->setWhatsThis(i18n("<b>Blur</b>: How strong the image is blurred before combining with the original "
                                      "image and with the tonemapping function."));
 
-    grid5->addWidget(d->stageFour,   0, 0, 1, 1);
+    grid5->addWidget(d->stageFour,   0, 0, 1, 2);
     grid5->addWidget(d->label10,     1, 0, 1, 1);
     grid5->addWidget(d->powerInput4, 1, 1, 1, 1);
     grid5->addWidget(d->label11,     2, 0, 1, 1);
@@ -448,10 +445,11 @@ LocalContrastTool::LocalContrastTool(QObject* parent)
     grid->setMargin(d->gboxSettings->spacingHint());
     grid->setSpacing(d->gboxSettings->spacingHint());
 
-    setToolSettings(d->gboxSettings);
+    d->previewWidget = new ImageRegionWidget;
 
-    d->previewWidget = new ImagePanelWidget(470, 350, "localcontrast Tool", d->gboxSettings->panIconView());
+    setToolSettings(d->gboxSettings);
     setToolView(d->previewWidget);
+    setPreviewModeMask(PreviewToolBar::AllPreviewModes);    
 
     init();
 }
@@ -497,6 +495,7 @@ void LocalContrastTool::slotStage4Enabled(bool b)
 void LocalContrastTool::renderingFinished()
 {
     d->expanderBox->setEnabled(true);
+    toolView()->setEnabled(true);
 }
 
 void LocalContrastTool::readSettings()
@@ -557,7 +556,6 @@ void LocalContrastTool::writeSettings()
     group.writeEntry(d->configFunctionInputEntry,   d->functionInput->currentIndex());
     d->expanderBox->writeSettings();
 
-    d->previewWidget->writeSettings();
     group.sync();
 }
 
@@ -632,7 +630,8 @@ ToneMappingParameters *LocalContrastTool::createParams()
 void LocalContrastTool::prepareEffect()
 {
     d->expanderBox->setEnabled(false);
-
+    toolView()->setEnabled(false);
+    
     ToneMappingParameters *par = createParams();
     DImg image                 = d->previewWidget->getOriginalRegionImage();
 
@@ -642,7 +641,8 @@ void LocalContrastTool::prepareEffect()
 void LocalContrastTool::prepareFinal()
 {
     d->expanderBox->setEnabled(false);
-
+    toolView()->setEnabled(false);
+    
     ToneMappingParameters *par = createParams();
 
     ImageIface iface(0, 0);
