@@ -30,7 +30,7 @@
 
 #include "imagecurves.h"
 
-// C++ includes.
+// C++ includes
 
 #include <cstdio>
 #include <cmath>
@@ -38,17 +38,25 @@
 #include <cstdlib>
 #include <cerrno>
 
-// Qt includes.
+// Qt includes
 
 #include <QFile>
 
-// KDE includes.
+// KDE includes
 
 #include <kdebug.h>
 
+// Local includes
+
+#include "globals.h"
+
 namespace Digikam
 {
 
+const int ImageCurves::NUM_POINTS = 17;
+const int ImageCurves::NUM_CHANNELS = 5;
+const int ImageCurves::MULTIPLIER_16BIT = 255;
+
 class ImageCurvesPriv
 {
 
@@ -56,9 +64,18 @@ public:
 
     struct _Curves
     {
-        ImageCurves::CurveType curve_type[5];     // Curve types by channels (Smooth or Free).
-        int                    points[5][17][2];  // Curve main points in Smooth mode ([channel][point id][x,y]).
-        unsigned short         curve[5][65536];   // Curve values by channels.
+        /**
+         * Curve types by channels (Smooth or Free).
+         */
+        ImageCurves::CurveType curve_type[ImageCurves::NUM_CHANNELS];
+        /**
+         * Curve main points in Smooth mode ([channel][point id][x,y])
+         */
+        int                    points[ImageCurves::NUM_CHANNELS][ImageCurves::NUM_POINTS][2];
+        /**
+         * Curve values by channels
+         */
+        unsigned short         curve[ImageCurves::NUM_CHANNELS][NUM_SEGMENTS_16BIT];
     };
 
     struct _Lut
@@ -76,6 +93,11 @@ public:
         dirty  = false;
     }
 
+    bool isPointEnabled(const QPoint &point)
+    {
+        return (point.x() > - 1) && (point.y() > -1);
+    }
+
     // Curves data.
     struct _Curves *curves;
 
@@ -99,8 +121,9 @@ ImageCurves::ImageCurves(bool sixteenBit)
            : d(new ImageCurvesPriv)
 {
     d->lut        = new ImageCurvesPriv::_Lut;
+    d->lut->luts  = NULL;
     d->curves     = new ImageCurvesPriv::_Curves;
-    d->segmentMax = sixteenBit ? 65535 : 255;
+    d->segmentMax = sixteenBit ? MAX_SEGMENT_16BIT : MAX_SEGMENT_8BIT;
 
     curvesReset();
 }
@@ -109,14 +132,7 @@ ImageCurves::~ImageCurves()
 {
     if (d->lut)
     {
-       if (d->lut->luts)
-       {
-          for (int i = 0 ; i < d->lut->nchannels ; i++)
-              delete [] d->lut->luts[i];
-
-          delete [] d->lut->luts;
-       }
-
+       freeLutData();
        delete d->lut;
     }
 
@@ -126,6 +142,95 @@ ImageCurves::~ImageCurves()
     delete d;
 }
 
+void ImageCurves::fillFromOtherCurvers(ImageCurves *otherCurves)
+{
+
+    kDebug() << "Filling this curve from other curve " << otherCurves;
+
+    curvesReset();
+
+    // if the other curves have the same bit depth, simply copy their data
+    if (isSixteenBits() == otherCurves->isSixteenBits())
+    {
+        kDebug() << "Both curves have same type: isSixteenBits = " << isSixteenBits();
+        for (int channel = 0; channel < NUM_CHANNELS; ++channel)
+        {
+            for (int point = 0; point < NUM_POINTS; ++point)
+            {
+                QPoint p = otherCurves->getCurvePoint(channel, point);
+                if (d->isPointEnabled(p))
+                {
+                    setCurvePoint(channel, point, p);
+                }
+            }
+        }
+    }
+    // other curve is 8 bit and this curve is 16 bit
+    else if (isSixteenBits() && !otherCurves->isSixteenBits())
+    {
+        kDebug() << "This curve is 16 bit and the other is 8 bit";
+        for (int channel = 0; channel < NUM_CHANNELS; ++channel)
+        {
+            for (int point = 0; point < NUM_POINTS; ++point)
+            {
+                QPoint p = otherCurves->getCurvePoint(channel, point);
+                if (d->isPointEnabled(p))
+                {
+                    p.setX(p.x() * MULTIPLIER_16BIT);
+                    p.setY(p.y() * MULTIPLIER_16BIT);
+                    setCurvePoint(channel, point, p);
+                }
+            }
+        }
+    }
+    // other curve is 16 bit and this is 8 bit
+    else if (!isSixteenBits() && otherCurves->isSixteenBits())
+    {
+        kDebug() << "This curve is 8 bit and the other is 16 bit";
+        for (int channel = 0; channel < NUM_CHANNELS; ++channel)
+        {
+            kDebug() << "Adopting points of channel " << channel;
+            for (int point = 0; point < NUM_POINTS; ++point)
+            {
+                QPoint p = otherCurves->getCurvePoint(channel, point);
+                kDebug() << "Point " << point << " in original is " << p;
+                if (d->isPointEnabled(p))
+                {
+                    p.setX(p.x() / MULTIPLIER_16BIT);
+                    p.setY(p.y() / MULTIPLIER_16BIT);
+                    kDebug() << "Setting curve point " << point << " to " << p;
+                    setCurvePoint(channel, point, p);
+                }
+                else
+                {
+                    kDebug() << "ignoring this point";
+                }
+            }
+        }
+    }
+    else
+    {
+        kError() << "Bad logic error, could not fill one curve into another";
+    }
+
+    kDebug() << "Updating curve types";
+
+    // adopt channel types
+    for (int channel = 0; channel < NUM_CHANNELS; ++channel)
+    {
+        kDebug() << "Curve type for channel " << channel
+                        << " is " << (int) otherCurves->getCurveType(channel);
+        setCurveType(channel, otherCurves->getCurveType(channel));
+    }
+
+    // invoke calculations once
+    for (int channel = 0; channel < NUM_CHANNELS; ++channel)
+    {
+        curvesCalculateCurve(channel);
+    }
+
+}
+
 bool ImageCurves::isDirty()
 {
     return d->dirty;
@@ -133,17 +238,18 @@ bool ImageCurves::isDirty()
 
 bool ImageCurves::isSixteenBits()
 {
-    return (d->segmentMax == 65535);
+    return (d->segmentMax == MAX_SEGMENT_16BIT);
 }
 
 void ImageCurves::curvesReset()
 {
     memset(d->curves, 0, sizeof(struct ImageCurvesPriv::_Curves));
+    freeLutData();
     d->lut->luts      = NULL;
     d->lut->nchannels = 0;
     d->dirty          = false;
 
-    for (int channel = 0 ; channel < 5 ; channel++)
+    for (int channel = 0 ; channel < NUM_CHANNELS ; ++channel)
     {
        setCurveType(channel, CURVE_SMOOTH);
        curvesChannelReset(channel);
@@ -158,12 +264,12 @@ void ImageCurves::curvesChannelReset(int channel)
 
     // Construct a linear curve.
 
-    for (j = 0 ; j <= d->segmentMax ; j++)
+    for (j = 0 ; j <= d->segmentMax ; ++j)
        d->curves->curve[channel][j] = j;
 
     // Init coordinates points to null.
 
-    for (j = 0 ; j < 17 ; j++)
+    for (j = 0 ; j < ImageCurves::NUM_POINTS ; ++j)
     {
        d->curves->points[channel][j][0] = -1;
        d->curves->points[channel][j][1] = -1;
@@ -173,14 +279,14 @@ void ImageCurves::curvesChannelReset(int channel)
 
     d->curves->points[channel][0][0]  = 0;
     d->curves->points[channel][0][1]  = 0;
-    d->curves->points[channel][16][0] = d->segmentMax;
-    d->curves->points[channel][16][1] = d->segmentMax;
+    d->curves->points[channel][NUM_POINTS - 1][0] = d->segmentMax;
+    d->curves->points[channel][NUM_POINTS - 1][1] = d->segmentMax;
 }
 
 void ImageCurves::curvesCalculateCurve(int channel)
 {
     int i;
-    int points[17];
+    int points[NUM_POINTS];
     int num_pts;
     int p1, p2, p3, p4;
 
@@ -197,7 +303,7 @@ void ImageCurves::curvesCalculateCurve(int channel)
 
           num_pts = 0;
 
-          for (i = 0 ; i < 17 ; i++)
+          for (i = 0 ; i < ImageCurves::NUM_POINTS ; ++i)
              if (d->curves->points[channel][i][0] != -1)
                 points[num_pts++] = i;
 
@@ -205,18 +311,18 @@ void ImageCurves::curvesCalculateCurve(int channel)
 
           if (num_pts != 0)
           {
-             for (i = 0 ; i < d->curves->points[channel][points[0]][0] ; i++)
+             for (i = 0 ; i < d->curves->points[channel][points[0]][0] ; ++i)
              {
                 d->curves->curve[channel][i] = d->curves->points[channel][points[0]][1];
              }
 
-             for (i = d->curves->points[channel][points[num_pts - 1]][0] ; i <= d->segmentMax ; i++)
+             for (i = d->curves->points[channel][points[num_pts - 1]][0] ; i <= d->segmentMax ; ++i)
              {
                 d->curves->curve[channel][i] = d->curves->points[channel][points[num_pts - 1]][1];
              }
           }
 
-          for (i = 0 ; i < num_pts - 1 ; i++)
+          for (i = 0 ; i < num_pts - 1 ; ++i)
           {
              p1 = (i == 0) ? points[i] : points[(i - 1)];
              p2 = points[i];
@@ -228,7 +334,7 @@ void ImageCurves::curvesCalculateCurve(int channel)
 
           // Ensure that the control points are used exactly
 
-          for (i = 0 ; i < num_pts ; i++)
+          for (i = 0 ; i < num_pts ; ++i)
           {
              int x, y;
 
@@ -304,13 +410,13 @@ void ImageCurves::curvesPlotCurve(int channel, int p1, int p2, int p3, int p4)
 
     // Construct the geometry matrix from the segment.
 
-    for (i = 0 ; i < 4 ; i++)
+    for (i = 0 ; i < 4 ; ++i)
     {
        geometry[i][2] = 0;
        geometry[i][3] = 0;
     }
 
-    for (i = 0 ; i < 2 ; i++)
+    for (i = 0 ; i < 2 ; ++i)
     {
        geometry[0][i] = d->curves->points[channel][p1][i];
        geometry[1][i] = d->curves->points[channel][p2][i];
@@ -361,7 +467,7 @@ void ImageCurves::curvesPlotCurve(int channel, int p1, int p2, int p3, int p4)
 
     // Loop over the curve.
 
-    for (i = 0 ; i < loopdiv ; i++)
+    for (i = 0 ; i < loopdiv ; ++i)
     {
        // Increment the x values.
 
@@ -392,9 +498,9 @@ void ImageCurves::curvesCRCompose(CRMatrix a, CRMatrix b, CRMatrix ab)
 {
     int i, j;
 
-    for (i = 0 ; i < 4 ; i++)
+    for (i = 0 ; i < 4 ; ++i)
     {
-       for (j = 0 ; j < 4 ; j++)
+       for (j = 0 ; j < 4 ; ++j)
        {
           ab[i][j] = (a[i][0] * b[0][j] +
                       a[i][1] * b[1][j] +
@@ -410,22 +516,16 @@ void ImageCurves::curvesLutSetup(int nchannels)
     uint   v;
     double val;
 
-    if (d->lut->luts)
-    {
-       for (i = 0 ; i < d->lut->nchannels ; i++)
-           delete [] d->lut->luts[i];
-
-       delete [] d->lut->luts;
-    }
+    freeLutData();
 
     d->lut->nchannels = nchannels;
     d->lut->luts      = new unsigned short*[d->lut->nchannels];
 
-    for (i = 0 ; i < d->lut->nchannels ; i++)
+    for (i = 0 ; i < d->lut->nchannels ; ++i)
     {
        d->lut->luts[i] = new unsigned short[d->segmentMax+1];
 
-       for (v = 0 ; v <= (uint)d->segmentMax ; v++)
+       for (v = 0 ; v <= (uint)d->segmentMax ; ++v)
        {
           // To add gamma correction use func(v ^ g) ^ 1/g instead.
 
@@ -451,13 +551,13 @@ void ImageCurves::curvesLutProcess(uchar *srcPR, uchar *destPR, int w, int h)
     if (d->lut->nchannels > 3)
        lut3 = d->lut->luts[3];
 
-    if (d->segmentMax == 255)        // 8 bits image.
+    if (!isSixteenBits())        // 8 bits image.
     {
         uchar red, green, blue, alpha;
         uchar *ptr = srcPR;
         uchar *dst = destPR;
 
-        for (i = 0 ; i < w*h ; i++)
+        for (i = 0 ; i < w*h ; ++i)
         {
             blue  = ptr[0];
             green = ptr[1];
@@ -491,7 +591,7 @@ void ImageCurves::curvesLutProcess(uchar *srcPR, uchar *destPR, int w, int h)
         unsigned short *ptr = (unsigned short *)srcPR;
         unsigned short *dst = (unsigned short *)destPR;
 
-        for (i = 0 ; i < w*h ; i++)
+        for (i = 0 ; i < w*h ; ++i)
         {
             blue  = ptr[0];
             green = ptr[1];
@@ -524,22 +624,42 @@ void ImageCurves::curvesLutProcess(uchar *srcPR, uchar *destPR, int w, int h)
 int ImageCurves::getCurveValue(int channel, int bin)
 {
     if ( d->curves &&
-         channel>=0 && channel<5 &&
+         channel>=0 && channel<NUM_CHANNELS &&
          bin>=0 && bin<=d->segmentMax )
        return(d->curves->curve[channel][bin]);
 
     return 0;
 }
 
+QPoint ImageCurves::getDisabledValue()
+{
+    return QPoint(-1, -1);
+}
+
+bool ImageCurves::isCurvePointEnabled(int channel, int point) const
+{
+    if (d->curves && channel >= 0 && channel < NUM_CHANNELS
+                    && point >= 0 && point <= NUM_POINTS
+                    && d->curves->points[channel][point][0] >= 0
+                    && d->curves->points[channel][point][1] >= 0)
+    {
+        return true;
+    }
+    else
+    {
+        return false;
+    }
+}
+
 QPoint ImageCurves::getCurvePoint(int channel, int point)
 {
     if ( d->curves &&
-         channel>=0 && channel<5 &&
-         point>=0 && point<=17 )
+         channel>=0 && channel<NUM_CHANNELS &&
+         point>=0 && point<=NUM_POINTS )
        return(QPoint(d->curves->points[channel][point][0],
                      d->curves->points[channel][point][1]) );
 
-    return QPoint(-1, -1);
+    return getDisabledValue();
 }
 
 QPolygon ImageCurves::getCurvePoints(int channel)
@@ -547,9 +667,9 @@ QPolygon ImageCurves::getCurvePoints(int channel)
     QPolygon array(18);
 
     if ( d->curves &&
-         channel>=0 && channel<5)
+         channel>=0 && channel<NUM_CHANNELS)
     {
-        for (int j = 0 ; j <= 17 ; j++)
+        for (int j = 0 ; j <= NUM_POINTS ; ++j)
         array.setPoint(j, getCurvePoint(channel, j));
     }
 
@@ -559,8 +679,8 @@ QPolygon ImageCurves::getCurvePoints(int channel)
 int ImageCurves::getCurvePointX(int channel, int point)
 {
     if ( d->curves &&
-         channel>=0 && channel<5 &&
-         point>=0 && point<=17 )
+         channel>=0 && channel<NUM_CHANNELS &&
+         point>=0 && point<=NUM_POINTS )
        return(d->curves->points[channel][point][0]);
 
     return(-1);
@@ -569,26 +689,26 @@ int ImageCurves::getCurvePointX(int channel, int point)
 int ImageCurves::getCurvePointY(int channel, int point)
 {
     if ( d->curves &&
-         channel>=0 && channel<5 &&
-         point>=0 && point<=17 )
+         channel>=0 && channel<NUM_CHANNELS &&
+         point>=0 && point<=NUM_POINTS )
        return(d->curves->points[channel][point][1]);
 
     return (-1);
 }
 
-int ImageCurves::getCurveType(int channel)
+ImageCurves::CurveType ImageCurves::getCurveType(int channel)
 {
     if ( d->curves &&
-         channel>=0 && channel<5 )
-       return ( d->curves->curve_type[channel] );
+         channel>=0 && channel<NUM_CHANNELS )
+       return ((ImageCurves::CurveType) d->curves->curve_type[channel] );
 
-    return (-1);
+    return CURVE_SMOOTH;
 }
 
 void ImageCurves::setCurveValue(int channel, int bin, int val)
 {
     if ( d->curves &&
-         channel>=0 && channel<5 &&
+         channel>=0 && channel<NUM_CHANNELS &&
          bin>=0 && bin<=d->segmentMax )
     {
        d->dirty = true;
@@ -599,8 +719,8 @@ void ImageCurves::setCurveValue(int channel, int bin, int val)
 void ImageCurves::setCurvePoint(int channel, int point, const QPoint& val)
 {
     if ( d->curves &&
-         channel>=0 && channel<5 &&
-         point>=0 && point<=17 &&
+         channel>=0 && channel<NUM_CHANNELS &&
+         point>=0 && point<=NUM_POINTS &&
          val.x()>=-1 && val.x()<=d->segmentMax && // x can be equal to -1
          val.y()>=0 && val.y()<=d->segmentMax)    // if the current point is disable !!!
     {
@@ -613,11 +733,11 @@ void ImageCurves::setCurvePoint(int channel, int point, const QPoint& val)
 void ImageCurves::setCurvePoints(int channel, const QPolygon& vals)
 {
     if ( d->curves &&
-         channel>=0 && channel<5 &&
+         channel>=0 && channel<NUM_CHANNELS &&
          vals.size() == 18 )
     {
         d->dirty = true;
-        for (int j = 0 ; j <= 17 ; j++)
+        for (int j = 0 ; j <= NUM_POINTS ; ++j)
             setCurvePoint(channel, j, vals.point(j));
     }
 }
@@ -625,8 +745,8 @@ void ImageCurves::setCurvePoints(int channel, const QPolygon& vals)
 void ImageCurves::setCurvePointX(int channel, int point, int x)
 {
     if ( d->curves &&
-         channel>=0 && channel<5 &&
-         point>=0 && point<=17 &&
+         channel>=0 && channel<NUM_CHANNELS &&
+         point>=0 && point<=NUM_POINTS &&
          x>=-1 && x<=d->segmentMax) // x can be equal to -1 if the current point is disable !!!
     {
         d->dirty = true;
@@ -637,8 +757,8 @@ void ImageCurves::setCurvePointX(int channel, int point, int x)
 void ImageCurves::setCurvePointY(int channel, int point, int y)
 {
     if ( d->curves &&
-         channel>=0 && channel<5 &&
-         point>=0 && point<=17 &&
+         channel>=0 && channel<NUM_CHANNELS &&
+         point>=0 && point<=NUM_POINTS &&
          y>=0 && y<=d->segmentMax)
     {
          d->dirty = true;
@@ -649,12 +769,20 @@ void ImageCurves::setCurvePointY(int channel, int point, int y)
 void ImageCurves::setCurveType(int channel, CurveType type)
 {
     if ( d->curves &&
-         channel>=0 && channel<5 &&
+         channel>=0 && channel<NUM_CHANNELS &&
          type>=CURVE_SMOOTH && type<=CURVE_FREE )
        d->curves->curve_type[channel] = type;
 }
 
-bool ImageCurves::loadCurvesFromGimpCurvesFile(const KUrl &fileUrl)
+void ImageCurves::setCurveType(ImageCurves::CurveType type)
+{
+    for (int channel = 0; channel < NUM_CHANNELS; ++channel)
+    {
+        setCurveType(channel, type);
+    }
+}
+
+bool ImageCurves::loadCurvesFromGimpCurvesFile(const KUrl& fileUrl)
 {
     // TODO : support KUrl !
 
@@ -662,10 +790,10 @@ bool ImageCurves::loadCurvesFromGimpCurvesFile(const KUrl &fileUrl)
     int   i, j;
     int   fields;
     char  buf[50];
-    int   index[5][17];
-    int   value[5][17];
+    int   index[NUM_CHANNELS][NUM_POINTS];
+    int   value[NUM_CHANNELS][NUM_POINTS];
 
-    file = fopen(QFile::encodeName(fileUrl.path()), "r");
+    file = fopen(QFile::encodeName(fileUrl.toLocalFile()), "r");
     if (!file)
        return false;
 
@@ -678,14 +806,14 @@ bool ImageCurves::loadCurvesFromGimpCurvesFile(const KUrl &fileUrl)
     if (strcmp (buf, "# GIMP Curves File\n") != 0)
        return false;
 
-    for (i = 0 ; i < 5 ; i++)
+    for (i = 0 ; i < NUM_CHANNELS ; ++i)
     {
-       for (j = 0 ; j < 17 ; j++)
+       for (j = 0 ; j < NUM_POINTS ; ++j)
        {
           fields = fscanf (file, "%d %d ", &index[i][j], &value[i][j]);
           if (fields != 2)
           {
-             kWarning(50003) <<  "Invalid Gimp curves file!" << endl;
+             kWarning() <<  "Invalid Gimp curves file!";
              fclose(file);
              return false;
           }
@@ -694,27 +822,27 @@ bool ImageCurves::loadCurvesFromGimpCurvesFile(const KUrl &fileUrl)
 
     curvesReset();
 
-    for (i = 0 ; i < 5 ; i++)
+    for (i = 0 ; i < NUM_CHANNELS ; ++i)
     {
        d->curves->curve_type[i] = CURVE_SMOOTH;
 
-       for (j = 0 ; j < 17 ; j++)
+       for (j = 0 ; j < NUM_POINTS ; ++j)
        {
-          d->curves->points[i][j][0] = ((d->segmentMax == 65535) && (index[i][j] !=-1) ?
-                                         index[i][j]*255 : index[i][j]);
-          d->curves->points[i][j][1] = ((d->segmentMax == 65535) && (value[i][j] !=-1) ?
-                                         value[i][j]*255 : value[i][j]);
+          d->curves->points[i][j][0] = (isSixteenBits() && (index[i][j] !=-1) ?
+                                         index[i][j]*MULTIPLIER_16BIT : index[i][j]);
+          d->curves->points[i][j][1] = (isSixteenBits() && (value[i][j] !=-1) ?
+                                         value[i][j]*MULTIPLIER_16BIT : value[i][j]);
        }
     }
 
-    for (i = 0 ; i < 5 ; i++)
+    for (i = 0 ; i < NUM_CHANNELS ; ++i)
        curvesCalculateCurve(i);
 
     fclose(file);
     return true;
 }
 
-bool ImageCurves::saveCurvesToGimpCurvesFile(const KUrl &fileUrl)
+bool ImageCurves::saveCurvesToGimpCurvesFile(const KUrl& fileUrl)
 {
     // TODO : support KUrl !
 
@@ -722,18 +850,18 @@ bool ImageCurves::saveCurvesToGimpCurvesFile(const KUrl &fileUrl)
     int   i, j;
     int   index;
 
-    file = fopen(QFile::encodeName(fileUrl.path()), "w");
+    file = fopen(QFile::encodeName(fileUrl.toLocalFile()), "w");
 
     if (!file)
        return false;
 
-    for (i = 0 ; i < 5 ; i++)
+    for (i = 0 ; i < NUM_CHANNELS ; ++i)
     {
        if (d->curves->curve_type[i] == CURVE_FREE)
        {
           //  Pick representative points from the curve and make them control points.
 
-          for (j = 0 ; j <= 8 ; j++)
+          for (j = 0 ; j <= 8 ; ++j)
           {
              index = CLAMP(j * 32, 0, d->segmentMax);
              d->curves->points[i][j * 2][0] = index;
@@ -744,15 +872,15 @@ bool ImageCurves::saveCurvesToGimpCurvesFile(const KUrl &fileUrl)
 
     fprintf (file, "# GIMP Curves File\n");
 
-    for (i = 0 ; i < 5 ; i++)
+    for (i = 0 ; i < NUM_CHANNELS ; ++i)
     {
-       for (j = 0 ; j < 17 ; j++)
+       for (j = 0 ; j < NUM_POINTS ; ++j)
        {
           fprintf (file, "%d %d ",
-                   ((d->segmentMax == 65535) && (d->curves->points[i][j][0]!=-1) ?
-                     d->curves->points[i][j][0]/255 : d->curves->points[i][j][0]),
-                   ((d->segmentMax == 65535) && (d->curves->points[i][j][1]!=-1) ?
-                     d->curves->points[i][j][1]/255 : d->curves->points[i][j][1]));
+                   (isSixteenBits() && (d->curves->points[i][j][0]!=-1) ?
+                     d->curves->points[i][j][0]/MULTIPLIER_16BIT : d->curves->points[i][j][0]),
+                   (isSixteenBits() && (d->curves->points[i][j][1]!=-1) ?
+                     d->curves->points[i][j][1]/MULTIPLIER_16BIT : d->curves->points[i][j][1]));
 
           fprintf (file, "\n");
        }
@@ -764,4 +892,16 @@ bool ImageCurves::saveCurvesToGimpCurvesFile(const KUrl &fileUrl)
     return true;
 }
 
+void ImageCurves::freeLutData()
+{
+    if (d->lut->luts)
+    {
+        for (int i = 0 ; i < d->lut->nchannels ; ++i)
+        {
+            delete [] d->lut->luts[i];
+        }
+        delete [] d->lut->luts;
+    }
+}
+
 }  // namespace Digikam
