@@ -26,7 +26,7 @@
 #ifndef ALBUMDB_H
 #define ALBUMDB_H
 
-// Qt includes.
+// Qt includes
 
 #include <QtCore/QString>
 #include <QtCore/QList>
@@ -36,11 +36,11 @@
 #include <QtCore/QMap>
 #include <QtCore/QUuid>
 
-// KDE includes.
+// KDE includes
 
 #include <kurl.h>
 
-// Local includes.
+// Local includes
 
 #include "albuminfo.h"
 #include "databasefields.h"
@@ -92,25 +92,25 @@ public:
     /**
      * Sets the main filter settings of the database. Should only be called at schema update.
      */
-    void setFilterSettings(const QStringList &imageFilter, const QStringList &videoFilter, const QStringList &audioFilter);
+    void setFilterSettings(const QStringList& imageFilter, const QStringList& videoFilter, const QStringList& audioFilter);
 
     /**
      * Sets the user-configurable filter settings. The lists shall be as specified for getFilterSettings.
      * They may include entries starting with "-", which indicates that this format shall be removed from
      * the list, if it is included in the main settings list.
      */
-    void setUserFilterSettings(const QStringList &imageFilter, const QStringList &videoFilter, const QStringList &audioFilter);
+    void setUserFilterSettings(const QStringList& imageFilter, const QStringList& videoFilter, const QStringList& audioFilter);
 
     /**
      * Sets the user-configurable filter settings. The strings shall be lists joined either by ";" or " ".
      * Extra whitespace, dots and wildcard characters (*.) are removed.
      */
-    void setUserFilterSettings(const QString &imageFilterString, const QString &videoFilterString, const QString &audioFilterString);
+    void setUserFilterSettings(const QString& imageFilterString, const QString& videoFilterString, const QString& audioFilterString);
 
     /**
      * Adds the given filters to the user image filter settings
      */
-    void addToUserImageFilterSettings(const QString &filterString);
+    void addToUserImageFilterSettings(const QString& filterString);
 
     /**
      * Returns a UUID for the database file.
@@ -129,14 +129,11 @@ public:
     /**
      * Add a new album to the database with the given attributes
      * @param type The type of the album root
-     * @param absolutePath The last absolute path in the file system.
-     *                     The usage of this parameter is up to the CollectionManager
-     * @param uuid         The volume UUID of the volume this album root is contained on.
      * @param specificPath The path specific to volume
      * @param label        An (optional) user-visible label
      * @returns the album root id of the newly created root
      */
-    int addAlbumRoot(AlbumRoot::Type type, const QString &identifier, const QString &specificPath, const QString &label);
+    int addAlbumRoot(AlbumRoot::Type type, const QString& identifier, const QString& specificPath, const QString& label);
 
     /**
      * Deletes an album  root from the database.
@@ -144,11 +141,19 @@ public:
      */
     void deleteAlbumRoot(int rootId);
 
+    /**
+     * Migrates a given album root to a new disk location. This only changes the values
+     * in the AlbumRoots table. It is expected that this merely reflects underlying partition changes,
+     * still pointing to the same data.
+     */
+    void migrateAlbumRoot(int rootId, const QString& identifier);
+
     /**
      * Changes the label of the specified album root
      * @param rootId the id of the album root
+     * @param newLabel new label for the album root
      */
-    void setAlbumRootLabel(int rootId, const QString &newLabel);
+    void setAlbumRootLabel(int rootId, const QString& newLabel);
 
     /**
      * Sets the type of the specified album root to a new value.
@@ -211,7 +216,7 @@ public:
      */
     int  getAlbumForPath(int albumRootId, const QString& relativePath, bool create = true);
 
-    //int  getAlbumForPath(const QString &albumRoot, const QString& relativePath, bool create = true);
+    //int  getAlbumForPath(const QString& albumRoot, const QString& relativePath, bool create = true);
 
     /**
      * Find out the album ids for a given relative path, including the subalbums.
@@ -226,7 +231,7 @@ public:
      * @param onlyDirectSubalbums if this is true, only first-level subalbums are returned,
      *                            if false, all levels of children are returned (include subalbums of subalbums).
      */
-    //QStringList getSubalbumsForPath(const QString &albumRoot, const QString& path, bool onlyDirectSubalbums = true);
+    //QStringList getSubalbumsForPath(const QString& albumRoot, const QString& path, bool onlyDirectSubalbums = true);
 
     /**
      * Find out all album ids of a given album root
@@ -371,7 +376,7 @@ public:
      * @param create create new tags if necessary
      * @returns a list of albumIDs of the tags in tagPaths
      */
-    QList<int> getTagsFromTagPaths(const QStringList &tagPaths, bool create);
+    QList<int> getTagsFromTagPaths(const QStringList& tagPaths, bool create);
 
     /**
      * Get a list of recently assigned tags (only last 6 tags are listed)
@@ -428,20 +433,21 @@ public:
 
     /**
      * Add a new search to the database with the given attributes
+     * @param type       search type
      * @param name       name of the search
-     * @param url        url of the search
+     * @param query      search query to use
      * @return the id of the album added or -1 if it failed
      */
-    int addSearch(DatabaseSearch::Type type, const QString& name, const QString &query);
+    int addSearch(DatabaseSearch::Type type, const QString& name, const QString& query);
 
     /**
      * Updates Search with new attributes
      * @param searchID   the id of the search
-     * @param name       name of the search
-     * @param url        url of the search
+     * @param type       type of the search
+     * @param query      database query of the search
      */
     void updateSearch(int searchID, DatabaseSearch::Type type,
-                      const QString& name, const QString &query);
+                      const QString& name, const QString& query);
 
     /**
      * Delete a search from the database.
@@ -519,7 +525,7 @@ public:
 
     /**
      * Get the imageId of the item
-     * @param albumId the albumID of the item
+     * @param albumID the albumID of the item
      * @param name the name of the item
      * @return the ImageId for the item, or -1 if it does not exist
      */
@@ -542,7 +548,7 @@ public:
      * @param recursive perform a recursive folder hierarchy parsing
      * @return It returns a QStringList with the filenames.
      */
-    QStringList getItemNamesInAlbum(int albumID, bool recurssive=false);
+    QStringList getItemNamesInAlbum(int albumID, bool recursive=false);
 
     /**
      * Returns an ItemScanInfo object for each item in the album
@@ -554,6 +560,7 @@ public:
      * Given a albumID, get a list of the url of all items in the album
      * NOTE: Uses the CollectionManager
      * @param  albumID the id of the album
+     * @param  order   order for the returned items to use
      * @return a list of urls for the items in the album. The urls are the
      * absolute path of the items
      */
@@ -625,6 +632,11 @@ public:
      */
     ItemShortInfo getItemShortInfo(qlonglong imageID);
 
+    /**
+     * Get item and album if from albumRootId, album path and file name.
+     */
+    ItemShortInfo getItemShortInfo(int albumRootId, const QString& relativePath, const QString& name);
+
     /**
      * Get scan info from the image ID
      */
@@ -672,7 +684,7 @@ public:
      * You can leave out entries from this list, which will then be filled with null values.
      * Indicate the values that you have passed in the ImageInformation flag in the third parameters.
      */
-    void addImageInformation(qlonglong imageID, const QVariantList &infos,
+    void addImageInformation(qlonglong imageID, const QVariantList& infos,
                              DatabaseFields::ImageInformation fields = DatabaseFields::ImageInformationAll);
 
     /**
@@ -681,7 +693,7 @@ public:
      * This method does nothing if the item does not yet have an entry in the ImageInformation table.
      * The parameters are as for the method above.
      */
-    void changeImageInformation(qlonglong imageID, const QVariantList &infos,
+    void changeImageInformation(qlonglong imageID, const QVariantList& infos,
                                 DatabaseFields::ImageInformation fields = DatabaseFields::ImageInformationAll);
 
     /**
@@ -714,7 +726,7 @@ public:
      * You can leave out entries from this list. Indicate the values that you have
      * passed in the ImageMetadata flag in the third parameters.
      */
-    void addImageMetadata(qlonglong imageID, const QVariantList &infos,
+    void addImageMetadata(qlonglong imageID, const QVariantList& infos,
                            DatabaseFields::ImageMetadata fields = DatabaseFields::ImageMetadataAll);
 
     /**
@@ -722,7 +734,7 @@ public:
      * This method does nothing if the item does not yet have an entry in the ImageInformation table.
      * The parameters are as for the method above.
      */
-    void changeImageMetadata(qlonglong imageID, const QVariantList &infos,
+    void changeImageMetadata(qlonglong imageID, const QVariantList& infos,
                              DatabaseFields::ImageMetadata fields = DatabaseFields::ImageMetadataAll);
 
     /**
@@ -748,7 +760,7 @@ public:
      * You can leave out entries from this list. Indicate the values that you have
      * passed in the ImageInfo flag in the third parameters.
      */
-    void addImagePosition(qlonglong imageID, const QVariantList &infos,
+    void addImagePosition(qlonglong imageID, const QVariantList& infos,
                            DatabaseFields::ImagePositions fields = DatabaseFields::ImagePositionsAll);
 
     /**
@@ -756,7 +768,7 @@ public:
      * This method does nothing if the item does not yet have an entry in the ImageInformation table.
      * The parameters are as for the method above.
      */
-    void changeImagePosition(qlonglong imageID, const QVariantList &infos,
+    void changeImagePosition(qlonglong imageID, const QVariantList& infos,
                              DatabaseFields::ImagePositions fields = DatabaseFields::ImagePositionsAll);
 
     /**
@@ -780,7 +792,7 @@ public:
      * source, language and author will be overwritten.
      * @param imageID  The imageID of the image
      * @param comment  The comment string
-     * @param source   The source of the comment
+     * @param type     The type of the comment
      * @param language Information about the language of the comment. A null string shall be used
      *                 if language information is not available from the source, or if
      *                 the comment is in the default language.
@@ -790,9 +802,9 @@ public:
      *                 If not supported by the source, pass a null string.
      * @returns the comment ID of the comment
      */
-    int setImageComment(qlonglong imageID, const QString &comment, DatabaseComment::Type type,
-                        const QString &language = QString(), const QString &author = QString(),
-                        const QDateTime &date = QDateTime());
+    int setImageComment(qlonglong imageID, const QString& comment, DatabaseComment::Type type,
+                        const QString& language = QString(), const QString& author = QString(),
+                        const QDateTime& date = QDateTime());
 
     /**
      * Changes the properties of a comment.
@@ -803,7 +815,7 @@ public:
      * 3) DateTime  Date
      * 4) String    Comment
      */
-    void changeImageComment(int commentId, qlonglong imageID, const QVariantList &infos,
+    void changeImageComment(int commentId, qlonglong imageID, const QVariantList& infos,
                             DatabaseFields::ImageComments fields = DatabaseFields::ImageCommentsAll);
 
 
@@ -815,18 +827,19 @@ public:
     /**
      * Returns the property with the specified name for the specified image
      */
-    QString getImageProperty(qlonglong imageID, const QString &property);
+    QString getImageProperty(qlonglong imageID, const QString& property);
 
     /**
      * Sets the property with the given name for the given image to the specified value
      */
-    void setImageProperty(qlonglong imageID, const QString &property, const QString &value);
+    void setImageProperty(qlonglong imageID, const QString& property, const QString& value);
+    void removeImageProperty(qlonglong imageID, const QString& property);
 
     /**
      * Returns the copyright properties of the specified image.
      * If property is not null, only the given property is returned.
      */
-    QList<CopyrightInfo> getImageCopyright(qlonglong imageID, const QString &property = QString());
+    QList<CopyrightInfo> getImageCopyright(qlonglong imageID, const QString& property = QString());
 
     /**
      * Sets the property with the given name for the given image to the specified value and extraValue
@@ -837,10 +850,18 @@ public:
         PropertyExtraValueUnique,
         PropertyNoConstraint
     };
-    void setImageCopyrightProperty(qlonglong imageID, const QString &property,
-                                   const QString &value, const QString &extraValue = QString(),
+    void setImageCopyrightProperty(qlonglong imageID, const QString& property,
+                                   const QString& value, const QString& extraValue = QString(),
                                    CopyrightPropertyUnique uniqueness = PropertyUnique);
 
+    /** Removes copyright properties for the given image id. All values after the first null value,
+     *  in order of parameters, are treated as wild cards (you can give value as wildcard; value and
+     *  extraValue; or property, extraValue and value).
+     *  Note that extraValue is ordered before value in this method!
+     */
+    void removeImageCopyrightProperties(qlonglong imageID, const QString& property = QString(),
+                                        const QString& extraValue = QString(),
+                                        const QString& value = QString() /* NOTE parameter order */);
     /**
      * Returns if there are valid entries in the ImageHaarMatrix table.
      * Returns false if the table is empty.
@@ -981,8 +1002,9 @@ public:
     /**
      * Remove all tags for the item
      * @param imageID the ID of the item
+     * @param currentTagIds the current tags ids assigned to the item
      */
-    void removeItemAllTags(qlonglong imageID);
+    void removeItemAllTags(qlonglong imageID, QList<int> currentTagIds);
 
     /**
      * Remove each tag from a list of tags
@@ -1026,6 +1048,12 @@ public:
      */
     QMap<int, int> getNumberOfImagesInTags();
 
+    /**
+     * Returns a QMap<QString,int> of ImageInformation.format
+     * -> count of items with that format.
+     */
+    QMap<QString,int> getImageFormatStatistics();
+
     // ----------- Moving and Copying Items -----------
 
     /**
@@ -1064,13 +1092,13 @@ public:
      * Search for the specified fingerprint in the download history table.
      * Returns the id of the entry, or -1 if not found.
      */
-    int findInDownloadHistory(const QString &identifier, const QString &name, int fileSize, const QDateTime &date);
+    int findInDownloadHistory(const QString& identifier, const QString& name, int fileSize, const QDateTime& date);
 
     /**
      * Add the specified fingerprint to the download history table.
      * Returns the id of the entry.
      */
-    int addToDownloadHistory(const QString &identifier, const QString &name, int fileSize, const QDateTime &date);
+    int addToDownloadHistory(const QString& identifier, const QString& name, int fileSize, const QDateTime& date);
 
     // ----------- Static helper methods for constructing SQL queries -----------
 
@@ -1079,7 +1107,7 @@ public:
     static QStringList imageMetadataFieldList(DatabaseFields::ImageMetadata fields);
     static QStringList imagePositionsFieldList(DatabaseFields::ImagePositions fields);
     static QStringList imageCommentsFieldList(DatabaseFields::ImageComments fields);
-    static void addBoundValuePlaceholders(QString &query, int count);
+    static void addBoundValuePlaceholders(QString& query, int count);
 
 private:
 
