@@ -23,13 +23,13 @@
 
 #include "collectionmanager.h"
 
-// Qt includes.
+// Qt includes
 
 #include <QCoreApplication>
 #include <QDir>
 #include <QThread>
 
-// KDE includes.
+// KDE includes
 
 #include <kdebug.h>
 #include <kglobal.h>
@@ -45,7 +45,7 @@
 #include <solid/predicate.h>
 
 
-// Local includes.
+// Local includes
 
 #include "databaseaccess.h"
 #include "databasechangesets.h"
@@ -68,14 +68,14 @@ public:
 
     AlbumRootLocation(const AlbumRootInfo &info)
     {
-        kDebug(50003) << "Creating new Location " << info.specificPath << " uuid " << info.identifier << endl;
+        kDebug() << "Creating new Location " << info.specificPath << " uuid " << info.identifier;
         m_id         = info.id;
         m_type       = (Type)info.type;
         specificPath = info.specificPath;
         identifier   = info.identifier;
         m_label      = info.label;
 
-        m_path       = QString();
+        m_path.clear();
 
         setStatus((CollectionLocation::Status)info.status);
     }
@@ -149,6 +149,7 @@ class SolidVolumeInfo
 
 public:
 
+    QString udi;  // Solid device UDI of the StorageAccess device
     QString path; // mount path of volume, with trailing slash
     QString uuid; // UUID as from Solid
     QString label; // volume label (think of CDs)
@@ -170,6 +171,7 @@ public:
 
     QMap<int, AlbumRootLocation *> locations;
     bool changingDB;
+    QStringList udisToWatch;
 
     // hack for Solid's threading problems
     QList<SolidVolumeInfo> actuallyListVolumes();
@@ -190,16 +192,16 @@ public:
      *  Find from a given list (usually the result of listVolumes) the volume
      *  on which the file path specified by the url is located.
      */
-    SolidVolumeInfo findVolumeForUrl(const KUrl &url, const QList<SolidVolumeInfo> volumes);
+    SolidVolumeInfo findVolumeForUrl(const KUrl &fileUrl, const QList<SolidVolumeInfo> volumes);
 
     /// Create the volume identifier for the given volume info
     static QString volumeIdentifier(const SolidVolumeInfo &info);
 
     /// Create a volume identifier based on the path only
-    QString volumeIdentifier(const QString &path);
+    QString volumeIdentifier(const QString& path);
 
     /// Create a network share identifier based on the mountpath
-    QString networkShareIdentifier(const QString &path);
+    QString networkShareIdentifier(const QString& path);
 
     /// Return the path, if location has a path-only identifier. Else returns a null string.
     QString pathFromIdentifier(const AlbumRootLocation *location);
@@ -208,10 +210,13 @@ public:
     QString networkShareMountPathFromIdentifier(const AlbumRootLocation *location);
 
     /// Create an MD5 hash of the top-level entries (file names, not file content) of the given path
-    static QString directoryHash(const QString &path);
+    static QString directoryHash(const QString& path);
 
     /// Check if a location for specified path exists, assuming the given list of locations was deleted
-    bool checkIfExists(const QString &path, QList<CollectionLocation> assumeDeleted);
+    bool checkIfExists(const QString& path, QList<CollectionLocation> assumeDeleted);
+
+    /// Make a user presentable description, regardless of current location status
+    QString technicalDescription(const AlbumRootLocation *location);
 
     CollectionManager *s;
 };
@@ -275,18 +280,29 @@ QList<SolidVolumeInfo> CollectionManagerPrivate::actuallyListVolumes()
 {
     QList<SolidVolumeInfo> volumes;
 
-    kDebug(50003) << "listFromType" << endl;
+    //kDebug() << "listFromType";
     QList<Solid::Device> devices = Solid::Device::listFromType(Solid::DeviceInterface::StorageAccess);
-    kDebug(50003) << "got listFromType" << endl;
+    //kDebug() << "got listFromType";
 
-    foreach(const Solid::Device &accessDevice, devices)
+    udisToWatch.clear();
+
+    foreach(const Solid::Device& accessDevice, devices)
     {
         // check for StorageAccess
         if (!accessDevice.is<Solid::StorageAccess>())
             continue;
 
+        // mark as a device of principal interest
+        udisToWatch << accessDevice.udi();
+
         const Solid::StorageAccess *access = accessDevice.as<Solid::StorageAccess>();
 
+        // watch mount status (remove previous connections)
+        QObject::disconnect(access, SIGNAL(accessibilityChanged(bool, const QString&)),
+                            s, SLOT(accessibilityChanged(bool, const QString&)));
+        QObject::connect(access, SIGNAL(accessibilityChanged(bool, const QString&)),
+                         s, SLOT(accessibilityChanged(bool, const QString&)));
+
         if (!access->isAccessible())
             continue;
 
@@ -321,13 +337,14 @@ QList<SolidVolumeInfo> CollectionManagerPrivate::actuallyListVolumes()
         Solid::StorageVolume *volume = volumeDevice.as<Solid::StorageVolume>();
 
         SolidVolumeInfo info;
+        info.udi = accessDevice.udi();
         info.path = access->filePath();
         info.isMounted = access->isAccessible();
         if (!info.path.isEmpty() && !info.path.endsWith('/'))
             info.path += '/';
         info.uuid = volume->uuid();
         info.label = volume->label();
-        info.isRemovable = drive->isRemovable();
+        info.isRemovable = drive->isHotpluggable() || drive->isRemovable();
         info.isOpticalDisc = volumeDevice.is<Solid::OpticalDisc>();
 
         volumes << info;
@@ -336,7 +353,7 @@ QList<SolidVolumeInfo> CollectionManagerPrivate::actuallyListVolumes()
     return volumes;
 }
 
-QString CollectionManagerPrivate::volumeIdentifier(const SolidVolumeInfo &volume)
+QString CollectionManagerPrivate::volumeIdentifier(const SolidVolumeInfo& volume)
 {
     KUrl url;
     url.setProtocol("volumeid");
@@ -364,7 +381,7 @@ QString CollectionManagerPrivate::volumeIdentifier(const SolidVolumeInfo &volume
     return url.url();
 }
 
-QString CollectionManagerPrivate::volumeIdentifier(const QString &path)
+QString CollectionManagerPrivate::volumeIdentifier(const QString& path)
 {
     KUrl url;
     url.setProtocol("volumeid");
@@ -372,7 +389,7 @@ QString CollectionManagerPrivate::volumeIdentifier(const QString &path)
     return url.url();
 }
 
-QString CollectionManagerPrivate::networkShareIdentifier(const QString &path)
+QString CollectionManagerPrivate::networkShareIdentifier(const QString& path)
 {
     KUrl url;
     url.setProtocol("networkshareid");
@@ -400,14 +417,14 @@ QString CollectionManagerPrivate::networkShareMountPathFromIdentifier(const Albu
     return url.queryItem("mountpath");
 }
 
-QString CollectionManagerPrivate::directoryHash(const QString &path)
+QString CollectionManagerPrivate::directoryHash(const QString& path)
 {
     QDir dir(path);
     if (dir.isReadable())
     {
         QStringList entries = dir.entryList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot);
         KMD5 hash;
-        foreach (const QString &entry, entries)
+        foreach (const QString& entry, entries)
         {
             hash.update(entry.toUtf8());
         }
@@ -426,9 +443,9 @@ SolidVolumeInfo CollectionManagerPrivate::findVolumeForLocation(const AlbumRootL
 
     if (!(queryItem = url.queryItem("uuid")).isNull())
     {
-        foreach (const SolidVolumeInfo &volume, volumes)
+        foreach (const SolidVolumeInfo& volume, volumes)
         {
-            if (volume.uuid == queryItem)
+            if (volume.uuid.compare(queryItem, Qt::CaseInsensitive) == 0)
                 return volume;
         }
         return SolidVolumeInfo();
@@ -440,7 +457,7 @@ SolidVolumeInfo CollectionManagerPrivate::findVolumeForLocation(const AlbumRootL
 
         // find all available volumes with the given label (usually one)
         QList<SolidVolumeInfo> candidateVolumes;
-        foreach (const SolidVolumeInfo &volume, volumes)
+        foreach (const SolidVolumeInfo& volume, volumes)
         {
             if (volume.label == queryItem)
                 candidateVolumes << volume;
@@ -476,13 +493,13 @@ SolidVolumeInfo CollectionManagerPrivate::findVolumeForLocation(const AlbumRootL
             // bail out if not provided
             if (dirHash.isNull())
             {
-                kDebug(50003) << "No directory hash specified for the non-unique Label"
-                         << queryItem << "Resorting to returning the first match." << endl;
+                kDebug() << "No directory hash specified for the non-unique Label"
+                         << queryItem << "Resorting to returning the first match.";
                 return candidateVolumes.first();
             }
 
             // match against directory hash
-            foreach (const SolidVolumeInfo &volume, candidateVolumes)
+            foreach (const SolidVolumeInfo& volume, candidateVolumes)
             {
                 QString volumeDirHash = directoryHash(volume.path);
                 if (volumeDirHash == dirHash)
@@ -493,7 +510,7 @@ SolidVolumeInfo CollectionManagerPrivate::findVolumeForLocation(const AlbumRootL
     }
     else if (!(queryItem = url.queryItem("mountpath")).isNull())
     {
-        foreach (const SolidVolumeInfo &volume, volumes)
+        foreach (const SolidVolumeInfo& volume, volumes)
         {
             if (volume.isMounted && volume.path == queryItem)
                 return volume;
@@ -504,15 +521,53 @@ SolidVolumeInfo CollectionManagerPrivate::findVolumeForLocation(const AlbumRootL
     return SolidVolumeInfo();
 }
 
-SolidVolumeInfo CollectionManagerPrivate::findVolumeForUrl(const KUrl &url, const QList<SolidVolumeInfo> volumes)
+QString CollectionManagerPrivate::technicalDescription(const AlbumRootLocation *albumLoc)
+{
+    KUrl url(albumLoc->identifier);
+    QString queryItem;
+
+    if (url.protocol() == "volumeid")
+    {
+        if (!(queryItem = url.queryItem("uuid")).isNull())
+        {
+            return i18nc("\"relative path\" on harddisk partition with \"UUID\"",
+                         "Folder \"%1\" on the volume with the id \"%2\"",
+                         albumLoc->specificPath, queryItem);
+        }
+        else if (!(queryItem = url.queryItem("label")).isNull())
+        {
+            return i18nc("\"relative path\" on harddisk partition with \"label\"",
+                         "Folder \"%1\" on the volume labeled \"%2\"",
+                         albumLoc->specificPath, queryItem);
+        }
+        else if (!(queryItem = url.queryItem("mountpath")).isNull())
+        {
+            return QString("\"%1\"").arg(queryItem);
+        }
+    }
+    else if (url.protocol() == "networkshareid")
+    {
+        return QString();
+
+        if (!(queryItem =  url.queryItem("mountpath")).isNull())
+        {
+            return QString("\"%1\"").arg(queryItem);
+        }
+    }
+
+    return QString();
+}
+
+SolidVolumeInfo CollectionManagerPrivate::findVolumeForUrl(const KUrl& fileUrl, const QList<SolidVolumeInfo> volumes)
 {
     SolidVolumeInfo volume;
-    QString path = url.path(KUrl::RemoveTrailingSlash);
+    // v.path is specified to have a trailing slash. path needs one as well.
+    QString path = fileUrl.toLocalFile(KUrl::AddTrailingSlash);
     int volumeMatch = 0;
 
     //FIXME: Network shares! Here we get only the volume of the mount path...
     // This is probably not really clean. But Solid does not help us.
-    foreach (const SolidVolumeInfo &v, volumes)
+    foreach (const SolidVolumeInfo& v, volumes)
     {
         if (v.isMounted && !v.path.isEmpty() && path.startsWith(v.path))
         {
@@ -527,23 +582,30 @@ SolidVolumeInfo CollectionManagerPrivate::findVolumeForUrl(const KUrl &url, cons
 
     if (!volumeMatch)
     {
-        kError(50003) << "Failed to detect a storage volume for path " << path << " with Solid" << endl;
+        kError() << "Failed to detect a storage volume for path " << path << " with Solid";
     }
 
     return volume;
 }
 
-bool CollectionManagerPrivate::checkIfExists(const QString &filePath, QList<CollectionLocation> assumeDeleted)
+bool CollectionManagerPrivate::checkIfExists(const QString& filePath, QList<CollectionLocation> assumeDeleted)
 {
+    const KUrl filePathUrl = filePath;
+
     DatabaseAccess access;
     foreach (AlbumRootLocation *location, locations)
     {
-        QString locationPath = location->albumRootPath();
-        kDebug() << filePath << locationPath;
-        if (!locationPath.isEmpty() && filePath.startsWith(locationPath))
+        const KUrl locationPathUrl = location->albumRootPath();
+        //kDebug() << filePathUrl << locationPathUrl;
+        // make sure filePathUrl is neither a child nor a parent
+        // of an existing collection
+        if (!locationPathUrl.isEmpty() &&
+              ( filePathUrl.isParentOf(locationPathUrl) ||
+                locationPathUrl.isParentOf(filePathUrl) )
+           )
         {
             bool isDeleted = false;
-            foreach (const CollectionLocation &deletedLoc, assumeDeleted)
+            foreach (const CollectionLocation& deletedLoc, assumeDeleted)
             {
                 if (deletedLoc.id() == location->id())
                 {
@@ -581,12 +643,12 @@ CollectionManager::CollectionManager()
     connect(Solid::DeviceNotifier::instance(),
             SIGNAL(deviceAdded(const QString &)),
             this,
-            SLOT(deviceChange(const QString &)));
+            SLOT(deviceAdded(const QString &)));
 
     connect(Solid::DeviceNotifier::instance(),
             SIGNAL(deviceRemoved(const QString &)),
             this,
-            SLOT(deviceChange(const QString &)));
+            SLOT(deviceRemoved(const QString &)));
 
     // DatabaseWatch slot is connected at construction of DatabaseWatch, which may be later.
 }
@@ -599,26 +661,18 @@ CollectionManager::~CollectionManager()
 void CollectionManager::refresh()
 {
     {
+        // if called from the DatabaseAccess constructor itself, it will
+        // hold a flag to prevent endless recursion
         DatabaseAccess access;
-
-        // clear list
-        foreach (AlbumRootLocation *location, d->locations)
-        {
-            CollectionLocation::Status oldStatus = location->status();
-            location->setStatus(CollectionLocation::LocationDeleted);
-            emit locationStatusChanged(*location, oldStatus);
-            delete location;
-        }
-        d->locations.clear();
+        clear_locked();
     }
-
     updateLocations();
 }
 
-CollectionLocation CollectionManager::addLocation(const KUrl &fileUrl, const QString &label)
+CollectionLocation CollectionManager::addLocation(const KUrl& fileUrl, const QString& label)
 {
-    kDebug(50003) << "addLocation " << fileUrl << endl;
-    QString path = fileUrl.path(KUrl::RemoveTrailingSlash);
+    kDebug() << "addLocation " << fileUrl;
+    QString path = fileUrl.toLocalFile(KUrl::RemoveTrailingSlash);
 
     if (!locationForPath(path).isNull())
         return CollectionLocation();
@@ -645,14 +699,14 @@ CollectionLocation CollectionManager::addLocation(const KUrl &fileUrl, const QSt
         // Empty volumes indicates that Solid is not working correctly.
         if (volumes.isEmpty())
         {
-            kError(50003) << "Solid did not return any storage volumes on your system.";
-            kError(50003) << "This indicates a missing implementation or a problem with your installation";
-            kError(50003) << "On Linux, check that Solid and HAL are working correctly."
+            kError() << "Solid did not return any storage volumes on your system.";
+            kError() << "This indicates a missing implementation or a problem with your installation";
+            kError() << "On Linux, check that Solid and HAL are working correctly."
                              "Problems with RAID partitions have been reported, if you have RAID this error may be normal.";
-            kError(50003) << "On Windows, Solid may not be fully implemented, if you are running Windows this error may be normal.";
+            kError() << "On Windows, Solid may not be fully implemented, if you are running Windows this error may be normal.";
         }
         // fall back
-        kWarning(50003) << "Unable to identify a path with Solid. Adding the location with path only.";
+        kWarning() << "Unable to identify a path with Solid. Adding the location with path only.";
         ChangingDB changing(d);
         DatabaseAccess().db()->addAlbumRoot(AlbumRoot::VolumeHardWired,
                                             d->volumeIdentifier(path), "/", label);
@@ -664,10 +718,10 @@ CollectionLocation CollectionManager::addLocation(const KUrl &fileUrl, const QSt
     return locationForPath(path);
 }
 
-CollectionLocation CollectionManager::addNetworkLocation(const KUrl &fileUrl, const QString &label)
+CollectionLocation CollectionManager::addNetworkLocation(const KUrl& fileUrl, const QString& label)
 {
-    kDebug(50003) << "addLocation " << fileUrl << endl;
-    QString path = fileUrl.path(KUrl::RemoveTrailingSlash);
+    kDebug() << "addLocation " << fileUrl;
+    QString path = fileUrl.toLocalFile(KUrl::RemoveTrailingSlash);
 
     if (!locationForPath(path).isNull())
         return CollectionLocation();
@@ -681,10 +735,19 @@ CollectionLocation CollectionManager::addNetworkLocation(const KUrl &fileUrl, co
     return locationForPath(path);
 }
 
-CollectionManager::LocationCheckResult CollectionManager::checkLocation(const KUrl &fileUrl,
+CollectionManager::LocationCheckResult CollectionManager::checkLocation(const KUrl& fileUrl,
         QList<CollectionLocation> assumeDeleted, QString *message, QString *iconName)
 {
-    QString path = fileUrl.path(KUrl::RemoveTrailingSlash);
+    if (!fileUrl.isLocalFile())
+    {
+        if (message)
+            *message = i18n("Sorry, digiKam does not support remote URLs as collections.");
+        if (iconName)
+            *iconName = "dialog-error";
+        return LocationNotAllowed;
+    }
+
+    QString path = fileUrl.toLocalFile(KUrl::RemoveTrailingSlash);
 
     QDir dir(path);
     if (!dir.isReadable())
@@ -774,7 +837,7 @@ CollectionManager::LocationCheckResult CollectionManager::checkLocation(const KU
             {
                 // Which situation? HasProblems or AllRight?
                 if (message)
-                    *message = i18n("This is a removable storage media that will be identified by its label (\"%1\")",
+                    *message = i18n("This is a removable storage medium that will be identified by its label (\"%1\")",
                                     volume.label);
                 if (iconName)
                     *iconName = "drive-removable-media";
@@ -795,7 +858,7 @@ CollectionManager::LocationCheckResult CollectionManager::checkLocation(const KU
     else
     {
         if (message)
-            *message = i18n("It is not possible on your system to identify the storage media of this path. "
+            *message = i18n("It is not possible on your system to identify the storage medium of this path. "
                             "It will be added using the file path as the only identifier. "
                             "This will work well for your local hard disk.");
                 if (iconName)
@@ -804,10 +867,27 @@ CollectionManager::LocationCheckResult CollectionManager::checkLocation(const KU
     }
 }
 
-CollectionManager::LocationCheckResult CollectionManager::checkNetworkLocation(const KUrl &fileUrl,
+CollectionManager::LocationCheckResult CollectionManager::checkNetworkLocation(const KUrl& fileUrl,
         QList<CollectionLocation> assumeDeleted, QString *message, QString *iconName)
 {
-    QString path = fileUrl.path(KUrl::RemoveTrailingSlash);
+    if (!fileUrl.isLocalFile())
+    {
+        if (message)
+        {
+            if (fileUrl.protocol() == "smb")
+                *message = i18n("You need to locally mount your Samba share. "
+                                "Sorry, digiKam does currently not support smb:// URLs. ");
+            else
+                *message = i18n("Your network storage must be set up to be accessible "
+                                "as files and folders through the operating system. "
+                                "DigiKam does not support remote URLs.");
+        }
+        if (iconName)
+            *iconName = "dialog-error";
+        return LocationNotAllowed;
+    }
+
+    QString path = fileUrl.toLocalFile(KUrl::RemoveTrailingSlash);
 
     QDir dir(path);
     if (!dir.isReadable())
@@ -822,7 +902,7 @@ CollectionManager::LocationCheckResult CollectionManager::checkNetworkLocation(c
     if (d->checkIfExists(path, assumeDeleted))
     {
         if (message)
-            *message = i18n("There is already a collection for a network share with the same path");
+            *message = i18n("There is already a collection for a network share with the same path.");
         if (iconName)
             *iconName = "dialog-error";
         return LocationNotAllowed;
@@ -837,7 +917,7 @@ CollectionManager::LocationCheckResult CollectionManager::checkNetworkLocation(c
     return LocationAllRight;
 }
 
-void CollectionManager::removeLocation(const CollectionLocation &location)
+void CollectionManager::removeLocation(const CollectionLocation& location)
 {
     {
         DatabaseAccess access;
@@ -861,7 +941,60 @@ void CollectionManager::removeLocation(const CollectionLocation &location)
     updateLocations();
 }
 
-void CollectionManager::setLabel(const CollectionLocation &location, const QString &label)
+QList<CollectionLocation> CollectionManager::checkHardWiredLocations()
+{
+    QList<CollectionLocation> disappearedLocations;
+    QList<SolidVolumeInfo> volumes = d->listVolumes();
+
+    DatabaseAccess access;
+
+    foreach (AlbumRootLocation *location, d->locations)
+    {
+        // Hardwired and unavailable?
+        if (location->type() == CollectionLocation::TypeVolumeHardWired
+            && location->status() == CollectionLocation::LocationUnavailable)
+        {
+            disappearedLocations << *location;
+        }
+    }
+
+    return disappearedLocations;
+}
+
+
+void CollectionManager::migrationCandidates(const CollectionLocation &location, QString *description,
+                                             QStringList *candidateIdentifiers, QStringList *candidateDescriptions)
+{
+    description->clear();
+    candidateIdentifiers->clear();
+    candidateDescriptions->clear();
+
+    QList<SolidVolumeInfo> volumes = d->listVolumes();
+
+    DatabaseAccess access;
+
+    AlbumRootLocation *albumLoc = d->locations.value(location.id());
+    if (!albumLoc)
+        return;
+
+    *description = d->technicalDescription(albumLoc);
+
+    // Find possible new volumes where the specific path is found.
+    foreach (const SolidVolumeInfo &info, volumes)
+    {
+        if (info.isMounted && !info.path.isEmpty())
+        {
+            QDir dir(info.path + albumLoc->specificPath);
+            if (dir.exists())
+            {
+                *candidateIdentifiers << d->volumeIdentifier(info);
+                *candidateDescriptions << dir.absolutePath();
+            }
+        }
+    }
+}
+
+void CollectionManager::migrateToVolume(const CollectionLocation& location, const QString& identifier)
 {
     DatabaseAccess access;
 
@@ -870,7 +1003,24 @@ void CollectionManager::setLabel(const CollectionLocation &location, const QStri
         return;
 
     // update db
-    ChangingDB db();
+    ChangingDB db(d);
+    access.db()->migrateAlbumRoot(albumLoc->id(), identifier);
+
+    albumLoc->identifier = identifier;
+
+    updateLocations();
+}
+
+void CollectionManager::setLabel(const CollectionLocation& location, const QString& label)
+{
+    DatabaseAccess access;
+
+    AlbumRootLocation *albumLoc = d->locations.value(location.id());
+    if (!albumLoc)
+        return;
+
+    // update db
+    ChangingDB db(d);
     access.db()->setAlbumRootLabel(albumLoc->id(), label);
 
     // update local structure
@@ -879,6 +1029,24 @@ void CollectionManager::setLabel(const CollectionLocation &location, const QStri
     emit locationPropertiesChanged(*albumLoc);
 }
 
+void CollectionManager::changeType(const CollectionLocation& location, int type)
+{
+    DatabaseAccess access;
+
+    AlbumRootLocation *albumLoc = d->locations.value(location.id());
+    if (!albumLoc)
+        return;
+
+    // update db
+    ChangingDB db(d);
+    access.db()->changeAlbumRootType(albumLoc->id(), (AlbumRoot::Type)type);
+
+    // update local structure
+    albumLoc->setType((CollectionLocation::Type)type);
+
+    emit locationPropertiesChanged(*albumLoc);
+}
+
 QList<CollectionLocation> CollectionManager::allLocations()
 {
     DatabaseAccess access;
@@ -922,12 +1090,12 @@ CollectionLocation CollectionManager::locationForAlbumRootId(int id)
         return CollectionLocation();
 }
 
-CollectionLocation CollectionManager::locationForAlbumRoot(const KUrl &fileUrl)
+CollectionLocation CollectionManager::locationForAlbumRoot(const KUrl& fileUrl)
 {
-    return locationForAlbumRootPath(fileUrl.path(KUrl::RemoveTrailingSlash));
+    return locationForAlbumRootPath(fileUrl.toLocalFile(KUrl::RemoveTrailingSlash));
 }
 
-CollectionLocation CollectionManager::locationForAlbumRootPath(const QString &albumRootPath)
+CollectionLocation CollectionManager::locationForAlbumRootPath(const QString& albumRootPath)
 {
     DatabaseAccess access;
     QString path = albumRootPath;
@@ -939,20 +1107,24 @@ CollectionLocation CollectionManager::locationForAlbumRootPath(const QString &al
     return CollectionLocation();
 }
 
-CollectionLocation CollectionManager::locationForUrl(const KUrl &fileUrl)
+CollectionLocation CollectionManager::locationForUrl(const KUrl& fileUrl)
 {
-    return locationForPath(fileUrl.path(KUrl::RemoveTrailingSlash));
+    return locationForPath(fileUrl.toLocalFile(KUrl::RemoveTrailingSlash));
 }
 
-CollectionLocation CollectionManager::locationForPath(const QString &filePath)
+CollectionLocation CollectionManager::locationForPath(const QString& givenPath)
 {
     DatabaseAccess access;
     foreach (AlbumRootLocation *location, d->locations)
     {
         QString rootPath = location->albumRootPath();
-        kDebug(50003) << "Testing location " << location->id() << filePath << rootPath << endl;
+        QString filePath = QDir::fromNativeSeparators(givenPath);
         if (!rootPath.isEmpty() && filePath.startsWith(rootPath))
-            return *location;
+        {
+            // see also bug #221155 for extra checks
+            if (filePath == rootPath || filePath.startsWith(rootPath + "/"))
+                return *location;
+        }
     }
     return CollectionLocation();
 }
@@ -961,24 +1133,24 @@ QString CollectionManager::albumRootPath(int id)
 {
     DatabaseAccess access;
     CollectionLocation *location = d->locations.value(id);
-    if (location)
+    if (location && location->status() == CollectionLocation::LocationAvailable)
     {
         return location->albumRootPath();
     }
     return QString();
 }
 
-KUrl CollectionManager::albumRoot(const KUrl &fileUrl)
+KUrl CollectionManager::albumRoot(const KUrl& fileUrl)
 {
-    return KUrl::fromPath(albumRootPath(fileUrl.path(KUrl::LeaveTrailingSlash)));
+    return KUrl::fromPath(albumRootPath(fileUrl.toLocalFile(KUrl::LeaveTrailingSlash)));
 }
 
-QString CollectionManager::albumRootPath(const KUrl &fileUrl)
+QString CollectionManager::albumRootPath(const KUrl& fileUrl)
 {
-    return albumRootPath(fileUrl.path(KUrl::LeaveTrailingSlash));
+    return albumRootPath(fileUrl.toLocalFile(KUrl::LeaveTrailingSlash));
 }
 
-QString CollectionManager::albumRootPath(const QString &filePath)
+QString CollectionManager::albumRootPath(const QString& filePath)
 {
     DatabaseAccess access;
     foreach (AlbumRootLocation *location, d->locations)
@@ -990,12 +1162,12 @@ QString CollectionManager::albumRootPath(const QString &filePath)
     return QString();
 }
 
-bool CollectionManager::isAlbumRoot(const KUrl &fileUrl)
+bool CollectionManager::isAlbumRoot(const KUrl& fileUrl)
 {
-    return isAlbumRoot(fileUrl.path(KUrl::RemoveTrailingSlash));
+    return isAlbumRoot(fileUrl.toLocalFile(KUrl::RemoveTrailingSlash));
 }
 
-bool CollectionManager::isAlbumRoot(const QString &filePath)
+bool CollectionManager::isAlbumRoot(const QString& filePath)
 {
     DatabaseAccess access;
     foreach (AlbumRootLocation *location, d->locations)
@@ -1006,12 +1178,12 @@ bool CollectionManager::isAlbumRoot(const QString &filePath)
     return false;
 }
 
-QString CollectionManager::album(const KUrl &fileUrl)
+QString CollectionManager::album(const KUrl& fileUrl)
 {
-    return album(fileUrl.path(KUrl::RemoveTrailingSlash));
+    return album(fileUrl.toLocalFile(KUrl::RemoveTrailingSlash));
 }
 
-QString CollectionManager::album(const QString &filePath)
+QString CollectionManager::album(const QString& filePath)
 {
     DatabaseAccess access;
     foreach (AlbumRootLocation *location, d->locations)
@@ -1036,12 +1208,12 @@ QString CollectionManager::album(const QString &filePath)
     return QString();
 }
 
-QString CollectionManager::album(const CollectionLocation &location, const KUrl &fileUrl)
+QString CollectionManager::album(const CollectionLocation& location, const KUrl& fileUrl)
 {
-    return album(location, fileUrl.path(KUrl::RemoveTrailingSlash));
+    return album(location, fileUrl.toLocalFile(KUrl::RemoveTrailingSlash));
 }
 
-QString CollectionManager::album(const CollectionLocation &location, const QString &filePath)
+QString CollectionManager::album(const CollectionLocation& location, const QString& filePath)
 {
     if (location.isNull())
         return QString();
@@ -1073,13 +1245,29 @@ QString CollectionManager::oneAlbumRootPath()
     return QString();
 }
 
-void CollectionManager::deviceChange(const QString &udi)
+void CollectionManager::deviceAdded(const QString& udi)
 {
     Solid::Device device(udi);
     if (device.is<Solid::StorageAccess>())
         updateLocations();
 }
 
+void CollectionManager::deviceRemoved(const QString& udi)
+{
+    // we can't access the Solid::Device to check because it is removed
+    DatabaseAccess access;
+    if (!d->udisToWatch.contains(udi))
+        return;
+    updateLocations();
+}
+
+void CollectionManager::accessibilityChanged(bool accessible, const QString& udi)
+{
+    Q_UNUSED(accessible);
+    Q_UNUSED(udi);
+    updateLocations();
+}
+
 void CollectionManager::updateLocations()
 {
     // get information from Solid
@@ -1098,7 +1286,7 @@ void CollectionManager::updateLocations()
         // synchronize map with database
         QMap<int, AlbumRootLocation *> locs = d->locations;
         d->locations.clear();
-        foreach (const AlbumRootInfo &info, infos)
+        foreach (const AlbumRootInfo& info, infos)
         {
             if (locs.contains(info.id))
             {
@@ -1169,7 +1357,7 @@ void CollectionManager::updateLocations()
             // Don't touch location->status, do not interfere with "hidden" setting
             location->available = available;
             location->setAbsolutePath(absolutePath);
-            kDebug(50003) << "location for " << absolutePath << " is available " << available << endl;
+            kDebug() << "location for " << absolutePath << " is available " << available;
             // set the status depending on "hidden" and "available"
             location->setStatusFromFlags();
         }
@@ -1182,12 +1370,26 @@ void CollectionManager::updateLocations()
             {
                 emit locationStatusChanged(*location, oldStatus[i]);
             }
-            i++;
+            ++i;
         }
     }
 }
 
-void CollectionManager::slotAlbumRootChange(const AlbumRootChangeset &changeset)
+void CollectionManager::clear_locked()
+{
+    // Internal method: Called with mutex locked
+    // Cave: Difficult recursions with DatabaseAccess constructor and setParameters
+    foreach (AlbumRootLocation *location, d->locations)
+    {
+        CollectionLocation::Status oldStatus = location->status();
+        location->setStatus(CollectionLocation::LocationDeleted);
+        emit locationStatusChanged(*location, oldStatus);
+        delete location;
+    }
+    d->locations.clear();
+}
+
+void CollectionManager::slotAlbumRootChange(const AlbumRootChangeset& changeset)
 {
     if (d->changingDB)
         return;
@@ -1208,7 +1410,7 @@ void CollectionManager::slotAlbumRootChange(const AlbumRootChangeset &changeset)
                     if (location)
                     {
                         QList<AlbumRootInfo> infos = access.db()->getAlbumRoots();
-                        foreach (const AlbumRootInfo &info, infos)
+                        foreach (const AlbumRootInfo& info, infos)
                         {
                             if (info.id == location->id())
                             {
