@@ -23,22 +23,22 @@
 
 #include "schemaupdater.h"
 
-// Qt includes.
+// Qt includes
 
 #include <QFileInfo>
 #include <QFile>
 #include <QDir>
 
-// KDE includes.
+// KDE includes
 
-#include <kdebug.h>
 #include <kio/job.h>
 #include <kio/netaccess.h>
 #include <klocale.h>
 #include <kconfig.h>
 #include <kconfiggroup.h>
+#include <kdebug.h>
 
-// LibKDcraw includes.
+// LibKDcraw includes
 
 #include <libkdcraw/version.h>
 #include <libkdcraw/kdcraw.h>
@@ -47,7 +47,7 @@
 #include <libkdcraw/dcrawbinary.h>
 #endif
 
-// Local includes.
+// Local includes
 
 #include "databasebackend.h"
 #include "albumdb.h"
@@ -57,7 +57,7 @@
 #include "collectionlocation.h"
 #include "collectionscanner.h"
 #include "imagequerybuilder.h"
-#include "initializationobserver.h"
+#include "collectionscannerobserver.h"
 
 namespace Digikam
 {
@@ -69,7 +69,7 @@ int SchemaUpdater::schemaVersion()
 
 int SchemaUpdater::filterSettingsVersion()
 {
-    return 2;
+    return 3;
 }
 
 SchemaUpdater::SchemaUpdater(DatabaseAccess *access)
@@ -82,8 +82,11 @@ SchemaUpdater::SchemaUpdater(DatabaseAccess *access)
 
 bool SchemaUpdater::update()
 {
-    kDebug(50003) << "SchemaUpdater update" << endl;
+    kDebug() << "SchemaUpdater update";
     bool success = startUpdates();
+    // cancelled?
+    if (m_observer && !m_observer->continueQuery())
+        return false;
     // even on failure, try to set current version - it may have incremented
     m_access->db()->setSetting("DBVersion",QString::number(m_currentVersion));
     if (!success)
@@ -111,13 +114,13 @@ bool SchemaUpdater::startUpdates()
         // Find out schema version of db file
         QString version = m_access->db()->getSetting("DBVersion");
         QString versionRequired = m_access->db()->getSetting("DBVersionRequired");
-        kDebug(50003) << "Have a database structure version " << version << endl;
+        kDebug() << "Have a database structure version " << version;
 
         // We absolutely require the DBVersion setting
         if (version.isEmpty())
         {
             // Something is damaged. Give up.
-            kError(50003) << "DBVersion not available! Giving up schema upgrading." << endl;
+            kError() << "DBVersion not available! Giving up schema upgrading.";
             QString errorMsg = i18n(
                     "The database is not valid: "
                     "the \"DBVersion\" setting does not exist. "
@@ -167,7 +170,7 @@ bool SchemaUpdater::startUpdates()
     }
     else
     {
-        kDebug(50003) << "No database file available" << endl;
+        kDebug() << "No database file available";
         // Legacy handling?
 
         // first test if there are older files that need to be upgraded.
@@ -228,7 +231,7 @@ bool SchemaUpdater::startUpdates()
 
 bool SchemaUpdater::makeUpdates()
 {
-    kDebug(50003) << "makeUpdates " << m_currentVersion << " to " << schemaVersion() << endl;
+    kDebug() << "makeUpdates " << m_currentVersion << " to " << schemaVersion();
     //DatabaseTransaction transaction(m_access);
     if (m_currentVersion < schemaVersion())
     {
@@ -249,23 +252,31 @@ bool SchemaUpdater::makeUpdates()
             if (!updateV4toV5())
             {
                 m_access->backend()->rollbackTransaction();
-                if (m_observer && !m_setError)
+                if (m_observer)
                 {
-                    QFileInfo currentDBFile(m_access->parameters().databaseName);
-                    QString errorMsg = i18n("The schema updating process from version 4 to 5 failed, "
-                                            "caused by an error that we did not expect. "
-                                            "You can try to discard your old database and start with an empty one. "
-                                            "(In this case, please move the database files "
-                                            "\"%1\" and \"%2\" from the directory \"%3\"). "
-                                            "More probably you will want to report this error to the digikam-devel@kde.org "
-                                            "mailing list. As well, please have a look at what digiKam prints on the console. ",
-                                            QString("digikam3.db"), QString("digikam4.db"), currentDBFile.dir().path());
-                    m_observer->error(errorMsg);
-                    m_observer->finishedSchemaUpdate(InitializationObserver::UpdateErrorMustAbort);
+                    // error or cancelled?
+                    if (!m_observer->continueQuery())
+                    {
+                        kDebug() << "Schema update cancelled by user";
+                    }
+                    else if (!m_setError)
+                    {
+                        QFileInfo currentDBFile(m_access->parameters().databaseName);
+                        QString errorMsg = i18n("The schema updating process from version 4 to 5 failed, "
+                                                "caused by an error that we did not expect. "
+                                                "You can try to discard your old database and start with an empty one. "
+                                                "(In this case, please move the database files "
+                                                "\"%1\" and \"%2\" from the directory \"%3\"). "
+                                                "More probably you will want to report this error to the digikam-devel@kde.org "
+                                                "mailing list. As well, please have a look at what digiKam prints on the console. ",
+                                                QString("digikam3.db"), QString("digikam4.db"), currentDBFile.dir().path());
+                        m_observer->error(errorMsg);
+                        m_observer->finishedSchemaUpdate(InitializationObserver::UpdateErrorMustAbort);
+                    }
                 }
                 return false;
             }
-            kDebug(50003) << "Success updating to v5" << endl;
+            kDebug() << "Success updating to v5";
             m_access->backend()->commitTransaction();
             // REMOVE BEFORE FINAL VERSION
             m_access->db()->setSetting("preAlpha010Update1", "true");
@@ -294,7 +305,7 @@ bool SchemaUpdater::makeUpdates()
     return true;
 }
 
-void SchemaUpdater::defaultFilterSettings(QStringList &defaultImageFilter,
+void SchemaUpdater::defaultFilterSettings(QStringList& defaultImageFilter,
                                           QStringList &defaultVideoFilter,
                                           QStringList &defaultAudioFilter)
 {
@@ -302,11 +313,11 @@ void SchemaUpdater::defaultFilterSettings(QStringList &defaultImageFilter,
     //When changing anything here, just increment filterSettingsVersion() so that the changes take effect
 
     defaultImageFilter << "jpg" << "jpeg" << "jpe"                    // JPEG
-                       << "jp2" << "j2k" << "jpx"  << "jpc" << "pgx"  // JPEG-2000
+                       << "jp2" << "j2k"  << "jpx"  << "jpc" << "pgx" // JPEG-2000
                        << "tif" << "tiff"                             // TIFF
                        << "png"                                       // PNG
-                       << "xpm" << "ppm" << "pnm"
-                       << "gif" << "bmp" << "xcf" << "pcx";
+                       << "xpm" << "ppm"  << "pnm" << "pgf"
+                       << "gif" << "bmp"  << "xcf" << "pcx";
 
 #if KDCRAW_VERSION < 0x000400
     defaultImageFilter << KDcrawIface::DcrawBinary::rawFilesList();
@@ -701,7 +712,7 @@ bool SchemaUpdater::createTriggersV5()
     return true;
 }
 
-bool SchemaUpdater::copyV3toV4(const QString &digikam3DBPath, const QString &currentDBPath)
+bool SchemaUpdater::copyV3toV4(const QString& digikam3DBPath, const QString& currentDBPath)
 {
     if (m_observer)
         m_observer->moreSchemaUpdateSteps(2);
@@ -755,7 +766,7 @@ bool SchemaUpdater::copyV3toV4(const QString &digikam3DBPath, const QString &cur
     return true;
 }
 
-bool SchemaUpdater::updateV2toV4(const QString &sqlite2DBPath)
+bool SchemaUpdater::updateV2toV4(const QString& sqlite2DBPath)
 {
     if (m_observer)
         m_observer->moreSchemaUpdateSteps(1);
@@ -796,7 +807,7 @@ static QStringList cleanUserFilterString(const QString &filterString)
         sep = QChar(' ');
 
     QStringList sepList = filterString.split(sep, QString::SkipEmptyParts);
-    foreach (const QString &f, sepList)
+    foreach (const QString& f, sepList)
     {
         if (f.startsWith(wildcard))
             filterList << f.mid(2).trimmed().toLower();
@@ -808,9 +819,13 @@ static QStringList cleanUserFilterString(const QString &filterString)
 
 bool SchemaUpdater::updateV4toV5()
 {
-    kDebug(50003) << "updateV4toV5" << endl;
+    kDebug() << "updateV4toV5";
     if (m_observer)
+    {
+        if (!m_observer->continueQuery())
+            return false;
         m_observer->moreSchemaUpdateSteps(11);
+    }
 
     // This update was introduced from digikam version 0.9 to digikam 0.10
     // We operator on an SQLite3 database under a transaction (which will be rolled back on error)
@@ -825,7 +840,7 @@ bool SchemaUpdater::updateV4toV5()
     if (!m_access->backend()->execSql(QString("ALTER TABLE Searches RENAME TO SearchesV3;")))
         return false;
 
-    kDebug(50003) << "Moved tables" << endl;
+    kDebug() << "Moved tables";
     // --- Drop some triggers and indices ---
 
     // Don't check for errors here. The "IF EXISTS" clauses seem not supported in SQLite
@@ -839,8 +854,12 @@ bool SchemaUpdater::updateV4toV5()
     m_access->backend()->execSql(QString("DROP INDEX tag_index;"));
 
     if (m_observer)
+    {
+        if (!m_observer->continueQuery())
+            return false;
         m_observer->schemaUpdateProgress(i18n("Prepared table creation"));
-    kDebug(50003) << "Dropped triggers" << endl;
+    }
+    kDebug() << "Dropped triggers";
 
     // --- Create new tables ---
 
@@ -848,7 +867,11 @@ bool SchemaUpdater::updateV4toV5()
         return false;
 
     if (m_observer)
+    {
+        if (!m_observer->continueQuery())
+            return false;
         m_observer->schemaUpdateProgress(i18n("Created tables"));
+    }
 
     // --- Populate AlbumRoots (from config) ---
 
@@ -859,7 +882,7 @@ bool SchemaUpdater::updateV4toV5()
 
     if (albumLibraryPath.isEmpty())
     {
-        kError(50003) << "Album library path from config file is empty. Aborting update." << endl;
+        kError() << "Album library path from config file is empty. Aborting update.";
         QString errorMsg = i18n("No album library path has been found in the configuration file. "
                                 "Giving up the schema updating process. "
                                 "Please try with an empty database, or repair your configuration.");
@@ -877,7 +900,7 @@ bool SchemaUpdater::updateV4toV5()
             CollectionManager::instance()->addLocation(KUrl::fromPath(albumLibraryPath));
     if (location.isNull())
     {
-        kError(50003) << "Failure to create a collection location. Aborting update." << endl;
+        kError() << "Failure to create a collection location. Aborting update.";
         QString errorMsg = i18n("There was an error associating your albumLibraryPath (\"%1\") "
                                 "with a storage volume of your system. "
                                 "This problem may indicate that there is a problem with your installation. "
@@ -896,8 +919,12 @@ bool SchemaUpdater::updateV4toV5()
     }
 
     if (m_observer)
+    {
+        if (!m_observer->continueQuery())
+            return false;
         m_observer->schemaUpdateProgress(i18n("Configured one album root"));
-    kDebug(50003) << "Inserted album root" << endl;
+    }
+    kDebug() << "Inserted album root";
 
     // --- With the album root, populate albums ---
 
@@ -912,8 +939,12 @@ bool SchemaUpdater::updateV4toV5()
         return false;
 
     if (m_observer)
+    {
+        if (!m_observer->continueQuery())
+            return false;
         m_observer->schemaUpdateProgress(i18n("Imported albums"));
-    kDebug(50003) << "Populated albums" << endl;
+    }
+    kDebug() << "Populated albums";
 
     // --- Add images ---
 
@@ -931,9 +962,13 @@ bool SchemaUpdater::updateV4toV5()
     m_access->backend()->execSql(QString("DELETE FROM Images WHERE album NOT IN (SELECT id FROM Albums);"));
 
     if (m_observer)
+    {
+        if (!m_observer->continueQuery())
+            return false;
         m_observer->schemaUpdateProgress(i18n("Imported images information"));
+    }
 
-    kDebug(50003) << "Populated Images" << endl;
+    kDebug() << "Populated Images";
 
     // --- Port searches ---
 
@@ -948,7 +983,7 @@ bool SchemaUpdater::updateV4toV5()
 
     SearchInfo::List sList = m_access->db()->scanSearches();
 
-    for (SearchInfo::List::iterator it = sList.begin(); it != sList.end(); ++it)
+    for (SearchInfo::List::const_iterator it = sList.constBegin(); it != sList.constEnd(); ++it)
     {
         KUrl url((*it).query);
 
@@ -977,7 +1012,7 @@ bool SchemaUpdater::updateV4toV5()
 
     if (!createTriggersV5())
         return false;
-    kDebug(50003) << "Created triggers" << endl;
+    kDebug() << "Created triggers";
 
     // --- Populate name filters ---
 
@@ -1001,20 +1036,31 @@ bool SchemaUpdater::updateV4toV5()
     configAudioFilter.subtract(defaultAudioFilter.toSet());
 
     m_access->db()->setUserFilterSettings(configImageFilter.toList(), configVideoFilter.toList(), configAudioFilter.toList());
-    kDebug(50003) << "Set initial filter settings with user settings" << configImageFilter << endl;
+    kDebug() << "Set initial filter settings with user settings" << configImageFilter;
 
     if (m_observer)
+    {
+        if (!m_observer->continueQuery())
+            return false;
         m_observer->schemaUpdateProgress(i18n("Initialized and imported file suffix filter"));
+    }
 
     // --- do a full scan ---
 
     CollectionScanner scanner;
     if (m_observer)
+    {
         m_observer->connectCollectionScanner(&scanner);
+        scanner.setObserver(m_observer);
+    }
     scanner.completeScan();
 
     if (m_observer)
+    {
+        if (!m_observer->continueQuery())
+            return false;
         m_observer->schemaUpdateProgress(i18n("Did the initial full scan"));
+    }
 
     // --- Port date, comment and rating (_after_ the scan) ---
 
@@ -1029,9 +1075,21 @@ bool SchemaUpdater::updateV4toV5()
          return false;
 
     if (m_observer)
+    {
+        if (!m_observer->continueQuery())
+            return false;
         m_observer->schemaUpdateProgress(i18n("Imported creation dates"));
+    }
 
     // Port ImagesV3.comment to ImageComments
+
+    // An author of NULL will inhibt the UNIQUE restriction to take effect (but #189080). Work around.
+    m_access->backend()->execSql(QString(
+                    "DELETE FROM ImageComments WHERE "
+                    "type=? AND language=? AND author IS NULL "
+                    "AND imageid IN ( SELECT id FROM ImagesV3 ); "),
+                    (int)DatabaseComment::Comment, QString("x-default"));
+
     if (!m_access->backend()->execSql(QString(
                     "REPLACE INTO ImageComments "
                     " (imageid, type, language, comment) "
@@ -1042,7 +1100,11 @@ bool SchemaUpdater::updateV4toV5()
          return false;
 
     if (m_observer)
+    {
+        if (!m_observer->continueQuery())
+            return false;
         m_observer->schemaUpdateProgress(i18n("Imported comments"));
+    }
 
     // Port rating storage in ImageProperties to ImageInformation
     if (!m_access->backend()->execSql(QString(
@@ -1059,7 +1121,11 @@ bool SchemaUpdater::updateV4toV5()
     m_access->backend()->execSql(QString("UPDATE ImageInformation SET rating=0 WHERE rating<0;"));
 
     if (m_observer)
+    {
+        if (!m_observer->continueQuery())
+            return false;
         m_observer->schemaUpdateProgress(i18n("Imported ratings"));
+    }
 
     // --- Drop old tables ---
 
@@ -1071,7 +1137,7 @@ bool SchemaUpdater::updateV4toV5()
         m_observer->schemaUpdateProgress(i18n("Dropped v3 tables"));
 
     m_currentVersion = 5;
-    kDebug(50003) << "Returning true from updating to 5" << endl;
+    kDebug() << "Returning true from updating to 5";
     return true;
 }
 
@@ -1103,7 +1169,7 @@ void SchemaUpdater::preAlpha010Update1()
 
     SearchInfo::List sList = m_access->db()->scanSearches();
 
-    for (SearchInfo::List::iterator it = sList.begin(); it != sList.end(); ++it)
+    for (SearchInfo::List::const_iterator it = sList.constBegin(); it != sList.constEnd(); ++it)
     {
         KUrl url((*it).query);
 
