@@ -7,8 +7,8 @@
  * Description : digiKam 8/16 bits image management API
  *
  * Copyright (C) 2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2005-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2009 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
+ * Copyright (C) 2005-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel.wiesweg@gmx.de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -808,7 +808,7 @@ int DImg::originalBitDepth() const
     return m_priv->attributes.value("originalBitDepth").toInt();
 }
 
-DImg::FORMAT DImg::fileFormat() const
+DImg::FORMAT DImg::detectedFormat() const
 {
     if (m_priv->attributes.contains("detectedFileFormat"))
         return (FORMAT)m_priv->attributes.value("detectedFileFormat").toInt();
@@ -816,6 +816,24 @@ DImg::FORMAT DImg::fileFormat() const
         return NONE;
 }
 
+QString DImg::format() const
+{
+    return m_priv->attributes.value("format").toString();
+}
+
+QString DImg::savedFormat() const
+{
+    return m_priv->attributes.value("savedformat").toString();
+}
+
+DRawDecoding DImg::rawDecodingSettings() const
+{
+    if (m_priv->attributes.contains("rawDecodingSettings"))
+        return m_priv->attributes.value("rawDecodingSettings").value<DRawDecoding>();
+    else
+        return DRawDecoding();
+}
+
 QByteArray DImg::getComments() const
 {
     return metadata(COM);
@@ -942,6 +960,19 @@ QString DImg::embeddedText(const QString& key) const
     return QString();
 }
 
+void DImg::switchOriginToLastSaved()
+{
+    QVariant savedformat = attribute("savedformat");
+    if (!savedformat.isNull())
+        setAttribute("format", savedformat);
+
+    QVariant readonly = attribute("savedformat-isreadonly");
+    if (!readonly.isNull())
+        setAttribute("isreadonly", readonly);
+
+    removeAttribute("rawDecodingSettings");
+}
+
 DColor DImg::getPixelColor(uint x, uint y) const
 {
     if (m_priv->null || x >= m_priv->width || y >= m_priv->height)
@@ -1570,7 +1601,8 @@ QImage DImg::pureColorMask(ExposureSettingsContainer *expoSettings)
     // alpha channel is auto-detected during QImage->QPixmap conversion
 
     uchar *bits = img.bits();
-    int    max  = sixteenBit() ? 65535 : 255;
+    // Using DImgScale before to compute Mask clamp to 65534 | 254. Why ?
+    int    max  = sixteenBit() ? 65534 : 254;
 
     // --------------------------------------------------------
 
@@ -1589,18 +1621,20 @@ QImage DImg::pureColorMask(ExposureSettingsContainer *expoSettings)
     // --------------------------------------------------------
 
     uint dim    = m_priv->width * m_priv->height;
-    uint*  sptr = (uint*)m_priv->data;
     uchar* dptr = bits;
 
-    if (under && over)
+    if (sixteenBit())
     {
+        unsigned short* sptr = (unsigned short*)m_priv->data;
+
         for (uint i = 0; i < dim; ++i)
         {
-            int s_red   = qRed(*sptr);
-            int s_green = qGreen(*sptr);
-            int s_blue  = qBlue(*sptr);
+            int s_blue  = *sptr++;
+            int s_green = *sptr++;
+            int s_red   = *sptr++;
+            sptr++;
 
-            if ((s_red == 0) && (s_green == 0) && (s_blue == 0))
+            if ((under) && (s_red == 0) && (s_green == 0) && (s_blue == 0))
             {
                 dptr[0] = u_blue;
                 dptr[1] = u_green;
@@ -1608,7 +1642,7 @@ QImage DImg::pureColorMask(ExposureSettingsContainer *expoSettings)
                 dptr[3] = 0xFF;
             }
 
-            if ((s_red == max) && (s_green == max) && (s_blue == max))
+            if ((over) && (s_red >= max) && (s_green >= max) && (s_blue >= max))
             {
                 dptr[0] = o_blue;
                 dptr[1] = o_green;
@@ -1617,14 +1651,20 @@ QImage DImg::pureColorMask(ExposureSettingsContainer *expoSettings)
             }
 
             dptr += 4;
-            ++sptr;
         }
     }
-    else if (under)
+    else
     {
-        for (uint i = 0; i < dim; ++i)
+       uchar* sptr = m_priv->data;
+
+       for (uint i = 0; i < dim; ++i)
         {
-            if ((qRed(*sptr) == 0) && (qGreen(*sptr) == 0) && (qBlue(*sptr) == 0))
+            int s_blue  = *sptr++;
+            int s_green = *sptr++;
+            int s_red   = *sptr++;
+            sptr++;
+
+            if ((under) && (s_red == 0) && (s_green == 0) && (s_blue == 0))
             {
                 dptr[0] = u_blue;
                 dptr[1] = u_green;
@@ -1632,15 +1672,7 @@ QImage DImg::pureColorMask(ExposureSettingsContainer *expoSettings)
                 dptr[3] = 0xFF;
             }
 
-            dptr += 4;
-            ++sptr;
-        }
-    }
-    else        // over-exposure
-    {
-        for (uint i = 0; i < dim; ++i)
-        {
-            if ((qRed(*sptr) == max) && (qGreen(*sptr) == max) && (qBlue(*sptr) == max))
+            if ((over) && (s_red >= max) && (s_green >= max) && (s_blue >= max))
             {
                 dptr[0] = o_blue;
                 dptr[1] = o_green;
@@ -1649,10 +1681,8 @@ QImage DImg::pureColorMask(ExposureSettingsContainer *expoSettings)
             }
 
             dptr += 4;
-            ++sptr;
         }
     }
-
     return img;
 }
 
