@@ -26,13 +26,17 @@
 #ifndef IMAGEDESCEDITTAB_H
 #define IMAGEDESCEDITTAB_H
 
-// Qt includes.
+// Qt includes
 
 #include <QScrollArea>
 #include <QPixmap>
 #include <QEvent>
 
-// Local includes.
+// KDE includes
+
+#include <kvbox.h>
+
+// Local includes
 
 #include "digikam_export.h"
 #include "searchtextbar.h"
@@ -47,7 +51,7 @@ class TAlbumCheckListItem;
 class ImageInfo;
 class ImageDescEditTabPriv;
 
-class ImageDescEditTab : public QScrollArea
+class ImageDescEditTab : public KVBox
 {
     Q_OBJECT
 
@@ -57,8 +61,8 @@ public:
     ~ImageDescEditTab();
 
     void assignRating(int rating);
-    void setItem(const ImageInfo &info = ImageInfo());
-    void setItems(const ImageInfoList &infos);
+    void setItem(const ImageInfo& info = ImageInfo());
+    void setItems(const ImageInfoList& infos);
     void populateTags();
     void refreshTagsView();
 
@@ -76,13 +80,14 @@ protected:
 
 private:
 
-    void setInfos(const ImageInfoList &infos);
+    void setInfos(const ImageInfoList& infos);
     void focusLastSelectedWidget();
 
     void updateTagsView();
     void updateComments();
     void updateRating();
     void updateDate();
+    void updateTemplate();
     void updateRecentTags();
 
     void tagNew(TAlbum* parAlbum, const QString& _title=QString(), const QString& _icon=QString()) const;
@@ -108,6 +113,7 @@ private Q_SLOTS:
     void slotCommentChanged();
     void slotDateTimeChanged(const QDateTime& dateTime);
     void slotRatingChanged(int rating);
+    void slotTemplateSelected();
     void slotModified();
     void slotRightButtonClicked(Q3ListViewItem*, const QPoint &, int);
     void slotTagsSearchChanged(const SearchTextSettings&);
