@@ -389,6 +389,7 @@ void ImagePropertiesColorsTab::setData(const KUrl& url, const QRect& selectionAr
     if (url.isEmpty())
     {
        setEnabled(false);
+       d->image.reset();
        return;
     }
 
@@ -458,7 +459,7 @@ void ImagePropertiesColorsTab::loadImageFromUrl(const KUrl& url)
 
         DRawDecoding rawDecodingSettings = DRawDecoding();
         rawDecodingSettings.optimizeTimeLoading();
-        desc = LoadingDescription(desc.filePath, rawDecodingSettings);
+        desc = LoadingDescription(desc.filePath, rawDecodingSettings, LoadingDescription::RawDecodingTimeOptimized);
     }
 
     if (d->currentLoadingDescription.equalsOrBetterThan(desc))
@@ -534,6 +535,7 @@ void ImagePropertiesColorsTab::setSelection(const QRect& selectionArea)
     }
     else
     {
+        d->imageSelection.reset();
         d->regionBox->hide();
         slotRenderingChanged(FullImageHistogram);
     }
