@@ -28,11 +28,11 @@
 
 #include "imagelevels.h"
 
-// Qt includes.
+// Qt includes
 
 #include <QFile>
 
-// C++ includes.
+// C++ includes
 
 #include <cstdio>
 #include <cmath>
@@ -40,13 +40,14 @@
 #include <cstdlib>
 #include <cerrno>
 
-// KDE includes.
+// KDE includes
 
 #include <kdebug.h>
 
-// Local includes.
+// Local includes
 
 #include "imagehistogram.h"
+#include "globals.h"
 
 namespace Digikam
 {
@@ -120,7 +121,7 @@ ImageLevels::~ImageLevels()
     {
        if (d->lut->luts)
        {
-          for (int i = 0 ; i < d->lut->nchannels ; i++)
+          for (int i = 0 ; i < d->lut->nchannels ; ++i)
               delete [] d->lut->luts[i];
 
           delete [] d->lut->luts;
@@ -147,7 +148,7 @@ bool ImageLevels::isSixteenBits()
 
 void ImageLevels::reset()
 {
-    for (int channel = 0 ; channel < 5 ; channel++)
+    for (int channel = 0 ; channel < 5 ; ++channel)
        levelsChannelReset(channel);
 }
 
@@ -167,11 +168,11 @@ void ImageLevels::levelsAuto(ImageHistogram *hist)
 {
     if (!d->levels || !hist) return;
 
-    levelsChannelReset(ImageHistogram::ValueChannel);
+    levelsChannelReset(LuminosityChannel);
 
-    for (int channel = ImageHistogram::RedChannel ;
-         channel <= ImageHistogram::BlueChannel ;
-         channel++)
+    for (int channel = RedChannel ;
+         channel <= BlueChannel ;
+         ++channel)
     {
        levelsChannelAuto(hist, channel);
     }
@@ -202,7 +203,7 @@ void ImageLevels::levelsChannelAuto(ImageHistogram *hist, int channel)
 
        new_count = 0.0;
 
-       for (i = 0 ; i < (d->sixteenBit ? 65535 : 255) ; i++)
+       for (i = 0 ; i < (d->sixteenBit ? 65535 : 255) ; ++i)
        {
           new_count       += hist->getValue(channel, i);
           percentage      = new_count / count;
@@ -219,7 +220,7 @@ void ImageLevels::levelsChannelAuto(ImageHistogram *hist, int channel)
 
        new_count = 0.0;
 
-       for (i = (d->sixteenBit ? 65535 : 255) ; i > 0 ; i--)
+       for (i = (d->sixteenBit ? 65535 : 255) ; i > 0 ; --i)
        {
           new_count       += hist->getValue(channel, i);
           percentage      = new_count / count;
@@ -239,16 +240,16 @@ int ImageLevels::levelsInputFromColor(int channel, const DColor& color)
 {
     switch (channel)
     {
-       case ImageHistogram::ValueChannel:
+        case LuminosityChannel:
           return qMax (qMax (color.red(), color.green()), color.blue());
 
-       case ImageHistogram::RedChannel:
+       case RedChannel:
           return color.red();
 
-       case ImageHistogram::GreenChannel:
+       case GreenChannel:
           return color.green();
 
-       case ImageHistogram::BlueChannel:
+       case BlueChannel:
           return color.blue();
     }
 
@@ -320,9 +321,9 @@ void ImageLevels::levelsCalculateTransfers()
 
     // Recalculate the levels arrays.
 
-    for (j = 0 ; j < 5 ; j++)
+    for (j = 0 ; j < 5 ; ++j)
     {
-      for (i = 0; i <= (d->sixteenBit ? 65535 : 255); i++)
+      for (i = 0; i <= (d->sixteenBit ? 65535 : 255); ++i)
       {
           //  determine input intensity.
 
@@ -412,7 +413,7 @@ void ImageLevels::levelsLutSetup(int nchannels)
 
     if (d->lut->luts)
     {
-       for (i = 0 ; i < d->lut->nchannels ; i++)
+       for (i = 0 ; i < d->lut->nchannels ; ++i)
            delete [] d->lut->luts[i];
 
        delete [] d->lut->luts;
@@ -421,11 +422,11 @@ void ImageLevels::levelsLutSetup(int nchannels)
     d->lut->nchannels = nchannels;
     d->lut->luts      = new unsigned short*[d->lut->nchannels];
 
-    for (i = 0 ; i < d->lut->nchannels ; i++)
+    for (i = 0 ; i < d->lut->nchannels ; ++i)
     {
        d->lut->luts[i] = new unsigned short[(d->sixteenBit ? 65535 : 255) + 1];
 
-       for (v = 0 ; v <= (d->sixteenBit ? 65535 : 255) ; v++)
+       for (v = 0 ; v <= (uint)(d->sixteenBit ? 65535 : 255) ; ++v)
        {
           // to add gamma correction use func(v ^ g) ^ 1/g instead.
 
@@ -458,7 +459,7 @@ void ImageLevels::levelsLutProcess(uchar *srcPR, uchar *destPR, int w, int h)
         uchar *ptr = srcPR;
         uchar *dst = destPR;
 
-        for (i = 0 ; i < w*h ; i++)
+        for (i = 0 ; i < w*h ; ++i)
         {
             blue  = ptr[0];
             green = ptr[1];
@@ -492,7 +493,7 @@ void ImageLevels::levelsLutProcess(uchar *srcPR, uchar *destPR, int w, int h)
         unsigned short *ptr = (unsigned short *)srcPR;
         unsigned short *dst = (unsigned short *)destPR;
 
-        for (i = 0 ; i < w*h ; i++)
+        for (i = 0 ; i < w*h ; ++i)
         {
             blue  = ptr[0];
             green = ptr[1];
@@ -621,7 +622,7 @@ bool ImageLevels::loadLevelsFromGimpLevelsFile(const KUrl& fileUrl)
     char    buf[50];
     char   *nptr;
 
-    file = fopen(QFile::encodeName(fileUrl.path()), "r");
+    file = fopen(QFile::encodeName(fileUrl.toLocalFile()), "r");
 
     if (!file)
        return false;
@@ -638,7 +639,7 @@ bool ImageLevels::loadLevelsFromGimpLevelsFile(const KUrl& fileUrl)
        return false;
     }
 
-    for (i = 0 ; i < 5 ; i++)
+    for (i = 0 ; i < 5 ; ++i)
     {
        fields = fscanf (file, "%d %d %d %d ",
                         &low_input[i],
@@ -648,14 +649,14 @@ bool ImageLevels::loadLevelsFromGimpLevelsFile(const KUrl& fileUrl)
 
        if (fields != 4)
        {
-          kWarning(50003) <<  "Invalid Gimp levels file!" << endl;
+          kWarning() <<  "Invalid Gimp levels file!";
           fclose(file);
           return false;
        }
 
        if (!fgets (buf, 50, file))
        {
-          kWarning(50003) <<  "Invalid Gimp levels file!" << endl;
+          kWarning() <<  "Invalid Gimp levels file!";
           fclose(file);
           return false;
        }
@@ -664,13 +665,13 @@ bool ImageLevels::loadLevelsFromGimpLevelsFile(const KUrl& fileUrl)
 
        if (buf == nptr || errno == ERANGE)
        {
-          kWarning(50003) <<  "Invalid Gimp levels file!" << endl;
+          kWarning() <<  "Invalid Gimp levels file!";
           fclose(file);
           return false;
        }
     }
 
-    for (i = 0 ; i < 5 ; i++)
+    for (i = 0 ; i < 5 ; ++i)
     {
        setLevelGammaValue(i, gamma[i]);
        setLevelLowInputValue(i, d->sixteenBit ? low_input[i]*255 : low_input[i]);
@@ -690,14 +691,14 @@ bool ImageLevels::saveLevelsToGimpLevelsFile(const KUrl& fileUrl)
     FILE *file;
     int   i;
 
-    file = fopen(QFile::encodeName(fileUrl.path()), "w");
+    file = fopen(QFile::encodeName(fileUrl.toLocalFile()), "w");
 
     if (!file)
        return false;
 
     fprintf (file, "# GIMP Levels File\n");
 
-    for (i = 0 ; i < 5 ; i++)
+    for (i = 0 ; i < 5 ; ++i)
     {
        char buf[256];
        sprintf (buf, "%f", getLevelGammaValue(i));
