@@ -21,22 +21,19 @@
  *
  * ============================================================ */
 
-#include "abstractalbummodel.h"
 #include "abstractalbummodel.moc"
 #include "abstractalbummodelpriv.h"
 
-// Qt includes.
+// KDE includes
 
-// KDE includes.
-
-#include <kdebug.h>
 #include <klocale.h>
 #include <kglobal.h>
 
-// Local includes.
+// Local includes
 
 #include "albummanager.h"
 #include "albumthumbnailloader.h"
+#include "albummodeldragdrophandler.h"
 
 namespace Digikam
 {
@@ -76,7 +73,7 @@ AbstractAlbumModel::~AbstractAlbumModel()
     delete d;
 }
 
-QVariant AbstractAlbumModel::data(const QModelIndex &index, int role) const
+QVariant AbstractAlbumModel::data(const QModelIndex& index, int role) const
 {
     if (!index.isValid())
         return QVariant();
@@ -113,7 +110,7 @@ QVariant AbstractAlbumModel::headerData(int section, Qt::Orientation orientation
     return QVariant();
 }
 
-int AbstractAlbumModel::rowCount(const QModelIndex &parent) const
+int AbstractAlbumModel::rowCount(const QModelIndex& parent) const
 {
     if (parent.isValid())
     {
@@ -137,7 +134,7 @@ int AbstractAlbumModel::columnCount(const QModelIndex &/*parent*/) const
     return 1;
 }
 
-Qt::ItemFlags AbstractAlbumModel::flags(const QModelIndex &index) const
+Qt::ItemFlags AbstractAlbumModel::flags(const QModelIndex& index) const
 {
     if (!index.isValid())
         return 0;
@@ -146,7 +143,7 @@ Qt::ItemFlags AbstractAlbumModel::flags(const QModelIndex &index) const
     return itemFlags(a);
 }
 
-bool AbstractAlbumModel::hasChildren(const QModelIndex &parent) const
+bool AbstractAlbumModel::hasChildren(const QModelIndex& parent) const
 {
     if (parent.isValid())
     {
@@ -165,7 +162,7 @@ bool AbstractAlbumModel::hasChildren(const QModelIndex &parent) const
     }
 }
 
-QModelIndex AbstractAlbumModel::index(int row, int column, const QModelIndex &parent) const
+QModelIndex AbstractAlbumModel::index(int row, int column, const QModelIndex& parent) const
 {
     if (column != 0)
         return QModelIndex();
@@ -197,7 +194,7 @@ QModelIndex AbstractAlbumModel::index(int row, int column, const QModelIndex &pa
     return QModelIndex();
 }
 
-QModelIndex AbstractAlbumModel::parent(const QModelIndex &index) const
+QModelIndex AbstractAlbumModel::parent(const QModelIndex& index) const
 {
     if (index.isValid())
     {
@@ -207,34 +204,57 @@ QModelIndex AbstractAlbumModel::parent(const QModelIndex &index) const
     return QModelIndex();
 }
 
-bool AbstractAlbumModel::setData(const QModelIndex &index, const QVariant &value, int role)
-{
-    //TODO
-    return QAbstractItemModel::setData(index, value, role);
-}
-
 Qt::DropActions AbstractAlbumModel::supportedDropActions() const
 {
-    //TODO
-    return QAbstractItemModel::supportedDropActions();
+    return Qt::CopyAction|Qt::MoveAction;
 }
 
 QStringList AbstractAlbumModel::mimeTypes() const
 {
-    //TODO
-    return QAbstractItemModel::mimeTypes();
+    if (d->dragDropHandler)
+        return d->dragDropHandler->mimeTypes();
+    return QStringList();
 }
 
-bool AbstractAlbumModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent)
+bool AbstractAlbumModel::dropMimeData(const QMimeData *, Qt::DropAction, int, int, const QModelIndex &)
 {
-    //TODO
-    return QAbstractItemModel::dropMimeData(data, action, row, column, parent);
+    // we require custom solutions
+    return false;
 }
 
-QMimeData *AbstractAlbumModel::mimeData(const QModelIndexList &indexes) const
+QMimeData *AbstractAlbumModel::mimeData(const QModelIndexList& indexes) const
 {
-    //TODO
-    return QAbstractItemModel::mimeData(indexes);
+    if (!d->dragDropHandler)
+        return 0;
+
+    QList<Album*> albums;
+    foreach (const QModelIndex& index, indexes)
+    {
+        Album *a = albumForIndex(index);
+        if (a)
+            albums << a;
+    }
+    return d->dragDropHandler->createMimeData(albums);
+}
+
+void AbstractAlbumModel::setEnableDrag(bool enable)
+{
+    d->itemDrag = enable;
+}
+
+void AbstractAlbumModel::setEnableDrop(bool enable)
+{
+    d->itemDrop = enable;
+}
+
+void AbstractAlbumModel::setDragDropHandler(AlbumModelDragDropHandler *handler)
+{
+    d->dragDropHandler = handler;
+}
+
+AlbumModelDragDropHandler *AbstractAlbumModel::dragDropHandler() const
+{
+    return d->dragDropHandler;
 }
 
 QModelIndex AbstractAlbumModel::indexForAlbum(Album *a) const
@@ -261,7 +281,7 @@ QModelIndex AbstractAlbumModel::indexForAlbum(Album *a) const
     return createIndex(row, 0, a);
 }
 
-Album *AbstractAlbumModel::albumForIndex(const QModelIndex &index) const
+Album *AbstractAlbumModel::albumForIndex(const QModelIndex& index) const
 {
     return static_cast<Album*>(index.internalPointer());
 }
@@ -276,6 +296,11 @@ QModelIndex AbstractAlbumModel::rootAlbumIndex() const
     return indexForAlbum(d->rootAlbum);
 }
 
+Album::Type AbstractAlbumModel::albumType() const
+{
+    return d->type;
+}
+
 QVariant AbstractAlbumModel::decorationRole(Album *) const
 {
     return QVariant();
@@ -288,7 +313,12 @@ QString AbstractAlbumModel::columnHeader() const
 
 Qt::ItemFlags AbstractAlbumModel::itemFlags(Album *) const
 {
-    return Qt::ItemIsSelectable|Qt::ItemIsEnabled;
+    Qt::ItemFlags f = Qt::ItemIsSelectable|Qt::ItemIsEnabled;
+    if (d->itemDrag)
+        f |= Qt::ItemIsDragEnabled;
+    if (d->itemDrop)
+        f |= Qt::ItemIsDropEnabled;
+    return f;
 }
 
 bool AbstractAlbumModel::filterAlbum(Album *album) const
@@ -301,15 +331,17 @@ void AbstractAlbumModel::slotAlbumAboutToBeAdded(Album *album, Album *parent, Al
     if (!filterAlbum(album))
         return;
 
-    // when the model is instantiated before albums are initialized
-    if (album->isRoot() && !d->rootAlbum)
-        d->rootAlbum = album;
-
     // start inserting operation
-    int row = prev ? d->findIndexAsChild(prev) : 0;
+    int row = prev ? d->findIndexAsChild(prev)+1 : 0;
     QModelIndex parentIndex = indexForAlbum(parent);
     beginInsertRows(parentIndex, row, row);
 
+    // The root album will become available in time
+    // when the model is instantiated before albums are initialized.
+    // Set d->rootAlbum only after
+    if (album->isRoot() && !d->rootAlbum)
+        d->rootAlbum = album;
+
     // store album for slotAlbumAdded
     d->addingAlbum = album;
 }
@@ -353,6 +385,7 @@ void AbstractAlbumModel::slotAlbumHasBeenDeleted(void *p)
 
 void AbstractAlbumModel::slotAlbumsCleared()
 {
+    d->rootAlbum = 0;
     reset();
     allAlbumsCleared();
 }
@@ -398,7 +431,7 @@ QString AbstractSpecificAlbumModel::columnHeader() const
     return m_columnHeader;
 }
 
-void AbstractSpecificAlbumModel::setColumnHeader(const QString &header)
+void AbstractSpecificAlbumModel::setColumnHeader(const QString& header)
 {
     m_columnHeader = header;
     emit headerDataChanged(Qt::Horizontal, 0, 0);
@@ -469,7 +502,7 @@ bool AbstractCountingAlbumModel::showCount() const
     return m_showCount;
 }
 
-void AbstractCountingAlbumModel::excludeChildrenCount(const QModelIndex &index)
+void AbstractCountingAlbumModel::excludeChildrenCount(const QModelIndex& index)
 {
     Album *album = albumForIndex(index);
     if (!album)
@@ -478,7 +511,7 @@ void AbstractCountingAlbumModel::excludeChildrenCount(const QModelIndex &index)
     updateCount(album);
 }
 
-void AbstractCountingAlbumModel::includeChildrenCount(const QModelIndex &index)
+void AbstractCountingAlbumModel::includeChildrenCount(const QModelIndex& index)
 {
     Album *album = albumForIndex(index);
     if (!album)
@@ -654,6 +687,11 @@ void AbstractCheckableAlbumModel::setCheckState(Album *album, Qt::CheckState sta
     setData(indexForAlbum(album), state, Qt::CheckStateRole);
 }
 
+void AbstractCheckableAlbumModel::toggleChecked(Album *album)
+{
+    setChecked(album, !isChecked(album));
+}
+
 QList<Album *> AbstractCheckableAlbumModel::checkedAlbums() const
 {
     // return a list with all keys with value Qt::Checked
@@ -687,12 +725,12 @@ QVariant AbstractCheckableAlbumModel::albumData(Album *a, int role) const
     return AbstractCountingAlbumModel::albumData(a, role);
 }
 
-Qt::ItemFlags AbstractCheckableAlbumModel::flags(const QModelIndex &index) const
+Qt::ItemFlags AbstractCheckableAlbumModel::flags(const QModelIndex& index) const
 {
     return AbstractCountingAlbumModel::flags(index) | m_extraFlags;
 }
 
-bool AbstractCheckableAlbumModel::setData(const QModelIndex &index, const QVariant &value, int role)
+bool AbstractCheckableAlbumModel::setData(const QModelIndex& index, const QVariant& value, int role)
 {
     if (role == Qt::CheckStateRole)
     {
@@ -709,4 +747,16 @@ bool AbstractCheckableAlbumModel::setData(const QModelIndex &index, const QVaria
         return AbstractCountingAlbumModel::setData(index, value, role);
 }
 
+void AbstractCheckableAlbumModel::albumCleared(Album *album)
+{
+    m_checkedAlbums.remove(album);
+    AbstractCountingAlbumModel::albumCleared(album);
+}
+
+void AbstractCheckableAlbumModel::allAlbumsCleared()
+{
+    m_checkedAlbums.clear();
+    AbstractCountingAlbumModel::allAlbumsCleared();
+}
+
 } // namespace Digikam
