@@ -7,7 +7,7 @@
  * Description : a generic widget to display a panel to choose
  *               a rectangular image area.
  *
- * Copyright (C) 2004-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2004-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -100,24 +100,6 @@ protected Q_SLOTS:
 
     void slotFlickerTimer();
 
-protected:
-
-    bool     m_flicker;
-
-    int      m_width;
-    int      m_height;
-    int      m_zoomedOrgWidth;
-    int      m_zoomedOrgHeight;
-    int      m_orgWidth;
-    int      m_orgHeight;
-
-    double   m_zoomFactor;
-
-    QRect    m_rect;
-    QRect    m_localRegionSelection;    // Thumbnail size selection.
-
-    QPixmap  m_pixmap;
-
 private:
 
     PanIconWidgetPriv* const d;
