@@ -24,14 +24,14 @@
 #ifndef GPCONFIGDLG_H
 #define GPCONFIGDLG_H
 
-// C ANSI includes.
+// C ANSI includes
 
 extern "C"
 {
 #include <gphoto2.h>
 }
 
-// KDE includes.
+// KDE includes
 
 #include <kdialog.h>
 
@@ -51,7 +51,7 @@ public:
     GPConfigDlg(Camera *camera, CameraWidget *widget, QWidget *parent=0);
     ~GPConfigDlg();
 
-private slots:
+private Q_SLOTS:
 
     void slotOk();
 
