@@ -189,23 +189,30 @@ void DImgInterface::setDisplayingWidget(QWidget *widget)
 
 void DImgInterface::load(const QString& filename, IOFileSettingsContainer *iofileSettings)
 {
-    LoadingDescription description(filename, iofileSettings->rawDecodingSettings, LoadingDescription::ConvertForEditor);
+    LoadingDescription description(filename, LoadingDescription::ConvertForEditor);
 
-    if (iofileSettings->useRAWImport && DImg::fileFormat(filename) == DImg::RAW)
+    if (DImg::fileFormat(filename) == DImg::RAW)
     {
-        d->nextRawDescription = description;
+        description = LoadingDescription(filename, iofileSettings->rawDecodingSettings,
+                                         LoadingDescription::RawDecodingGlobalSettings,
+                                         LoadingDescription::ConvertForEditor);
 
-        RawImport *rawImport = new RawImport(KUrl(filename), this);
-        EditorToolIface::editorToolIface()->loadTool(rawImport);
+        if (iofileSettings->useRAWImport)
+        {
+            d->nextRawDescription = description;
 
-        connect(rawImport, SIGNAL(okClicked()),
-                this, SLOT(slotLoadRawFromTool()));
+            RawImport *rawImport = new RawImport(KUrl(filename), this);
+            EditorToolIface::editorToolIface()->loadTool(rawImport);
 
-        connect(rawImport, SIGNAL(cancelClicked()),
-                this, SLOT(slotLoadRaw()));
+            connect(rawImport, SIGNAL(okClicked()),
+                    this, SLOT(slotLoadRawFromTool()));
 
-        d->thread->stopLoading();
-        return;
+                    connect(rawImport, SIGNAL(cancelClicked()),
+                            this, SLOT(slotLoadRaw()));
+
+                            d->thread->stopLoading();
+                            return;
+        }
     }
     else
     {
@@ -219,7 +226,10 @@ void DImgInterface::slotLoadRawFromTool()
 {
     RawImport *rawImport = dynamic_cast<RawImport*>(EditorToolIface::editorToolIface()->currentTool());
     if (rawImport)
+    {
         d->nextRawDescription.rawDecodingSettings = rawImport->rawDecodingSettings();
+        d->nextRawDescription.rawDecodingHint     = LoadingDescription::RawDecodingCustomSettings;
+    }
     slotLoadRaw();
 }
 
@@ -240,6 +250,11 @@ void DImgInterface::load(const LoadingDescription& description)
 
         loadCurrent();
     }
+    else
+    {
+        emit signalLoadingStarted(d->filename);
+        emit signalImageLoaded(d->filename, true);
+    }
 
     EditorToolIface::editorToolIface()->unLoadTool();
 }
@@ -298,16 +313,26 @@ void DImgInterface::resetValues()
     d->undoMan->clear();
 }
 
-void DImgInterface::setICCSettings(ICCSettingsContainer *cmSettings)
+void DImgInterface::setICCSettings(ICCSettingsContainer* cmSettings)
 {
     d->cmSettings = cmSettings;
 }
 
-void DImgInterface::setExposureSettings(ExposureSettingsContainer *expoSettings)
+ICCSettingsContainer* DImgInterface::getICCSettings()
+{
+    return d->cmSettings;
+}
+
+void DImgInterface::setExposureSettings(ExposureSettingsContainer* expoSettings)
 {
     d->expoSettings = expoSettings;
 }
 
+ExposureSettingsContainer* DImgInterface::getExposureSettings()
+{
+    return d->expoSettings;
+}
+
 void DImgInterface::slotImageLoaded(const LoadingDescription& loadingDescription, const DImg& img)
 {
     const QString &fileName = loadingDescription.filePath;
@@ -331,17 +356,13 @@ void DImgInterface::slotImageLoaded(const LoadingDescription& loadingDescription
         d->height     = d->origHeight;
         valRet        = true;
 
-        // Raw files are already rotated properly by dcraw. Only perform auto-rotation with JPEG/PNG/TIFF file.
+        // Raw files are already rotated properly by dcraw. Only perform auto-rotation with non-RAW files.
         // We don't have a feedback from dcraw about auto-rotated RAW file during decoding. Well set transformed
         // flag as well.
 
-        if (d->image.attribute("format").toString() == QString("RAW"))
+        if (d->image.detectedFormat() == DImg::RAW)
             d->rotatedOrFlipped = true;
-
-        if (d->exifOrient &&
-            (d->image.attribute("format").toString() == QString("JPEG") ||
-             d->image.attribute("format").toString() == QString("PNG")  ||
-             d->image.attribute("format").toString() == QString("TIFF")))
+        else if (d->exifOrient)
              exifRotate(d->filename);
 
         updateColorManagement();
@@ -474,7 +495,7 @@ void DImgInterface::saveAs(const QString& fileName, IOFileSettingsContainer *iof
         mimeType = getImageFormat();
 
     kDebug() << "Saving to :" << QFile::encodeName(fileName).data() << " ("
-                  << mimeType << ")";
+             << mimeType << ")";
 
     // JPEG file format.
     if ( mimeType.toUpper() == QString("JPG") || mimeType.toUpper() == QString("JPEG") ||
@@ -549,14 +570,7 @@ void DImgInterface::switchToLastSaved(const QString& newFilename)
     // it has previously been saved to.
     d->filename = newFilename;
 
-    // Currently the only place where a DImg is connected to the file it originates from
-    // is the format attribute.
-    QVariant savedformat = d->image.attribute("savedformat");
-    if (!savedformat.isNull())
-        d->image.setAttribute("format", savedformat.toString());
-    QVariant readonly = d->image.attribute("savedformat-isreadonly");
-    if (!readonly.isNull())
-        d->image.setAttribute("isreadonly", readonly.toBool());
+    d->image.switchOriginToLastSaved();
 }
 
 void DImgInterface::setModified()
@@ -702,8 +716,8 @@ void DImgInterface::paintOnDevice(QPaintDevice* p,
 
     if (d->expoSettings->underExposureIndicator || d->expoSettings->overExposureIndicator)
     {
-        QImage pureColorMask = d->image.copy(sx, sy, sw, sh).pureColorMask(d->expoSettings);
-        QPixmap pixMask      = QPixmap::fromImage(pureColorMask.scaled(dw, dh));
+        QImage pureColorMask = img.pureColorMask(d->expoSettings);
+        QPixmap pixMask      = QPixmap::fromImage(pureColorMask);
         painter.drawPixmap(dx, dy, pixMask, 0, 0, pixMask.width(), pixMask.height());
     }
 
@@ -764,8 +778,8 @@ void DImgInterface::paintOnDevice(QPaintDevice* p,
 
     if (d->expoSettings->underExposureIndicator || d->expoSettings->overExposureIndicator)
     {
-        QImage pureColorMask = d->image.copy(sx, sy, sw, sh).pureColorMask(d->expoSettings);
-        QPixmap pixMask      = QPixmap::fromImage(pureColorMask.scaled(dw, dh));
+        QImage pureColorMask = img.pureColorMask(d->expoSettings);
+        QPixmap pixMask      = QPixmap::fromImage(pureColorMask);
         painter.drawPixmap(dx, dy, pixMask, 0, 0, pixMask.width(), pixMask.height());
     }
 
@@ -1037,7 +1051,7 @@ QString DImgInterface::getImageFormat()
     if (d->image.isNull())
         return QString();
 
-    QString mimeType = d->image.attribute("format").toString();
+    QString mimeType = d->image.format();
     // It is a bug in the loader if format attribute is not given
     if (mimeType.isEmpty())
     {
@@ -1047,11 +1061,6 @@ QString DImgInterface::getImageFormat()
     return mimeType;
 }
 
-ICCSettingsContainer* DImgInterface::getICCSettings()
-{
-    return d->cmSettings;
-}
-
 QPixmap DImgInterface::convertToPixmap(DImg& img)
 {
     if (d->cmSettings->enableCM && (d->cmSettings->useManagedView || d->doSoftProofing))
@@ -1071,14 +1080,4 @@ QPixmap DImgInterface::convertToPixmap(DImg& img)
     return img.convertToPixmap();
 }
 
-QColor DImgInterface::underExposureColor()
-{
-    return d->expoSettings->underExposureColor;
-}
-
-QColor DImgInterface::overExposureColor()
-{
-    return d->expoSettings->overExposureColor;
-}
-
 }  // namespace Digikam
