@@ -6,7 +6,7 @@
  * Date        : 2008-08-20
  * Description : A widget stack to embed editor view.
  *
- * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,9 +26,8 @@
 // Local includes
 
 #include "previewwidget.h"
-#include "imageregionwidget.h"
-#include "imagepanelwidget.h"
 #include "canvas.h"
+#include "thumbnailsize.h"
 
 namespace Digikam
 {
@@ -67,6 +66,9 @@ void EditorStackView::setCanvas(Canvas* canvas)
 
     connect(d->canvas, SIGNAL(signalZoomChanged(double)),
             this, SLOT(slotZoomChanged(double)));
+
+    connect(d->canvas, SIGNAL(signalToggleOffFitToWindow()),
+            this, SIGNAL(signalToggleOffFitToWindow()));
 }
 
 Canvas* EditorStackView::canvas() const
@@ -84,11 +86,14 @@ void EditorStackView::setToolView(QWidget* view)
     if (d->toolView)
         insertWidget(ToolViewMode, d->toolView);
 
-    PreviewWidget *preview = previewWidget();
+    PreviewWidget* preview = previewWidget();
     if (preview)
     {
         connect(preview, SIGNAL(signalZoomFactorChanged(double)),
                 this, SLOT(slotZoomChanged(double)));
+
+        connect(preview, SIGNAL(signalToggleOffFitToWindow()),
+                this, SIGNAL(signalToggleOffFitToWindow()));
     }
 }
 
@@ -118,7 +123,7 @@ void EditorStackView::increaseZoom()
     }
     else
     {
-        PreviewWidget *preview = previewWidget();
+        PreviewWidget* preview = previewWidget();
         if (preview)
             preview->slotIncreaseZoom();
     }
@@ -132,7 +137,7 @@ void EditorStackView::decreaseZoom()
     }
     else
     {
-        PreviewWidget *preview = previewWidget();
+        PreviewWidget* preview = previewWidget();
         if (preview)
             preview->slotDecreaseZoom();
     }
@@ -140,45 +145,32 @@ void EditorStackView::decreaseZoom()
 
 void EditorStackView::toggleFitToWindow()
 {
-    if (viewMode() == CanvasMode)
-    {
-        d->canvas->toggleFitToWindow();
-    }
-    else
-    {
-        PreviewWidget *preview = previewWidget();
-        if (preview)
-            preview->toggleFitToWindow();
-    }
+    // Fit to window action is common place to switch view in this mode.
+    // User want to see the same behavors between canvas and tool preview.
+    // Both are toggle at the same time.
+    d->canvas->toggleFitToWindow();
+    PreviewWidget* preview = previewWidget();
+    if (preview)
+        preview->toggleFitToWindow();
 }
 
 void EditorStackView::fitToSelect()
 {
     if (viewMode() == CanvasMode)
-    {
         d->canvas->fitToSelect();
-    }
 }
 
 void EditorStackView::zoomTo100Percent()
 {
     if (viewMode() == CanvasMode)
     {
-        if (d->canvas->zoomFactor() == 1.0)
-            d->canvas->toggleFitToWindow();
-        else
-            d->canvas->setZoomFactor(1.0);
+        d->canvas->setZoomFactor(1.0);
     }
     else
     {
-        PreviewWidget *preview = previewWidget();
+        PreviewWidget* preview = previewWidget();
         if (preview)
-        {
-            if (preview->zoomFactor() == 1.0)
-                preview->toggleFitToWindow();
-            else
-                preview->setZoomFactor(1.0);
-        }
+            preview->setZoomFactor(1.0);
     }
 }
 
@@ -190,12 +182,69 @@ void EditorStackView::setZoomFactor(double zoom)
     }
     else
     {
-        PreviewWidget *preview = previewWidget();
+        PreviewWidget* preview = previewWidget();
         if (preview)
             preview->setZoomFactor(zoom);
     }
 }
 
+double EditorStackView::zoomMax()
+{
+    if (viewMode() == CanvasMode)
+    {
+        return d->canvas->zoomMax();
+    }
+    else
+    {
+        PreviewWidget* preview = previewWidget();
+        if (preview)
+            return preview->zoomMax();
+        else 
+            return -1.0;
+    }
+}
+
+double EditorStackView::zoomMin()
+{
+    if (viewMode() == CanvasMode)
+    {
+        return d->canvas->zoomMin();
+    }
+    else
+    {
+        PreviewWidget* preview = previewWidget();
+        if (preview)
+            return preview->zoomMin();
+        else 
+            return -1.0;
+    }
+}
+    
+void EditorStackView::slotZoomSliderChanged(int size)
+{
+    if (viewMode() == ToolViewMode && !previewWidget())
+        return;
+
+    double h    = (double)ThumbnailSize::Huge;
+    double s    = (double)ThumbnailSize::Small;
+    double zmin = zoomMin();
+    double zmax = zoomMax();
+    double b    = (zmin-(zmax*s/h))/(1-s/h);
+    double a    = (zmax-b)/h;
+    double z    = a*size+b;
+
+    if (viewMode() == CanvasMode)
+    {
+        d->canvas->setZoomFactorSnapped(z);
+    }
+    else
+    {
+        PreviewWidget* preview = previewWidget();
+        if (preview)
+            preview->setZoomFactorSnapped(z);
+    } 
+}
+    
 void EditorStackView::slotZoomChanged(double zoom)
 {
     bool max, min;
@@ -208,7 +257,7 @@ void EditorStackView::slotZoomChanged(double zoom)
     }
     else
     {
-        PreviewWidget *preview = previewWidget();
+        PreviewWidget* preview = previewWidget();
         if (preview)
         {
             max = preview->maxZoom();
@@ -220,12 +269,9 @@ void EditorStackView::slotZoomChanged(double zoom)
 
 PreviewWidget* EditorStackView::previewWidget() const
 {
-    PreviewWidget *preview = dynamic_cast<PreviewWidget*>(d->toolView);
+    PreviewWidget* preview = dynamic_cast<PreviewWidget*>(d->toolView);
     if (preview) return preview;
 
-    ImagePanelWidget *panel = dynamic_cast<ImagePanelWidget*>(d->toolView);
-    if (panel) return (dynamic_cast<PreviewWidget*>(panel->previewWidget()));
-
     return 0;
 }
 
