@@ -6,7 +6,7 @@
  * Date        : 2008-08-20
  * Description : editor tool template class.
  *
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -31,13 +31,13 @@
 // KDE includes
 
 #include <kdebug.h>
+#include <klocale.h>
 
 // Local includes
 
 #include "dimgthreadedfilter.h"
-#include "imagewidget.h"
 #include "imageguidewidget.h"
-#include "imagepanelwidget.h"
+#include "imageregionwidget.h"
 #include "histogramwidget.h"
 #include "histogrambox.h"
 #include "editortoolsettings.h"
@@ -68,7 +68,7 @@ public:
     EditorToolSettings* settings;
 };
 
-EditorTool::EditorTool(QObject *parent)
+EditorTool::EditorTool(QObject* parent)
           : QObject(parent), d(new EditorToolPriv)
 {
     d->timer = new QTimer(this);
@@ -107,17 +107,32 @@ void EditorTool::setToolName(const QString& name)
     d->name = name;
 }
 
+void EditorTool::setPreviewModeMask(int mask)
+{
+    EditorToolIface::editorToolIface()->setPreviewModeMask(mask);
+}
+
 QWidget* EditorTool::toolView() const
 {
     return d->view;
 }
 
-void EditorTool::setToolView(QWidget *view)
+void EditorTool::setToolView(QWidget* view)
 {
     d->view = view;
     // Will be unblocked in slotInit()
     // This will prevent resize event signals emit during tool init.
     d->view->blockSignals(true);
+
+    ImageGuideWidget* wgt = dynamic_cast<ImageGuideWidget*>(d->view);
+    if (wgt)    
+    {
+        connect(d->view, SIGNAL(spotPositionChangedFromOriginal(const Digikam::DColor&, const QPoint&)),
+                this, SLOT(slotUpdateSpotInfo(const Digikam::DColor&, const QPoint&)));
+
+        connect(d->view, SIGNAL(spotPositionChangedFromTarget(const Digikam::DColor&, const QPoint&)),
+                this, SLOT(slotUpdateSpotInfo(const Digikam::DColor&, const QPoint&)));
+    }
 }
 
 EditorToolSettings* EditorTool::toolSettings() const
@@ -125,7 +140,7 @@ EditorToolSettings* EditorTool::toolSettings() const
     return d->settings;
 }
 
-void EditorTool::setToolSettings(EditorToolSettings *settings)
+void EditorTool::setToolSettings(EditorToolSettings* settings)
 {
     d->settings = settings;
 
@@ -227,6 +242,42 @@ void EditorTool::slotCloseTool()
     slotCancel();
 }
 
+void EditorTool::ICCSettingsChanged()
+{
+    ImageGuideWidget* view = dynamic_cast<ImageGuideWidget*>(d->view);
+    if (view)
+        view->ICCSettingsChanged();
+
+    ImageRegionWidget* view2 = dynamic_cast<ImageRegionWidget*>(d->view);
+    if (view2)
+        view2->ICCSettingsChanged();
+}
+
+void EditorTool::exposureSettingsChanged()
+{
+    ImageGuideWidget* view = dynamic_cast<ImageGuideWidget*>(d->view);
+    if (view)
+        view->exposureSettingsChanged();
+
+    ImageRegionWidget* view2 = dynamic_cast<ImageRegionWidget*>(d->view);
+    if (view2)
+        view2->exposureSettingsChanged();
+}
+
+void EditorTool::setToolInfoMessage(const QString& txt)
+{
+    EditorToolIface::editorToolIface()->setToolInfoMessage(txt);
+}
+
+void EditorTool::slotUpdateSpotInfo(const Digikam::DColor& col, const QPoint& point)
+{
+    DColor color = col;
+    setToolInfoMessage(i18n("(%1,%2) RGBA:%3,%4,%5,%6",
+                            point.x(), point.y(),
+                            color.red(), color.green(),
+                            color.blue(), color.alpha()));                              
+}
+
 // ----------------------------------------------------------------
 
 class EditorToolThreadedPriv
@@ -276,7 +327,7 @@ DImgThreadedFilter* EditorToolThreaded::filter() const
     return d->threadedFilter;
 }
 
-void EditorToolThreaded::setFilter(DImgThreadedFilter *filter)
+void EditorToolThreaded::setFilter(DImgThreadedFilter* filter)
 {
     d->threadedFilter = filter;
 
@@ -385,8 +436,7 @@ void EditorToolThreaded::setToolView(QWidget *view)
 {
     EditorTool::setToolView(view);
 
-    if (dynamic_cast<ImageWidget*>(view) || dynamic_cast<ImageGuideWidget*>(view) ||
-        dynamic_cast<ImagePanelWidget*>(view))
+    if (dynamic_cast<ImageGuideWidget*>(view) || dynamic_cast<ImageRegionWidget*>(view))
     {
         connect(view, SIGNAL(signalResized()),
                 this, SLOT(slotResized()));
