@@ -6,7 +6,7 @@
  * Date        : 2008-08-20
  * Description : editor tool template class.
  *
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -29,10 +29,13 @@
 #include <QObject>
 #include <QString>
 #include <QPixmap>
+#include <QPoint>
 
 // Local includes
 
 #include "digikam_export.h"
+#include "dcolor.h"
+#include "previewtoolbar.h"
 
 namespace Digikam
 {
@@ -58,8 +61,12 @@ public:
     QWidget*            toolView() const;
     EditorToolSettings* toolSettings() const;
 
+    virtual void        ICCSettingsChanged();
+    virtual void        exposureSettingsChanged();
+
 public Q_SLOTS:
 
+    void slotUpdateSpotInfo(const Digikam::DColor& col, const QPoint& point);
     virtual void slotCloseTool();
 
 Q_SIGNALS:
@@ -69,12 +76,14 @@ Q_SIGNALS:
 
 protected:
 
+    void setToolInfoMessage(const QString& txt);
     void setToolHelp(const QString& anchor);
     void setToolName(const QString& name);
     void setToolIcon(const QPixmap& icon);
+    void setPreviewModeMask(int mask);
 
-    virtual void setToolView(QWidget *view);
-    virtual void setToolSettings(EditorToolSettings *settings);
+    virtual void setToolView(QWidget* view);
+    virtual void setToolSettings(EditorToolSettings* settings);
     virtual void setBusy(bool);
     virtual void readSettings();
     virtual void writeSettings();
@@ -138,14 +147,14 @@ public Q_SLOTS:
 protected:
 
     DImgThreadedFilter* filter() const;
-    void setFilter(DImgThreadedFilter *filter);
+    void setFilter(DImgThreadedFilter* filter);
 
     /** If true, delete filter instance when preview or final rendering is processed.
         If false, filter instance will be managed outside for ex. with ContentAwareResizing tool.
      */
     void deleteFilterInstance(bool b=true);
 
-    virtual void setToolView(QWidget *view);
+    virtual void setToolView(QWidget* view);
     virtual void prepareEffect(){};
     virtual void prepareFinal(){};
     virtual void putPreviewData(){};
