@@ -6,7 +6,7 @@
  * Date        : 2008-08-20
  * Description : Image editor interface used by editor tools.
  *
- * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -21,14 +21,13 @@
  *
  * ============================================================ */
 
-#include "editortooliface.h"
 #include "editortooliface.moc"
 
-// Qt includes.
+// Qt includes
 
 #include <QWidget>
 
-// Local includes.
+// Local includes
 
 #include "sidebar.h"
 #include "canvas.h"
@@ -37,6 +36,8 @@
 #include "editortoolsettings.h"
 #include "editorstackview.h"
 #include "editorwindow.h"
+#include "imageguidewidget.h"
+#include "imageregionwidget.h"
 
 namespace Digikam
 {
@@ -48,16 +49,12 @@ public:
 
     EditorToolIfacePriv()
     {
-        prevTab = 0;
-        editor  = 0;
-        tool    = 0;
+        editor = 0;
+        tool   = 0;
     }
 
-    QWidget      *prevTab;
-
-    EditorTool   *tool;
-
-    EditorWindow *editor;
+    EditorTool*   tool;
+    EditorWindow* editor;
 };
 
 EditorToolIface* EditorToolIface::m_iface = 0;
@@ -67,7 +64,7 @@ EditorToolIface* EditorToolIface::editorToolIface()
     return m_iface;
 }
 
-EditorToolIface::EditorToolIface(EditorWindow *editor)
+EditorToolIface::EditorToolIface(EditorWindow* editor)
                : QObject(), d(new EditorToolIfacePriv)
 {
     d->editor = editor;
@@ -93,7 +90,6 @@ void EditorToolIface::loadTool(EditorTool* tool)
     d->tool = tool;
     d->editor->editorStackView()->setToolView(d->tool->toolView());
     d->editor->editorStackView()->setViewMode(EditorStackView::ToolViewMode);
-    d->prevTab = d->editor->rightSideBar()->getActiveTab();
     d->editor->rightSideBar()->appendTab(d->tool->toolSettings(), d->tool->toolIcon(), d->tool->toolName());
     d->editor->rightSideBar()->setActiveTab(d->tool->toolSettings());
     d->editor->toggleActions(false);
@@ -101,6 +97,38 @@ void EditorToolIface::loadTool(EditorTool* tool)
     // If editor tool has zoomable preview, switch on zoom actions.
     if (d->editor->editorStackView()->previewWidget())
         d->editor->toggleZoomActions(true);
+
+    ImageGuideWidget* view = dynamic_cast<ImageGuideWidget*>(d->tool->toolView());
+    if (view)
+    {
+        connect(d->editor, SIGNAL(signalPreviewModeChanged(int)),
+                view, SLOT(slotPreviewModeChanged(int)));
+
+        view->slotPreviewModeChanged(d->editor->previewMode());
+    }
+
+    ImageRegionWidget* view2 = dynamic_cast<ImageRegionWidget*>(d->tool->toolView());
+    if (view2)
+    {
+        connect(d->editor, SIGNAL(signalPreviewModeChanged(int)),
+                view2, SLOT(slotPreviewModeChanged(int)));
+
+        if (d->editor->editorStackView()->canvas()->fitToWindow())
+        {
+            view2->toggleFitToWindow();
+        }
+        else
+        {
+            view2->setZoomFactor(d->editor->editorStackView()->canvas()->zoomFactor());
+            QPoint tl = d->editor->editorStackView()->canvas()->visibleArea().topLeft();
+            view2->setContentsPos(tl.x(), tl.y());
+        }
+        view2->slotPreviewModeChanged(d->editor->previewMode());
+    }
+
+    updateExposureSettings();
+    updateICCSettings();
+    setToolInfoMessage(QString());
 }
 
 void EditorToolIface::unLoadTool()
@@ -110,13 +138,21 @@ void EditorToolIface::unLoadTool()
     d->editor->editorStackView()->setViewMode(EditorStackView::CanvasMode);
     d->editor->editorStackView()->setToolView(0);
     d->editor->rightSideBar()->deleteTab(d->tool->toolSettings());
-    d->editor->rightSideBar()->setActiveTab(d->prevTab);
     d->editor->toggleActions(true);
+    d->editor->setPreviewModeMask(PreviewToolBar::NoPreviewMode);
     // To restore canvas zoom level in zoom combobox.
     if (!d->editor->editorStackView()->canvas()->fitToWindow())
         d->editor->editorStackView()->setZoomFactor(d->editor->editorStackView()->canvas()->zoomFactor());
     delete d->tool;
     d->tool = 0;
+
+    // Reset info label in status bar with canvas selection info.
+    d->editor->slotSelected(!d->editor->m_canvas->getSelectedArea().isNull());
+}
+
+void EditorToolIface::setToolInfoMessage(const QString& txt)
+{
+    d->editor->setToolInfoMessage(txt);
 }
 
 void EditorToolIface::setToolStartProgress(const QString& toolName)
@@ -144,4 +180,36 @@ void EditorToolIface::slotToolAborted()
     if (tool) tool->slotAbort();
 }
 
+void EditorToolIface::slotCloseTool()
+{
+    EditorTool *tool = dynamic_cast<EditorTool*>(d->tool);
+    if (tool) tool->slotCloseTool();
+}
+
+void EditorToolIface::setupICC()
+{
+    d->editor->setupICC();
+}
+
+void EditorToolIface::updateICCSettings()
+{
+    ICCSettingsContainer* cmSettings = d->editor->cmSettings();
+    d->editor->editorStackView()->canvas()->setICCSettings(cmSettings);
+    EditorTool *tool = dynamic_cast<EditorTool*>(d->tool);
+    if (tool) tool->ICCSettingsChanged();
+}
+
+void EditorToolIface::updateExposureSettings()
+{
+    ExposureSettingsContainer* expoSettings = d->editor->exposureSettings();
+    d->editor->editorStackView()->canvas()->setExposureSettings(expoSettings);
+    EditorTool *tool = dynamic_cast<EditorTool*>(d->tool);
+    if (tool) tool->exposureSettingsChanged();
+}
+
+void EditorToolIface::setPreviewModeMask(int mask)
+{
+    d->editor->setPreviewModeMask(mask);
+}
+
 }  // namespace Digikam
