@@ -6,7 +6,7 @@
  * Date        : 2008-08-20
  * Description : Image editor interface used by editor tools.
  *
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,6 +37,8 @@ namespace Digikam
 
 class EditorTool;
 class EditorWindow;
+class ExposureSettingsContainer;
+class ICCSettingsContainer;
 class EditorToolIfacePriv;
 
 class DIGIKAM_EXPORT EditorToolIface : public QObject
@@ -47,7 +49,7 @@ public:
 
     static EditorToolIface* editorToolIface();
 
-    EditorToolIface(EditorWindow *editor);
+    EditorToolIface(EditorWindow* editor);
     ~EditorToolIface();
 
     EditorTool* currentTool() const;
@@ -55,12 +57,19 @@ public:
     void loadTool(EditorTool* tool);
     void unLoadTool();
 
+    void setPreviewModeMask(int mask);
+
     void setToolStartProgress(const QString& toolName);
     void setToolProgress(int progress);
     void setToolStopProgress();
 
+    void setToolInfoMessage(const QString& txt);
+    
     void setupICC();
 
+    void updateExposureSettings();
+    void updateICCSettings();
+
 public Q_SLOTS:
 
     void slotCloseTool();
@@ -68,7 +77,7 @@ public Q_SLOTS:
 
 private:
 
-    static EditorToolIface *m_iface;
+    static EditorToolIface* m_iface;
 
     EditorToolIfacePriv* const d;
 };
