@@ -6,8 +6,8 @@
  * Date        : 2008-08-21
  * Description : Editor tool settings template box
  *
- * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2008-2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -43,7 +43,6 @@ class KPushButton;
 namespace Digikam
 {
 class HistogramBox;
-class ImagePanIconWidget;
 class EditorToolSettingsPriv;
 
 class DIGIKAM_EXPORT EditorToolSettings : public QScrollArea
@@ -67,8 +66,7 @@ public:
     {
         NoTool     = 0x00000000,
         ColorGuide = 0x00000001,
-        PanIcon    = 0x00000002,
-        Histogram  = 0x00000004
+        Histogram  = 0x00000002
     };
     Q_DECLARE_FLAGS(Tools, ToolCode)
 
@@ -89,9 +87,8 @@ public:
     int marginHint();
     int spacingHint();
 
-    QWidget* plainPage() const;
+    QWidget*      plainPage()    const;
     HistogramBox* histogramBox() const;
-    ImagePanIconWidget* panIconView() const;
 
     QColor guideColor() const;
     void setGuideColor(const QColor& color);
