@@ -6,8 +6,8 @@
  * Date        : 2006-01-20
  * Description : main image editor GUI implementation
  *
- * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2006-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -41,6 +41,7 @@
 
 #include "digikam_export.h"
 #include "thumbbardock.h"
+#include "previewtoolbar.h"
 
 class QSplitter;
 class QLabel;
@@ -58,8 +59,10 @@ class DPopupMenu;
 class DLogoAction;
 class EditorStackView;
 class EditorWindowPriv;
+class ExposureSettingsContainer;
 class IOFileSettingsContainer;
 class ImagePluginLoader;
+class ICCSettingsContainer;
 class SavingContextContainer;
 class Sidebar;
 class SidebarSplitter;
@@ -84,6 +87,7 @@ Q_SIGNALS:
 
     void signalSelectionChanged(const QRect&);
     void signalNoCurrentItem();
+    void signalPreviewModeChanged(int);
 
 protected:
 
@@ -147,12 +151,14 @@ protected:
 
     bool promptForOverWrite();
     virtual bool hasChangesToSave();
+
     enum SaveOrSaveAs
     {
         AskIfNeeded,
         OverwriteWithoutAsking,
         AlwaysSaveAs
     };
+
     bool promptUserSave(const KUrl& url, SaveOrSaveAs = AskIfNeeded, bool allowCancel = true);
     bool waitForSavingToComplete();
     void startingSave(const KUrl& url);
@@ -161,7 +167,9 @@ protected:
     void moveFile();
     void colorManage();
 
-    EditorStackView* editorStackView() const;
+    EditorStackView*           editorStackView()  const;
+    ExposureSettingsContainer* exposureSettings() const;
+    ICCSettingsContainer*      cmSettings()       const;
 
     virtual void finishSaving(bool success);
 
@@ -255,8 +263,6 @@ private Q_SLOTS:
     void slotContribute();
     void slotToggleSlideShow();
     void slotZoomTo100Percents();
-    void slotZoomSelected(int);
-    void slotZoomTextChanged(const QString&);
     void slotZoomChanged(bool isMax, bool isMin, double zoom);
     void slotSelectionChanged(const QRect& sel);
     void slotToggleFitToWindow();
@@ -284,6 +290,11 @@ private:
     void setToolStartProgress(const QString& toolName);
     void setToolProgress(int progress);
     void setToolStopProgress();
+    
+    void setToolInfoMessage(const QString& txt);
+
+    void setPreviewModeMask(int mask);
+    PreviewToolBar::PreviewMode previewMode();
 
     /**
      * Sets up a temp file to save image contents to and updates the saving
