@@ -6,7 +6,7 @@
  * Date        : 2008-08-20
  * Description : Raw import tool
  *
- * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -207,7 +207,7 @@ void RawImport::slotOk()
     // NOTE: work around B.K.O #211810
     if (d->settingsBox->curvesWidget()->isSixteenBits() != d->settingsBox->settings().sixteenBitsImage)
         d->settingsBox->curvesWidget()->updateData(0, 0, 0, d->settingsBox->settings().sixteenBitsImage);
-      
+
     EditorTool::slotOk();
 }
 
@@ -216,4 +216,14 @@ void RawImport::slotCancel()
     EditorTool::slotCancel();
 }
 
+void RawImport::exposureSettingsChanged()
+{
+    d->previewWidget->exposureSettingsChanged();
+}
+
+void RawImport::ICCSettingsChanged()
+{
+    d->previewWidget->ICCSettingsChanged();
+}
+
 } // namespace Digikam
