@@ -6,7 +6,7 @@
  * Date        : 2006-21-12
  * Description : digiKam light table preview item.
  *
- * Copyright (C) 2006-2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -30,7 +30,6 @@
 #include <QCursor>
 #include <QString>
 #include <QFileInfo>
-#include <QToolButton>
 #include <QPixmap>
 #include <QDragMoveEvent>
 #include <QDropEvent>
@@ -41,7 +40,6 @@
 
 #include <kapplication.h>
 #include <kcursor.h>
-#include <kdatetable.h>
 #include <kdialog.h>
 #include <kiconloader.h>
 #include <klocale.h>
@@ -62,7 +60,6 @@
 #include "dpopupmenu.h"
 #include "loadingdescription.h"
 #include "metadatahub.h"
-#include "paniconwidget.h"
 #include "previewloadthread.h"
 #include "ratingpopupmenu.h"
 #include "tagspopupmenu.h"
@@ -78,9 +75,6 @@ public:
 
     LightTablePreviewPriv()
     {
-        panIconPopup         = 0;
-        panIconWidget        = 0;
-        cornerButton         = 0;
         previewThread        = 0;
         previewPreloadThread = 0;
         hasPrev              = false;
@@ -88,32 +82,23 @@ public:
         selected             = false;
         dragAndDropEnabled   = true;
         loadFullImageSize    = false;
-        currentFitWindowZoom = 0;
         previewSize          = 1024;
-        keepZoom             = false;
+        isLoaded             = false;
     }
 
+    bool               isLoaded;
     bool               hasPrev;
     bool               hasNext;
     bool               selected;
     bool               dragAndDropEnabled;
     bool               loadFullImageSize;
-    bool               keepZoom;
 
     int                previewSize;
 
-    double             currentFitWindowZoom;
-
     QString            path;
     QString            nextPath;
     QString            previousPath;
 
-    QToolButton*       cornerButton;
-
-    KPopupFrame*       panIconPopup;
-
-    PanIconWidget*     panIconWidget;
-
     DImg               preview;
 
     ImageInfo          imageInfo;
@@ -125,10 +110,6 @@ public:
 LightTablePreview::LightTablePreview(QWidget *parent)
                  : PreviewWidget(parent), d(new LightTablePreviewPriv)
 {
-    KSharedConfig::Ptr config = KGlobal::config();
-    KConfigGroup group        = config->group("LightTable Settings");
-    d->keepZoom               = group.readEntry("Zoom fixed",              false);
- 
     // get preview size from screen size, but limit from VGA to WQXGA
     d->previewSize = qMax(KApplication::desktop()->height(),
                           KApplication::desktop()->width());
@@ -143,17 +124,11 @@ LightTablePreview::LightTablePreview(QWidget *parent)
     slotThemeChanged();
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
-    d->cornerButton = PanIconWidget::button();
-    setCornerWidget(d->cornerButton);
-
     setLineWidth(5);
     setSelected(false);
 
     // ------------------------------------------------------------
 
-    connect(d->cornerButton, SIGNAL(pressed()),
-            this, SLOT(slotCornerButtonPressed()));
-
     connect(this, SIGNAL(signalRightButtonClicked()),
             this, SLOT(slotContextMenu()));
 
@@ -203,7 +178,7 @@ void LightTablePreview::setImage(const DImg& image)
 {
     d->preview = image;
 
-    updateZoomAndSize(!d -> keepZoom);
+    updateZoomAndSize(false);
 
     viewport()->setUpdatesEnabled(true);
     viewport()->update();
@@ -243,6 +218,7 @@ void LightTablePreview::setImagePath(const QString& path)
     {
         slotReset();
         unsetCursor();
+        d->isLoaded = false;
         return;
     }
 
@@ -250,14 +226,15 @@ void LightTablePreview::setImagePath(const QString& path)
     {
         d->previewThread = new PreviewLoadThread();
         d->previewThread->setDisplayingWidget(this);
-        connect(d->previewThread, SIGNAL(signalImageLoaded(const LoadingDescription &, const DImg &)),
-                this, SLOT(slotGotImagePreview(const LoadingDescription &, const DImg&)));
+        connect(d->previewThread, SIGNAL(signalImageLoaded(const LoadingDescription&, const DImg&)),
+                this, SLOT(slotGotImagePreview(const LoadingDescription&, const DImg&)));
     }
+
     if (!d->previewPreloadThread)
     {
         d->previewPreloadThread = new PreviewLoadThread();
         d->previewPreloadThread->setDisplayingWidget(this);
-        connect(d->previewPreloadThread, SIGNAL(signalImageLoaded(const LoadingDescription &, const DImg &)),
+        connect(d->previewPreloadThread, SIGNAL(signalImageLoaded(const LoadingDescription&, const DImg&)),
                 this, SLOT(slotNextPreload()));
     }
 
@@ -285,7 +262,7 @@ void LightTablePreview::slotGotImagePreview(const LoadingDescription& descriptio
                    info.fileName()));
         p.end();
         setImage(DImg(pix.toImage()));
-
+        d->isLoaded = false;
         emit signalPreviewLoaded(false);
     }
     else
@@ -294,6 +271,7 @@ void LightTablePreview::slotGotImagePreview(const LoadingDescription& descriptio
         if (AlbumSettings::instance()->getExifRotate())
             d->previewThread->exifRotate(img, description.filePath);
         setImage(img);
+        d->isLoaded = true;
         emit signalPreviewLoaded(true);
     }
 
@@ -306,16 +284,18 @@ void LightTablePreview::slotNextPreload()
     QString loadPath;
     if (!d->nextPath.isNull())
     {
-        loadPath    = d->nextPath;
+        loadPath = d->nextPath;
         d->nextPath.clear();
     }
     else if (!d->previousPath.isNull())
     {
-        loadPath        = d->previousPath;
+        loadPath = d->previousPath;
         d->previousPath.clear();
     }
     else
+    {
         return;
+    }
 
     if (d->loadFullImageSize)
         d->previewThread->loadHighQuality(loadPath, AlbumSettings::instance()->getExifRotate());
@@ -330,7 +310,9 @@ void LightTablePreview::setImageInfo(const ImageInfo& info, const ImageInfo& pre
     d->hasNext   = !next.isNull();
 
     if (!d->imageInfo.isNull())
+    {
         setImagePath(info.filePath());
+    }
     else
     {
         setImagePath();
@@ -363,7 +345,7 @@ void LightTablePreview::slotContextMenu()
     QAction *fitWindowAction = new QAction(SmallIcon("zoom-fit-best"), i18n("Fit to &Window"), this);
     QAction *slideshowAction = new QAction(SmallIcon("view-presentation"), i18n("Slideshow"), this);
     QAction *editAction      = new QAction(SmallIcon("editimage"), i18n("Edit..."), this);
-    QAction *trashAction     = new QAction(SmallIcon("user-trash"), i18n("Move to Trash"), this);
+    QAction *trashAction     = new QAction(SmallIcon("user-trash"), i18nc("Non-pluralized", "Move to Trash"), this);
 
     // --------------------------------------------------------
 
@@ -457,72 +439,6 @@ void LightTablePreview::slotThemeChanged()
     frameChanged();
 }
 
-void LightTablePreview::slotCornerButtonPressed()
-{
-    if (d->panIconPopup)
-    {
-        d->panIconPopup->hide();
-        delete d->panIconPopup;
-        d->panIconPopup = 0;
-    }
-
-    d->panIconPopup    = new KPopupFrame(this);
-    PanIconWidget *pan = new PanIconWidget(d->panIconPopup);
-    pan->setImage(180, 120, getImage());
-    d->panIconPopup->setMainWidget(pan);
-
-    QRect r((int)(contentsX()    / zoomFactor()), (int)(contentsY()     / zoomFactor()),
-            (int)(visibleWidth() / zoomFactor()), (int)(visibleHeight() / zoomFactor()));
-    pan->setRegionSelection(r);
-    pan->setMouseFocus();
-
-    connect(pan, SIGNAL(signalSelectionMoved(const QRect&, bool)),
-            this, SLOT(slotPanIconSelectionMoved(const QRect&, bool)));
-
-    connect(pan, SIGNAL(signalHidden()),
-            this, SLOT(slotPanIconHiden()));
-
-    QPoint g = mapToGlobal(viewport()->pos());
-    g.setX(g.x()+ viewport()->size().width());
-    g.setY(g.y()+ viewport()->size().height());
-    d->panIconPopup->popup(QPoint(g.x() - d->panIconPopup->width(),
-                                  g.y() - d->panIconPopup->height()));
-
-    pan->setCursorToLocalRegionSelectionCenter();
-}
-
-void LightTablePreview::slotPanIconHiden()
-{
-    d->cornerButton->blockSignals(true);
-    d->cornerButton->animateClick();
-    d->cornerButton->blockSignals(false);
-}
-
-void LightTablePreview::slotPanIconSelectionMoved(const QRect& r, bool b)
-{
-    setContentsPos((int)(r.x()*zoomFactor()), (int)(r.y()*zoomFactor()));
-
-    if (b)
-    {
-        d->panIconPopup->hide();
-        d->panIconPopup->deleteLater();
-        d->panIconPopup = 0;
-        slotPanIconHiden();
-    }
-}
-
-void LightTablePreview::zoomFactorChanged(double zoom)
-{
-    updateScrollBars();
-
-    if (horizontalScrollBar()->isVisible() || verticalScrollBar()->isVisible())
-        d->cornerButton->show();
-    else
-        d->cornerButton->hide();
-
-    PreviewWidget::zoomFactorChanged(zoom);
-}
-
 void LightTablePreview::resizeEvent(QResizeEvent* e)
 {
     if (!e) return;
@@ -531,33 +447,12 @@ void LightTablePreview::resizeEvent(QResizeEvent* e)
 
     if (d->imageInfo.isNull())
     {
-        d->cornerButton->hide();
         setDragAndDropMessage();
     }
 
     updateZoomAndSize(false);
 }
 
-void LightTablePreview::updateZoomAndSize(bool alwaysFitToWindow)
-{
-    // Set zoom for fit-in-window as minimum, but don't scale up images
-    // that are smaller than the available space, only scale down.
-    double zoom = calcAutoZoomFactor(ZoomInOnly);
-    setZoomMin(zoom);
-    setZoomMax(zoom*12.0);
-
-    // Is currently the zoom factor set to fit to window? Then set it again to fit the new size.
-    if (zoomFactor() < zoom || alwaysFitToWindow || zoomFactor() == d->currentFitWindowZoom)
-    {
-        setZoomFactor(zoom);
-    }
-
-    // store which zoom factor means it is fit to window
-    d->currentFitWindowZoom = zoom;
-
-    updateContentsSize();
-}
-
 int LightTablePreview::previewWidth()
 {
     return d->preview.width();
@@ -586,7 +481,7 @@ void LightTablePreview::resetPreview()
     emit signalPreviewLoaded(false);
 }
 
-void LightTablePreview::paintPreview(QPixmap *pix, int sx, int sy, int sw, int sh)
+void LightTablePreview::paintPreview(QPixmap* pix, int sx, int sy, int sw, int sh)
 {
     DImg img     = d->preview.smoothScaleSection(sx, sy, sw, sh, tileSize(), tileSize());
     QPixmap pix2 = img.convertToPixmap();
@@ -595,7 +490,44 @@ void LightTablePreview::paintPreview(QPixmap *pix, int sx, int sy, int sw, int s
     p.end();
 }
 
-void LightTablePreview::contentsDragEnterEvent(QDragEnterEvent *e)
+void LightTablePreview::viewportPaintExtraData()
+{
+    if (!m_movingInProgress && d->isLoaded)
+    {
+        QPainter p(viewport());
+        p.setRenderHint(QPainter::Antialiasing, true);
+        p.setBackgroundMode(Qt::TransparentMode);
+        QFontMetrics fontMt = p.fontMetrics();
+
+        QString text;
+        QRect textRect, fontRect;
+        QRect region = contentsRect();
+        p.translate(region.topLeft());
+
+        if (!d->loadFullImageSize)
+        {
+            if (d->imageInfo.format().startsWith("RAW"))
+                text = i18n("Embedded JPEG Preview");
+            else
+                text = i18n("Reduced Size Preview");
+        }
+        else
+        {
+            if (d->imageInfo.format().startsWith("RAW"))
+                text = i18n("Half Size Raw Preview");
+            else
+                text = i18n("Full Size Preview");
+        }
+
+        fontRect = fontMt.boundingRect(0, 0, contentsWidth(), contentsHeight(), 0, text);
+        textRect.setTopLeft(QPoint(region.topRight().x()-fontRect.width()-20, region.topRight().y()+20));
+        textRect.setSize( QSize(fontRect.width()+2, fontRect.height()+2) );
+        drawText(&p, textRect, text);
+        p.end();
+    }
+}
+
+void LightTablePreview::contentsDragEnterEvent(QDragEnterEvent* e)
 {
     if (d->dragAndDropEnabled)
     {
@@ -617,7 +549,7 @@ void LightTablePreview::contentsDragEnterEvent(QDragEnterEvent *e)
     e->ignore();
 }
 
-void LightTablePreview::contentsDropEvent(QDropEvent *e)
+void LightTablePreview::contentsDropEvent(QDropEvent* e)
 {
     if (d->dragAndDropEnabled)
     {
@@ -692,7 +624,7 @@ bool LightTablePreview::isSelected()
     return d->selected;
 }
 
-void LightTablePreview::drawFrame(QPainter *p)
+void LightTablePreview::drawFrame(QPainter* p)
 {
     if (d->selected)
     {
@@ -700,7 +632,14 @@ void LightTablePreview::drawFrame(QPainter *p)
         qDrawPlainRect(p, frameRect(), ThemeEngine::instance()->textSelColor(), 2);
     }
     else
+    {
         qDrawPlainRect(p, frameRect(), ThemeEngine::instance()->baseColor(), lineWidth());
+    }
+}
+
+QImage LightTablePreview::previewToQImage() const
+{
+    return d->preview.copyQImage();
 }
 
 }  // namespace Digikam
