@@ -280,9 +280,17 @@ void LightTableWindow::setupStatusBar()
     statusBar()->addWidget(d->leftZoomBar, 1);
     d->leftZoomBar->setEnabled(false);
 
+    d->leftFileName = new KSqueezedTextLabel(statusBar());
+    d->leftFileName->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
+    statusBar()->addWidget(d->leftFileName, 10);
+
     d->statusProgressBar = new StatusProgressBar(statusBar());
     d->statusProgressBar->setAlignment(Qt::AlignCenter);
-    statusBar()->addWidget(d->statusProgressBar, 100);
+    statusBar()->addWidget(d->statusProgressBar, 10);
+
+    d->rightFileName = new KSqueezedTextLabel(statusBar());
+    d->rightFileName->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
+    statusBar()->addWidget(d->rightFileName, 10);
 
     d->rightZoomBar = new StatusZoomBar(statusBar());
     statusBar()->addWidget(d->rightZoomBar, 1);
@@ -449,7 +457,7 @@ void LightTableWindow::setupActions()
     connect(d->clearListAction, SIGNAL(triggered()), this, SLOT(slotClearItemsList()));
     actionCollection()->addAction("lighttable_clearlist", d->clearListAction);
 
-    d->fileDeleteAction = new KAction(KIcon("user-trash"), i18n("Move to Trash"), this);
+    d->fileDeleteAction = new KAction(KIcon("user-trash"), i18nc("Non-pluralized", "Move to Trash"), this);
     d->fileDeleteAction->setShortcut(KShortcut(Qt::Key_Delete));
     d->fileDeleteAction->setEnabled(false);
     connect(d->fileDeleteAction, SIGNAL(triggered()), this, SLOT(slotDeleteItem()));
@@ -710,9 +718,11 @@ void LightTableWindow::slotRightPanelLeftButtonClicked()
 void LightTableWindow::slotLeftPreviewLoaded(bool b)
 {
     d->leftZoomBar->setEnabled(b);
+    d->leftFileName->clear();
 
     if (b)
     {
+        d->leftFileName->setText(d->previewView->leftImageInfo().name());
         d->previewView->checkForSelection(d->barView->currentItemImageInfo());
         d->barView->setOnLeftPanel(d->previewView->leftImageInfo());
 
@@ -739,8 +749,11 @@ void LightTableWindow::slotLeftPreviewLoaded(bool b)
 void LightTableWindow::slotRightPreviewLoaded(bool b)
 {
     d->rightZoomBar->setEnabled(b);
+    d->rightFileName->clear();
+
     if (b)
     {
+        d->rightFileName->setText(d->previewView->rightImageInfo().name());
         d->previewView->checkForSelection(d->barView->currentItemImageInfo());
         d->barView->setOnRightPanel(d->previewView->rightImageInfo());
 
