@@ -24,7 +24,7 @@
 #ifndef CONVERT2JP2_H
 #define CONVERT2JP2_H
 
-// Local includes.
+// Local includes
 
 #include "batchtool.h"
 
@@ -48,10 +48,10 @@ public:
 private Q_SLOTS:
 
     void slotSettingsChanged();
+    void slotAssignSettings2Widget();
 
 private:
 
-    void assignSettings2Widget();
     bool toolOperations();
 
 private:
