@@ -23,36 +23,37 @@
 
 #define ICONSIZE 64
 
-#include "queuelist.h"
 #include "queuelist.moc"
 
-// Qt includes.
+// Qt includes
 
-#include <QPainter>
 #include <QDragEnterEvent>
-#include <QUrl>
 #include <QFileInfo>
 #include <QHeaderView>
+#include <QPainter>
 #include <QTimer>
+#include <QUrl>
 
-// KDE includes.
+// KDE includes
 
-#include <klocale.h>
-#include <kiconloader.h>
-#include <kdebug.h>
 #include <kaction.h>
-#include <kmenu.h>
 #include <kactioncollection.h>
+#include <kiconloader.h>
+#include <klocale.h>
+#include <kmenu.h>
+#include <kurl.h>
 
-// Local includes.
+// Local includes
 
 #include "albumdb.h"
-#include "thumbnailsize.h"
-#include "thumbnailloadthread.h"
-#include "renamecustomizer.h"
+#include "databasechangesets.h"
+#include "databasewatch.h"
 #include "ddragobjects.h"
+#include "defaultrenameparser.h"
 #include "queuemgrwindow.h"
 #include "queuetooltip.h"
+#include "thumbnailloadthread.h"
+#include "thumbnailsize.h"
 
 namespace Digikam
 {
@@ -203,17 +204,17 @@ public:
 
     bool                 showTips;
 
-    QTimer              *toolTipTimer;
+    QTimer*              toolTipTimer;
 
-    ThumbnailLoadThread *thumbLoadThread;
+    ThumbnailLoadThread* thumbLoadThread;
 
     QueueSettings        settings;
 
     AssignedBatchTools   toolsList;
 
-    QueueToolTip        *toolTip;
+    QueueToolTip*        toolTip;
 
-    QueueListViewItem   *toolTipItem;
+    QueueListViewItem*   toolTipItem;
 };
 
 QueueListView::QueueListView(QWidget *parent)
@@ -250,6 +251,10 @@ QueueListView::QueueListView(QWidget *parent)
 
     // -----------------------------------------------------------
 
+    connect(DatabaseAccess::databaseWatch(), SIGNAL(collectionImageChange(const CollectionImageChangeset&)),
+            this, SLOT(slotCollectionImageChange(const CollectionImageChangeset&)),
+            Qt::QueuedConnection);
+
     connect(d->thumbLoadThread, SIGNAL(signalThumbnailLoaded(const LoadingDescription&, const QPixmap&)),
             this, SLOT(slotThumbnailLoaded(const LoadingDescription&, const QPixmap&)));
 
@@ -426,7 +431,7 @@ void QueueListView::dropEvent(QDropEvent *e)
             e->acceptProposedAction();
         }
     }
-    else if(DTagDrag::canDecode(e->mimeData()))
+    else if (DTagDrag::canDecode(e->mimeData()))
     {
         int tagID;
         if (!DTagDrag::decode(e->mimeData(), tagID))
@@ -492,7 +497,7 @@ void QueueListView::mouseMoveEvent(QMouseEvent* e)
     {
         QueueListViewItem* item = dynamic_cast<QueueListViewItem*>(itemAt(e->pos()));
 
-        if(d->showTips)
+        if (d->showTips)
         {
             if (!isActiveWindow())
             {
@@ -512,7 +517,7 @@ void QueueListView::mouseMoveEvent(QMouseEvent* e)
                 }
             }
 
-            if(item == d->toolTipItem && !acceptToolTip(e->pos()))
+            if (item == d->toolTipItem && !acceptToolTip(e->pos()))
             {
                 hideToolTip();
             }
@@ -576,7 +581,7 @@ void QueueListView::slotAddItems(const ImageInfoList& list)
         if (!find)
         {
             item = new QueueListViewItem(this, info);
-            d->thumbLoadThread->find(info.fileUrl().path());
+            d->thumbLoadThread->find(info.fileUrl().toLocalFile());
         }
     }
     emit signalQueueContentsChanged();
@@ -667,6 +672,11 @@ void QueueListView::removeItems(int removeType)
 }
 
 void QueueListView::removeItemByInfo(const ImageInfo& info)
+{
+    removeItemById(info.id());
+}
+
+void QueueListView::removeItemById(qlonglong id)
 {
     hideToolTip();
 
@@ -678,7 +688,7 @@ void QueueListView::removeItemByInfo(const ImageInfo& info)
         while (*it)
         {
             QueueListViewItem* item = dynamic_cast<QueueListViewItem*>(*it);
-            if (item->info() == info)
+            if (item->info().id() == id)
             {
                 delete item;
                 find = true;
@@ -693,18 +703,22 @@ void QueueListView::removeItemByInfo(const ImageInfo& info)
 }
 
 bool QueueListView::findItemByInfo(const ImageInfo& info)
+{
+    return (findItemById(info.id()) ? true : false);
+}
+
+QueueListViewItem* QueueListView::findItemById(qlonglong id)
 {
     QTreeWidgetItemIterator it(this);
     while (*it)
     {
         QueueListViewItem* item = dynamic_cast<QueueListViewItem*>(*it);
-        if (item->info() == info)
-            return true;
+        if (item->info().id() == id)
+            return item;
 
         ++it;
     }
-
-    return false;
+    return 0;
 }
 
 QueueListViewItem* QueueListView::findItemByUrl(const KUrl& url)
@@ -729,7 +743,7 @@ int QueueListView::itemsCount()
     while (*it)
     {
         QueueListViewItem* item = dynamic_cast<QueueListViewItem*>(*it);
-        if (item) count++;
+        if (item) ++count;
         ++it;
     }
     return count;
@@ -797,7 +811,10 @@ void QueueListView::slotAssignedToolsChanged(const AssignedBatchTools& tools)
 
 void QueueListView::updateDestFileNames()
 {
-    int index = 1;
+    DefaultRenameParser p;
+    QString parseString      = settings().renamingParser;
+    AssignedBatchTools tools = assignedTools();
+
     QTreeWidgetItemIterator it(this);
     while (*it)
     {
@@ -806,31 +823,31 @@ void QueueListView::updateDestFileNames()
         {
             // Update base name using queue renaming rules.
             ImageInfo info = item->info();
-            QFileInfo fi(info.name());
-
-            QString baseName = fi.baseName();
-            if (settings().renamingRule == QueueSettings::CUSTOMIZE)
-            {
-                QString parser = settings().renamingParser;
-                QString camera = info.photoInfoContainer().make + info.photoInfoContainer().model;
-                QDateTime date = info.dateTime();
-                baseName       = ManualRenameInput::parser(parser, baseName, camera, date, index);
-            }
+            QFileInfo fi(info.filePath());
 
             // Update suffix using assigned batch tool rules.
-            AssignedBatchTools tools = assignedTools();
-            tools.itemUrl            = item->info().fileUrl();
-            QString newSuffix        = tools.targetSuffix();
+            tools.itemUrl     = item->info().fileUrl();
+            QString newSuffix = tools.targetSuffix();
+            QString newName   = QString("%1.%2").arg(fi.completeBaseName()).arg(newSuffix);
 
-            item->setDestFileName(QString("%1.%2").arg(baseName).arg(newSuffix));
+            if (settings().renamingRule == QueueSettings::CUSTOMIZE)
+            {
+                ParseSettings settings(info);
+                settings.parseString = parseString;
+                settings.fileUrl     = KUrl(QString("%1/%2.%3").arg(fi.absolutePath()).arg(fi.completeBaseName()).arg(newSuffix));
+                newName              = p.parse(settings);
+            }
+
+            item->setDestFileName(newName);
         }
         ++it;
-        index++;
     }
 }
 
 void QueueListView::slotContextMenu()
 {
+    if (!viewport()->isEnabled()) return;
+
     KActionCollection *acol = QueueMgrWindow::queueManagerWindow()->actionCollection();
     KMenu popmenu(this);
     popmenu.addAction(acol->action("queuemgr_removeitemssel"));
@@ -839,4 +856,27 @@ void QueueListView::slotContextMenu()
     popmenu.exec(QCursor::pos());
 }
 
+void QueueListView::slotCollectionImageChange(const CollectionImageChangeset& changeset)
+{
+    if (QueueMgrWindow::queueManagerWindow()->isBusy())
+        return;
+
+    switch(changeset.operation())
+    {
+        case CollectionImageChangeset::Removed:
+        case CollectionImageChangeset::RemovedAll:
+        {
+            foreach (const qlonglong& id, changeset.ids())
+            {
+                removeItemById(id);
+            }
+            break;
+        }
+        default:
+        {
+            break;
+        }
+    }
+}
+
 }  // namespace Digikam
