@@ -268,7 +268,7 @@ void QueueMgrWindow::setupUserArea()
 void QueueMgrWindow::setupStatusBar()
 {
     d->statusProgressBar = new StatusProgressBar(statusBar());
-    d->statusProgressBar->setAlignment(Qt::AlignCenter);
+    d->statusProgressBar->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
     d->statusProgressBar->setMaximumHeight(fontMetrics().height()+2);
     statusBar()->addWidget(d->statusProgressBar, 60);
 
@@ -511,7 +511,7 @@ void QueueMgrWindow::writeSettings()
 void QueueMgrWindow::applySettings()
 {
     // Do not apply general settings from config panel if BQM is busy.
-    if (!d->busy) return;
+    if (d->busy) return;
 
     AlbumSettings *settings   = AlbumSettings::instance();
     KSharedConfig::Ptr config = KGlobal::config();
