@@ -21,10 +21,9 @@
  *
  * ============================================================ */
 
-#include "searchgroup.h"
 #include "searchgroup.moc"
 
-// Qt includes.
+// Qt includes
 
 #include <QGridLayout>
 #include <QLabel>
@@ -33,26 +32,27 @@
 #include <QStackedLayout>
 #include <QVBoxLayout>
 
-// KDE includes.
+// KDE includes
 
 #include <kcombobox.h>
-#include <kdebug.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
+#include <kdebug.h>
 
-// Local includes.
+// Local includes
 
-#include "searchview.h"
-#include "searchfields.h"
+#include "rexpanderbox.h"
 #include "searchfieldgroup.h"
+#include "searchfields.h"
 #include "searchutilities.h"
+#include "searchview.h"
 
 namespace Digikam
 {
 
 SearchGroup::SearchGroup(SearchView *parent)
-           : AbstractSearchGroupContainer(parent), 
+           : AbstractSearchGroupContainer(parent),
              m_view(parent), m_layout(0), m_label(0), m_groupType(FirstGroup)
 {
 }
@@ -95,6 +95,7 @@ void SearchGroup::setup(Type type)
     group->addField(SearchField::createField("albumname", group));
     group->addField(SearchField::createField("tagid", group));
     group->addField(SearchField::createField("tagname", group));
+    group->addField(SearchField::createField("notag", group));
     group->addField(SearchField::createField("filename", group));
 
     m_fieldLabels << label;
@@ -112,7 +113,9 @@ void SearchGroup::setup(Type type)
     group->addField(SearchField::createField("creationdate", group));
     group->addField(SearchField::createField("rating", group));
     group->addField(SearchField::createField("dimension", group));
-    group->addField(SearchField::createField("orientation", group));
+    group->addField(SearchField::createField("pageorientation", group));
+    group->addField(SearchField::createField("width", group));
+    group->addField(SearchField::createField("height", group));
     group->addField(SearchField::createField("format", group));
     group->addField(SearchField::createField("colordepth", group));
     group->addField(SearchField::createField("colormodel", group));
@@ -158,6 +161,7 @@ void SearchGroup::setup(Type type)
     group->addField(SearchField::createField("exposureprogram", group));
     group->addField(SearchField::createField("exposuremode", group));
     group->addField(SearchField::createField("sensitivity", group));
+    group->addField(SearchField::createField("orientation", group));
     group->addField(SearchField::createField("flashmode", group));
     group->addField(SearchField::createField("whitebalance", group));
     group->addField(SearchField::createField("whitebalancecolortemperature", group));
@@ -199,7 +203,7 @@ void SearchGroup::setup(Type type)
     QStyleOption option;
     option.initFrom(this);
     int indent = 5 * style()->pixelMetric(QStyle::PM_LayoutLeftMargin, &option, this);
-    indent = qMax(indent, 20);
+    indent     = qMax(indent, 20);
     indentLayout->addSpacing(indent);
 
     m_subgroupLayout = new QVBoxLayout;
@@ -221,7 +225,7 @@ void SearchGroup::setup(Type type)
     reset();
 }
 
-void SearchGroup::read(SearchXmlCachingReader &reader)
+void SearchGroup::read(SearchXmlCachingReader& reader)
 {
     reset();
 
@@ -262,7 +266,7 @@ void SearchGroup::read(SearchXmlCachingReader &reader)
             }
             else
             {
-                kWarning(50003) << "Unhandled search field in XML with field name" << name << endl;
+                kWarning() << "Unhandled search field in XML with field name" << name;
                 reader.readToEndOfElement();
             }
         }
@@ -284,7 +288,7 @@ void SearchGroup::addGroupToLayout(SearchGroup *group)
     m_subgroupLayout->addWidget(group);
 }
 
-void SearchGroup::write(SearchXmlWriter &writer)
+void SearchGroup::write(SearchXmlWriter& writer)
 {
     writer.writeGroup();
     writer.setGroupOperator(m_label->groupOperator());
@@ -333,8 +337,29 @@ QList<QRect> SearchGroup::startupAnimationArea() const
 
 // -------------------------------------------------------------------------
 
+class RadioButtonHBox : public QHBoxLayout
+{
+public:
+
+    RadioButtonHBox(QWidget* left, QWidget *right, Qt::LayoutDirection dir)
+        : QHBoxLayout()
+    {
+        if (dir == Qt::RightToLeft)
+        {
+            addWidget(right, Qt::AlignRight);
+            addWidget(left);
+        }
+        else
+        {
+            addWidget(left);
+            addWidget(right, Qt::AlignLeft);
+        }
+        setSpacing(0);
+    }
+};
+
 SearchGroupLabel::SearchGroupLabel(SearchViewThemedPartsCache *cache, SearchGroup::Type type, QWidget *parent)
-                : QWidget(parent), 
+                : QWidget(parent),
                   m_extended(false), m_groupOp(SearchXml::And), m_fieldOp(SearchXml::And),
                   m_groupOpLabel(0), m_stackedLayout(0), m_themeCache(cache)
 {
@@ -345,17 +370,22 @@ SearchGroupLabel::SearchGroupLabel(SearchViewThemedPartsCache *cache, SearchGrou
     QLabel *mainLabel = new QLabel(i18n("Find Pictures"));
     mainLabel->setObjectName("SearchGroupLabel_MainLabel");
 
-    m_allBox = new QRadioButton(i18n("Meet All of the following conditions"));
-    m_allBox->setObjectName("SearchGroupLabel_CheckBox");
+    // Use radio button with a separate label to fix styling problem, see bug 195809
+    m_allBox = new QRadioButton;
+    QLabel *allBoxLabel = new QLabel(i18n("Meet All of the following conditions"));
+    allBoxLabel->setObjectName("SearchGroupLabel_CheckBox");
 
-    m_anyBox = new QRadioButton(i18n("Meet Any of the following conditions"));
-    m_anyBox->setObjectName("SearchGroupLabel_CheckBox");
+    m_anyBox = new QRadioButton;
+    QLabel *anyBoxLabel = new QLabel(i18n("Meet Any of the following conditions"));
+    anyBoxLabel->setObjectName("SearchGroupLabel_CheckBox");
 
-    m_noneBox = new QRadioButton(i18n("None of these conditions are met"));
-    m_noneBox->setObjectName("SearchGroupLabel_CheckBox");
+    m_noneBox = new QRadioButton;
+    QLabel *noneBoxLabel = new QLabel(i18n("None of these conditions are met"));
+    noneBoxLabel->setObjectName("SearchGroupLabel_CheckBox");
 
-    m_oneNotBox = new QRadioButton(i18n("At least one of these conditions is not met"));
-    m_oneNotBox->setObjectName("SearchGroupLabel_CheckBox");
+    m_oneNotBox = new QRadioButton;
+    QLabel *oneNotBoxLabel = new QLabel(i18n("At least one of these conditions is not met"));
+    oneNotBoxLabel->setObjectName("SearchGroupLabel_CheckBox");
 
     connect(m_allBox, SIGNAL(toggled(bool)),
             this, SLOT(boxesToggled()));
@@ -372,14 +402,14 @@ SearchGroupLabel::SearchGroupLabel(SearchViewThemedPartsCache *cache, SearchGrou
         logo->setPixmap(QPixmap(KStandardDirs::locate("data", "digikam/data/logo-digikam.png"))
                 .scaled(96, 96, Qt::KeepAspectRatio, Qt::SmoothTransformation));
 
-        m_optionsLabel = new SearchClickLabel;
+        m_optionsLabel = new RClickLabel;
         m_optionsLabel->setObjectName("SearchGroupLabel_OptionsLabel");
-        connect(m_optionsLabel, SIGNAL(leftClicked()),
+        connect(m_optionsLabel, SIGNAL(activated()),
                  this, SLOT(toggleShowOptions()));
 
-        QWidget *simpleHeader = new QWidget;
+        QWidget *simpleHeader     = new QWidget;
         QVBoxLayout *headerLayout = new QVBoxLayout;
-        QLabel *simpleLabel1 = new QLabel;
+        QLabel *simpleLabel1      = new QLabel;
         //simpleLabel->setText(i18n("Find Pictures meeting all of these conditions"));
         //simpleLabel->setPixmap(SmallIcon("edit-find", 128));
         simpleLabel1->setText(i18n("Search your collection<br>for pictures meeting the following conditions"));
@@ -390,12 +420,12 @@ SearchGroupLabel::SearchGroupLabel(SearchViewThemedPartsCache *cache, SearchGrou
         headerLayout->setMargin(0);
         simpleHeader->setLayout(headerLayout);
 
-        QWidget *optionsBox = new QWidget;
+        QWidget *optionsBox        = new QWidget;
         QGridLayout *optionsLayout = new QGridLayout;
-        optionsLayout->addWidget(m_allBox,    0, 0);
-        optionsLayout->addWidget(m_anyBox,    1, 0);
-        optionsLayout->addWidget(m_noneBox,   0, 1);
-        optionsLayout->addWidget(m_oneNotBox, 1, 1);
+        optionsLayout->addLayout(new RadioButtonHBox(m_allBox, allBoxLabel, layoutDirection()),       0, 0);
+        optionsLayout->addLayout(new RadioButtonHBox(m_anyBox, anyBoxLabel, layoutDirection()),       1, 0);
+        optionsLayout->addLayout(new RadioButtonHBox(m_noneBox, noneBoxLabel, layoutDirection()),     0, 1);
+        optionsLayout->addLayout(new RadioButtonHBox(m_oneNotBox, oneNotBoxLabel, layoutDirection()), 1, 1);
         optionsLayout->setMargin(0);
         optionsBox->setLayout(optionsLayout);
 
@@ -414,21 +444,21 @@ SearchGroupLabel::SearchGroupLabel(SearchViewThemedPartsCache *cache, SearchGrou
     }
     else
     {
-        m_groupOpLabel = new SearchClickLabel;
+        m_groupOpLabel = new RClickLabel;
         m_groupOpLabel->setObjectName("SearchGroupLabel_GroupOpLabel");
-        connect(m_groupOpLabel, SIGNAL(leftClicked()),
+        connect(m_groupOpLabel, SIGNAL(activated()),
                 this, SLOT(toggleGroupOperator()));
 
-        m_removeLabel = new SearchClickLabel(i18n("Remove Group"));
+        m_removeLabel = new RClickLabel(i18n("Remove Group"));
         m_removeLabel->setObjectName("SearchGroupLabel_RemoveLabel");
-        connect(m_removeLabel, SIGNAL(leftClicked()),
+        connect(m_removeLabel, SIGNAL(activated()),
                 this, SIGNAL(removeClicked()));
 
         m_layout->addWidget(m_groupOpLabel, 0, 0, 1, 1);
-        m_layout->addWidget(m_allBox,       1, 0, 1, 1);
-        m_layout->addWidget(m_anyBox,       2, 0, 1, 1);
-        m_layout->addWidget(m_noneBox,      3, 0, 1, 1);
-        m_layout->addWidget(m_oneNotBox,    4, 0, 1, 1);
+        m_layout->addLayout(new RadioButtonHBox(m_allBox, allBoxLabel, layoutDirection()),       1, 0, 1, 1);
+        m_layout->addLayout(new RadioButtonHBox(m_anyBox, anyBoxLabel, layoutDirection()),       2, 0, 1, 1);
+        m_layout->addLayout(new RadioButtonHBox(m_noneBox, noneBoxLabel, layoutDirection()),     3, 0, 1, 1);
+        m_layout->addLayout(new RadioButtonHBox(m_oneNotBox, oneNotBoxLabel, layoutDirection()), 4, 0, 1, 1);
         m_layout->addWidget(m_removeLabel,  0, 2, 1, 1);
         m_layout->setColumnStretch(1, 10);
     }
